#!/usr/bin/env python
from PyNjoy_mp import *
from os import uname
import multiprocessing as mp
import os, sys, time
import copy
from collections import OrderedDict 
# parallel distribution of the library generation
# Author: Richard Chambon - Ecole Polytechnique
#   based on a modified version by Javier Ortensi - Idaho National laboratory
#   of the workflow endfb7r1_shem361.py developed by EPM

tim0=time.time()
print('___TIMER___: BEGIN @' + str(tim0)) 
print('___TIMER___: BEGIN = 0      s') 
#############################################################################
#  file locations & options
#############################################################################
# folder name where computations are performed
evalName   = "/tmp/shem361_endfb7r1_epm_mp"
# relative path to the 'xnjox' code from current folder
execDir    = "../" + uname()[0]
# evaluation folder paths
evalDir    = "$HOME/evaluations/ENDFB7r1/neutrons/"
scatLawDir = "$HOME/evaluations/ENDFB7r1/thermal_scatt/"

#os.system("rm " + evalName + "/drag*")
#os.system("rm " + evalName + "/*/drag*")
#os.system("rm " + evalName + "/*/out_drag*")
#os.system("rm " + evalName + "/*/file_data_d*")
#os.system("rm " + evalName + "/file*")
os.system("rm " + evalName + "/chain*")
os.system("rm " + evalName + "/temp*")
os.system("rm " + evalName + "/tape*")
os.system("rm " + evalName + "/*/temp*")
os.system("rm " + evalName + "/*/tape*")

ncpu = 23
#ncpu = mp.cpu_count()

job_ref = lib_base(evalName, execDir, evalDir, scatLawDir)
# General options
job_ref.nstr = 26 # SHEM-361 group structure
job_ref.eaf = 0
job_ref.temperatures = ( 293., 550., 900., 1200., 2000. )
job_ref.fission = None
job_ref.dilutions = None
# Specifics for output library format 
job_ref.Espectra = None
job_ref.autolib = (22.53556, 1.11377e4, 0.0005)
job_ref.fp = 0
job_ref.unform = 1
job_ref.concat = 1
# Default options (reminder of the PyNjoy __init__)
#    self.iwt = 4
#    self.legendre = 1
#    self.legendregg = 6
#    self.scatteringLaw = None
#    self.eFiss = None
#    self.branchingNG = None
#    self.branchingN2N = None
#    self.gstr = 0
#    self.oldlib = None
#    self.purr = None
#    self.sgref = 1.0E10
#    self.yields = None
#    self.iburn = -1
#    self.ip1opt = 0
#    self.ifprod = 0
#    self.jp1 = 0
#    self.iverw = 4
#    self.concat = 0 
#    # concat : flag for parallel computing: 0 = sequential / 1 = multi-thread
#    self.unform = 0
#    # unform : flag for library format: 0 = formatted / 1 = unformatted

njoy_jobs = []
tim = time.time()
print('___TIMER___: General options done =' + str(tim - tim0) + ' s') 

#############################################################################
#  fission products
#############################################################################
c1 = len(njoy_jobs)
job_ref_fp = copy.deepcopy(job_ref)
# General options
job_ref_fp.legendre = 0
# Specifics for output library format 
job_ref_fp.fp = 1

# fp with dilution
job_ref_fp.ss = (22.53556, 1.858471e4)

  
this_job = copy.deepcopy(job_ref_fp)
this_job.hmat = "Zr96"
this_job.mat = 4043
this_job.evaluationFile = this_job.evaluationDir + "n-040_Zr_096.endf"
#this_job.fission = None
#this_job.ss = (22.53556, 1.858471e4)
this_job.potential = 6.8813
this_job.dilutions = ( 1.e10, 10000.0, 3549.18335, 1259.67004, 447.079956, \
  158.676849, 56.3173141, 19.9880447, 7.09412289, 2.51783395 )
njoy_jobs.append(this_job)
  
################################################################################
# Specifics for output library format: 
# Draglib
###############################################################################
if __name__ == '__main__':
  print('The total number jobs to process is: '+ str(len(njoy_jobs)))
  #  Parallel execution (concatenate at the end mandatory)
  #    Verify that: job_ref.concat = 1
  #--------------------
  print('Using ' + str(ncpu) + ' processors')
  pool = mp.Pool(processes=ncpu)
  results = []
  results = [pool.apply_async(njoy_job_dendf, args=(this_job,)) for this_job in njoy_jobs]
#  output = [p.get() for p in results]
  pool.close()
  pool.join()  # block at this line until all processes are done
#  for idx, code in enumerate(output):
#    if code != 0:
#      print('njoy run for ' + njoy_jobs[idx].hmat + ' reported an error in draglib!')
  tim1 = time.time()
  print('___TIMER___: All draglib computed =' + str(tim1 - tim) + ' s') 
  tim = tim1

#  for this_job in njoy_jobs:
#    this_job.draglibcat()
#  tim1 =time.time()
#  print('___TIMER___: All draglib concatenated =' + str(tim1 - tim) + ' s') 
#  tim = tim1
#
  for this_job in njoy_jobs:
    this_job.draglibconv()
  tim1 =time.time()
  print('___TIMER___: All draglib concatenated =' + str(tim1 - tim) + ' s') 
  tim = tim1


