#!/usr/bin/env python
from PyNjoy_mp import *
from os import uname
import os, sys, time
import copy
from collections import OrderedDict
# parallel distribution of the library generation
# Author: Richard Chambon - Ecole Polytechnique
#   based on a modified version by Javier Ortensi - Idaho National laboratory
#   of the workflow endfb7r1_shem361.py developed by EPM

tim0=time.time()
print('___TIMER___: BEGIN @' + str(tim0))
print('___TIMER___: BEGIN = 0      s')
#############################################################################
#  file locations & options
#############################################################################
# folder name where computations are performed
evalName   = "/tmp/shem361_endfb7r1_epm_mp"
if not os.path.isdir(evalName): os.mkdir(evalName)
# relative path to the 'xnjox' code from current folder
execDir    = "../" + uname()[0]
# evaluation folder paths
evalDir    = "$HOME/evaluations/ENDFB7r1/neutrons/"
scatLawDir = "$HOME/evaluations/ENDFB7r1/thermal_scatt/"

#os.system("rm " + evalName + "/drag*")
#os.system("rm " + evalName + "/*/drag*")
#os.system("rm " + evalName + "/*/out_drag*")
#os.system("rm " + evalName + "/*/file_data_d*")
#os.system("rm " + evalName + "/file*")
os.system("rm " + evalName + "/chain*")
os.system("rm " + evalName + "/temp*")
os.system("rm " + evalName + "/tape*")
os.system("rm " + evalName + "/*/temp*")
os.system("rm " + evalName + "/*/tape*")

ncpu = 23
#ncpu = mp.cpu_count()

job_ref = lib_base(evalName, execDir, evalDir, scatLawDir)
# General options
job_ref.nstr = 26 # SHEM-361 group structure
job_ref.eaf = 0
job_ref.temperatures = ( 293., 550., 900., 1200., 2000. )
job_ref.fission = None
job_ref.dilutions = None
# Specifics for output library format
job_ref.Espectra = None
job_ref.autolib = (22.53556, 1.11377e4, 0.0005)
job_ref.fp = 0
job_ref.concat = 1
# Default options (reminder of the PyNjoy __init__)
#    self.iwt = 4
#    self.legendre = 1
#    self.legendregg = 6
#    self.scatteringLaw = None
#    self.eFiss = None
#    self.branchingNG = None
#    self.branchingN2N = None
#    self.gstr = 0
#    self.oldlib = None
#    self.purr = None
#    self.sgref = 1.0E10
#    self.yields = None
#    self.iburn = -1
#    self.ip1opt = 0
#    self.ifprod = 0
#    self.jp1 = 0
#    self.iverw = 4
#    self.concat = 0
#    # concat : flag for parallel computing: 0 = sequential / 1 = multi-thread
#    self.unform = 0
#    # unform : flag for library format: 0 = formatted / 1 = unformatted

njoy_jobs = VectPyNjoy()
njoy_jobs.setncpu()

tim = time.time()
print('___TIMER___: General options done =' + str(tim - tim0) + ' s')
#############################################################################
#  Thermal scattering
#############################################################################
job_ref_tsl = copy.deepcopy(job_ref)
# General options
# Specifics for output library format

this_job = copy.deepcopy(job_ref_tsl)
this_job.legendre = 3
this_job.hmat = "H1_H2O"
this_job.mat = 125
this_job.evaluationFile = this_job.evaluationDir + "n-001_H_001.endf"
this_job.scatteringLaw = this_job.ScatteringLawDir + "tsl-HinH2O.endf"
this_job.scatteringMat = 1
this_job.temperatures = ( 293.6, 350.0, 400.0, 450.0, 500.0, 600.0 )
njoy_jobs.append(this_job)

this_job = copy.deepcopy(job_ref_tsl)
this_job.hmat = "H2_D2O"
this_job.mat = 128
this_job.evaluationFile = this_job.evaluationDir + "n-001_H_002.endf"
this_job.scatteringLaw = this_job.ScatteringLawDir + "tsl-DinD2O.endf"
this_job.scatteringMat = 11
this_job.temperatures = ( 293.6, 350.0, 400.0, 450.0, 500.0, 600.0 )
njoy_jobs.append(this_job)

this_job = copy.deepcopy(job_ref_tsl)
this_job.hmat = "H1_CH2"
this_job.mat = 125
this_job.evaluationFile = this_job.evaluationDir + "n-001_H_001.endf"
this_job.scatteringLaw = this_job.ScatteringLawDir + "tsl-HinCH2.endf"
this_job.scatteringMat = 37
this_job.temperatures = ( 296.,  350. )
njoy_jobs.append(this_job)

this_job = copy.deepcopy(job_ref_tsl)
this_job.hmat = "H1_ZRH"
this_job.mat = 125
this_job.temperatures = ( 296., 400., 500., 600., 700., 800., 1000., 1200.)
this_job.evaluationFile = this_job.evaluationDir + "n-001_H_001.endf"
this_job.scatteringLaw = this_job.ScatteringLawDir + "tsl-HinZrH.endf"
this_job.scatteringMat = 7
njoy_jobs.append(this_job)

this_job = copy.deepcopy(job_ref_tsl)
this_job.hmat = "Zr90_ZRH"
this_job.mat =  4025
this_job.temperatures = ( 296., 400., 500., 600., 700., 800., 1000., 1200.)
this_job.evaluationFile = this_job.evaluationDir + "n-040_Zr_090.endf"
this_job.scatteringLaw = this_job.ScatteringLawDir +  "tsl-ZrinZrH.endf"
this_job.scatteringMat = 58
njoy_jobs.append(this_job)

this_job = copy.deepcopy(job_ref_tsl)
this_job.hmat = "C0_GR"
this_job.mat = 600
this_job.temperatures = ( 296., 400., 500., 600., 700., 800., 1000., 1200., 1600., 2000.)
this_job.evaluationFile = this_job.evaluationDir + "n-006_C_000.endf"
this_job.scatteringLaw = this_job.ScatteringLawDir + "tsl-graphite.endf"
this_job.scatteringMat = 31
njoy_jobs.append(this_job)

this_job = copy.deepcopy(job_ref_tsl)
this_job.hmat = "Be9"
this_job.mat = 425
this_job.temperatures = ( 296., 400., 500., 600., 700., 800., 1000., 1200.)
this_job.evaluationFile = this_job.evaluationDir + "n-004_Be_009.endf"
this_job.scatteringLaw = this_job.ScatteringLawDir +  "tsl-Be-metal.endf"
this_job.scatteringMat = 26
njoy_jobs.append(this_job)

print('Number of jobs from isotopes with thermal scattering: '+ str(len(njoy_jobs)))

#############################################################################
#  nominal isotopes
#############################################################################
c1 = len(njoy_jobs)
job_ref_nom = copy.deepcopy(job_ref)
# General options
# Specifics for output library format

iso_dict = OrderedDict()

iso_dict["H1"] = (125, "n-001_H_001.endf")
iso_dict["H2"] = (128, "n-001_H_002.endf")
iso_dict["H3"] = (131, "n-001_H_003.endf")
iso_dict["He3"] = (225, "n-002_He_003.endf")
iso_dict["He4"] = (228, "n-002_He_004.endf")
iso_dict["Li6"] = (325, "n-003_Li_006.endf")
iso_dict["Li7"] = (328, "n-003_Li_007.endf")
iso_dict["Be7"] = (419, "n-004_Be_007.endf")
iso_dict["B10"] = (525, "n-005_B_010.endf")
iso_dict["B11"] = (528, "n-005_B_011.endf")
iso_dict["C0"] = (600, "n-006_C_000.endf")
iso_dict["N14"] = (725, "n-007_N_014.endf")
iso_dict["N15"] = (728, "n-007_N_015.endf")
iso_dict["O16"] = (825, "n-008_O_016.endf")
iso_dict["O17"] = (828, "n-008_O_017.endf")
iso_dict["F19"] = (925, "n-009_F_019.endf")
iso_dict["Na23"] = (1125, "n-011_Na_023.endf")
iso_dict["Mg24"] = (1225, "n-012_Mg_024.endf")
iso_dict["Mg25"] = (1228, "n-012_Mg_025.endf")
iso_dict["Mg26"] = (1231, "n-012_Mg_026.endf")
iso_dict["Al27"] = (1325, "n-013_Al_027.endf")
iso_dict["Si28"] = (1425, "n-014_Si_028.endf")
iso_dict["Si29"] = (1428, "n-014_Si_029.endf")
iso_dict["Si30"] = (1431, "n-014_Si_030.endf")
iso_dict["P31"] = (1525, "n-015_P_031.endf")
iso_dict["S32"] = (1625, "n-016_S_032.endf")
iso_dict["S33"] = (1628, "n-016_S_033.endf")
iso_dict["S34"] = (1631, "n-016_S_034.endf")
iso_dict["S36"] = (1637, "n-016_S_036.endf")
iso_dict["Cl35"] = (1725, "n-017_Cl_035.endf")
iso_dict["Cl37"] = (1731, "n-017_Cl_037.endf")
iso_dict["K39"] = (1925, "n-019_K_039.endf")
iso_dict["K40"] = (1928, "n-019_K_040.endf")
iso_dict["K41"] = (1931, "n-019_K_041.endf")
iso_dict["Ca40"] = (2025, "n-020_Ca_040.endf")
iso_dict["Ca42"] = (2031, "n-020_Ca_042.endf")
iso_dict["Ca43"] = (2034, "n-020_Ca_043.endf")
iso_dict["Ca44"] = (2037, "n-020_Ca_044.endf")
iso_dict["Ca46"] = (2043, "n-020_Ca_046.endf")
iso_dict["Ca48"] = (2049, "n-020_Ca_048.endf")
iso_dict["Ti46"] = (2225, "n-022_Ti_046.endf")
iso_dict["Ti47"] = (2228, "n-022_Ti_047.endf")
iso_dict["Ti48"] = (2231, "n-022_Ti_048.endf")
iso_dict["Ti49"] = (2234, "n-022_Ti_049.endf")
iso_dict["Ti50"] = (2237, "n-022_Ti_050.endf")
iso_dict["V50"] = (2325, "n-023_V_050.endf")
iso_dict["V51"] = (2328, "n-023_V_051.endf")
iso_dict["Cr50"] = (2425, "n-024_Cr_050.endf")
iso_dict["Cr52"] = (2431, "n-024_Cr_052.endf")
iso_dict["Cr53"] = (2434, "n-024_Cr_053.endf")
iso_dict["Cr54"] = (2437, "n-024_Cr_054.endf")
iso_dict["Mn55"] = (2525, "n-025_Mn_055.endf")
iso_dict["Fe54"] = (2625, "n-026_Fe_054.endf")
iso_dict["Fe56"] = (2631, "n-026_Fe_056.endf")
iso_dict["Fe57"] = (2634, "n-026_Fe_057.endf")
iso_dict["Fe58"] = (2637, "n-026_Fe_058.endf")
iso_dict["Co59"] = (2725, "n-027_Co_059.endf")
iso_dict["Ni58"] = (2825, "n-028_Ni_058.endf")
iso_dict["Ni60"] = (2831, "n-028_Ni_060.endf")
iso_dict["Ni61"] = (2834, "n-028_Ni_061.endf")
iso_dict["Ni62"] = (2837, "n-028_Ni_062.endf")
iso_dict["Ni64"] = (2843, "n-028_Ni_064.endf")
iso_dict["Cu63"] = (2925, "n-029_Cu_063.endf")
iso_dict["Cu65"] = (2931, "n-029_Cu_065.endf")
iso_dict["Zn66"] = (3031, "n-030_Zn_066.endf")
iso_dict["Zn67"] = (3034, "n-030_Zn_067.endf")
iso_dict["Zn68"] = (3037, "n-030_Zn_068.endf")
iso_dict["Zn70"] = (3043, "n-030_Zn_070.endf")
iso_dict["Ga69"] = (3125, "n-031_Ga_069.endf")
iso_dict["Ga71"] = (3131, "n-031_Ga_071.endf")
iso_dict["W182"] = (7431, "n-074_W_182.endf")
iso_dict["W183"] = (7434, "n-074_W_183.endf")
iso_dict["W184"] = (7437, "n-074_W_184.endf")
iso_dict["W186"] = (7443, "n-074_W_186.endf")
iso_dict["Pb204"] = (8225, "n-082_Pb_204.endf")
iso_dict["Pb206"] = (8231, "n-082_Pb_206.endf")
iso_dict["Pb207"] = (8234, "n-082_Pb_207.endf")
iso_dict["Pb208"] = (8237, "n-082_Pb_208.endf")
iso_dict["Bi209"] = (8325, "n-083_Bi_209.endf")

for iso_name, tup in iso_dict.items():
  this_job = copy.deepcopy(job_ref_nom)
  this_job.hmat = iso_name
  this_job.mat = tup[0]
  this_job.evaluationFile = this_job.evaluationDir + tup[1]
#  print (this_job.hmat + str(this_job.fp) + str(this_job.dilutions) + str(this_job.scatteringLaw))
  njoy_jobs.append(this_job)

print('Number of jobs from nominal isotopes: '+ str(len(njoy_jobs) - c1))

#############################################################################
#  fissionable isotopes
#############################################################################
c1 = len(njoy_jobs)
job_ref_fiss = copy.deepcopy(job_ref)
# General options
# Specifics for output library format
job_ref_fiss.ss = (22.53556, 3.206464e5)

this_job = copy.deepcopy(job_ref_fiss)
this_job.hmat = "Th230"
this_job.mat = 9034
this_job.evaluationFile = this_job.evaluationDir + "n-090_Th_230.endf"
this_job.fission = 1 # fission without delayed neutrons
#this_job.ss = (22.53556, 3.206464e5)
this_job.potential = 8.7040
this_job.eFiss = 1.7406E+02
this_job.dilutions = ( 1.e10, 10000.0, 3549.18335, 1259.67004, 447.079956, \
  158.676849, 56.3173141, 19.9880447, 7.09412289, 2.51783395 )
njoy_jobs.append(this_job)

this_job = copy.deepcopy(job_ref_fiss)
this_job.hmat = "Th232"
this_job.mat = 9040
this_job.evaluationFile = this_job.evaluationDir + "n-090_Th_232.endf"
this_job.fission = 2 # fission with delayed neutrons
#this_job.ss = (22.53556, 3.206464e5)
this_job.potential = 11.8699
this_job.eFiss = 1.7193E+02
this_job.dilutions = ( 1.e10, 10000.0, 5957.50244, 3549.18335, 2114.42676, \
  1259.67004, 750.448669, 447.079956, 266.347961, 158.676849, 94.5317612, \
  56.3173141, 33.5510521, 19.9880447, 11.9078817, 7.09412289, 4.22632504, \
  2.51783395, 1.5 )
this_job.eFiss = 1.7193E+02
njoy_jobs.append(this_job)

this_job = copy.deepcopy(job_ref_fiss)
this_job.hmat = "Pa231"
this_job.mat = 9131
this_job.evaluationFile = this_job.evaluationDir + "n-091_Pa_231.endf"
this_job.fission = 1 # fission without delayed neutrons
#this_job.ss = (22.53556, 3.206464e5)
this_job.potential = 8.7266
this_job.eFiss = 1.7E2
this_job.dilutions = ( 1.e10, 10000.0, 3549.18335, 1259.67004, 447.079956, \
  158.676849, 56.3173141, 19.9880447, 7.09412289, 2.51783395 )
njoy_jobs.append(this_job)

this_job = copy.deepcopy(job_ref_fiss)
this_job.hmat = "Pa233"
this_job.mat = 9137
this_job.evaluationFile = this_job.evaluationDir + "n-091_Pa_233.endf"
this_job.fission = 1 # fission without delayed neutrons
#this_job.ss = (22.53556, 3.206464e5)
this_job.potential = 9.9950
this_job.eFiss = 1.7558E+02
this_job.dilutions = ( 1.e10, 10000.0, 3549.18335, 1259.67004, 447.079956, \
  158.676849, 56.3173141, 19.9880447, 7.09412289, 2.51783395 )
njoy_jobs.append(this_job)

this_job = copy.deepcopy(job_ref_fiss)
this_job.hmat = "U232"
this_job.mat = 9219
this_job.evaluationFile = this_job.evaluationDir + "n-092_U_232.endf"
this_job.fission = 1 # fission without delayed neutrons
#this_job.ss = (22.53556, 3.206464e5)
this_job.potential = 12.0687
this_job.eFiss = 1.8E2
this_job.dilutions = ( 1.e10, 10000.0, 3549.18335, 1259.67004, 447.079956, \
  158.676849, 56.3173141, 19.9880447, 7.09412289, 2.51783395 )
njoy_jobs.append(this_job)

this_job = copy.deepcopy(job_ref_fiss)
this_job.hmat = "U233"
this_job.mat = 9222
this_job.evaluationFile = this_job.evaluationDir + "n-092_U_233.endf"
this_job.fission = 2 # fission with delayed neutrons
#this_job.ss = (22.53556, 3.206464e5)
this_job.potential = 12.2989
this_job.eFiss = 1.8087E+02
this_job.dilutions = ( 1.e10, 10000.0, 3549.18335, 1259.67004, 447.079956, \
  158.676849, 56.3173141, 19.9880447, 7.09412289, 2.51783395 )
njoy_jobs.append(this_job)

this_job = copy.deepcopy(job_ref_fiss)
this_job.hmat = "U234"
this_job.mat = 9225
this_job.evaluationFile = this_job.evaluationDir + "n-092_U_234.endf"
this_job.fission = 1 # fission without delayed neutrons
#this_job.ss = (22.53556, 3.206464e5)
this_job.potential = 10.0210
this_job.dilutions = ( 1.e10, 10000.0, 3549.18335, 1259.67004, 447.079956, \
  158.676849, 56.3173141, 19.9880447, 7.09412289, 2.51783395 )
njoy_jobs.append(this_job)

this_job = copy.deepcopy(job_ref_fiss)
this_job.hmat = "U235"
this_job.mat = 9228
this_job.evaluationFile = this_job.evaluationDir + "n-092_U_235.endf"
this_job.fission = 2 # fission with delayed neutrons
#this_job.ss = (22.53556, 3.206464e5)
this_job.potential = 11.6070
this_job.dilutions = ( 1.e10, 10000.0, 5957.50244, 3549.18335, 2114.42676, \
  1259.67004, 750.448669, 447.079956, 266.347961, 158.676849, 94.5317612, \
  56.3173141, 33.5510521, 19.9880447, 11.9078817, 7.09412289, 4.22632504, \
  2.51783395, 1.5 )
njoy_jobs.append(this_job)

this_job = copy.deepcopy(job_ref_fiss)
this_job.hmat = "U236"
this_job.mat = 9231
this_job.evaluationFile = this_job.evaluationDir + "n-092_U_236.endf"
this_job.fission = 1 # fission without delayed neutrons
#this_job.ss = (22.53556, 3.206464e5)
this_job.potential = 10.9954
this_job.dilutions = ( 1.e10, 10000.0, 3549.18335, 1259.67004, 447.079956, \
  158.676849, 56.3173141, 19.9880447, 7.09412289, 2.51783395 )
njoy_jobs.append(this_job)

this_job = copy.deepcopy(job_ref_fiss)
this_job.hmat = "U237"
this_job.mat = 9234
this_job.evaluationFile = this_job.evaluationDir + "n-092_U_237.endf"
this_job.fission = 1 # fission without delayed neutrons
#this_job.ss = (22.53556, 3.206464e5)
this_job.potential = 10.5000
this_job.dilutions = ( 1.e10, 10000.0, 3549.18335, 1259.67004, 447.079956, \
  158.676849, 56.3173141, 19.9880447, 7.09412289, 2.51783395 )
njoy_jobs.append(this_job)

this_job = copy.deepcopy(job_ref_fiss)
this_job.hmat = "U238"
this_job.mat = 9237
this_job.evaluationFile = this_job.evaluationDir + "n-092_U_238.endf"
this_job.fission = 2 # fission with delayed neutrons
#this_job.ss = (22.53556, 3.206464e5)
this_job.potential = 11.17103
this_job.dilutions = ( 1.e10, 10000.0, 5957.50244, 3549.18335, 2114.42676, \
  1259.67004, 750.448669, 447.079956, 266.347961, 158.676849, 94.5317612, \
  56.3173141, 33.5510521, 19.9880447, 11.9078817, 7.09412289, 4.22632504, \
  2.51783395, 1.5 )
njoy_jobs.append(this_job)

this_job = copy.deepcopy(job_ref_fiss)
this_job.hmat = "Np236"
this_job.mat = 9343
this_job.evaluationFile = this_job.evaluationDir + "n-093_Np_236.endf"
this_job.fission = 1 # fission without delayed neutrons
#this_job.ss = (22.53556, 3.206464e5)
this_job.eFiss = 1.8E2
this_job.potential = 12.1427
this_job.dilutions = ( 1.e10, 10000.0, 3549.18335, 1259.67004, 447.079956, \
  158.676849, 56.3173141, 19.9880447, 7.09412289, 2.51783395 )
njoy_jobs.append(this_job)

this_job = copy.deepcopy(job_ref_fiss)
this_job.hmat = "Np237"
this_job.mat = 9346
this_job.evaluationFile = this_job.evaluationDir + "n-093_Np_237.endf"
this_job.fission = 1 # fission without delayed neutrons
#this_job.ss = (22.53556, 3.206464e5)
this_job.potential = 11.4369
this_job.branchingN2N = 0.801
this_job.dilutions = ( 1.e10, 10000.0, 3549.18335, 1259.67004, 447.079956, \
  158.676849, 56.3173141, 19.9880447, 7.09412289, 2.51783395 )
njoy_jobs.append(this_job)

this_job = copy.deepcopy(job_ref_fiss)
this_job.hmat = "Np238"
this_job.mat = 9349
this_job.evaluationFile = this_job.evaluationDir + "n-093_Np_238.endf"
this_job.fission = 1 # fission without delayed neutrons
#this_job.ss = (22.53556, 3.206464e5)
this_job.eFiss = 1.8E2
this_job.potential = 10.4000
this_job.dilutions = ( 1.e10, 10000.0, 3549.18335, 1259.67004, 447.079956, \
  158.676849, 56.3173141 )
njoy_jobs.append(this_job)

this_job = copy.deepcopy(job_ref_fiss)
this_job.hmat = "Np239"
this_job.mat = 9352
this_job.evaluationFile = this_job.evaluationDir + "n-093_Np_239.endf"
this_job.fission = 1 # fission without delayed neutrons
#this_job.ss = (22.53556, 3.206464e5)
this_job.eFiss = 1.8E2
this_job.potential = 10.4979
this_job.dilutions = ( 1.e10, 10000.0, 3549.18335, 1259.67004, 447.079956, \
  158.676849, 56.3173141, 19.9880447, 7.09412289, 2.51783395 )
njoy_jobs.append(this_job)

this_job = copy.deepcopy(job_ref_fiss)
this_job.hmat = "Pu236"
this_job.mat = 9428
this_job.evaluationFile = this_job.evaluationDir + "n-094_Pu_236.endf"
this_job.fission = 1 # fission without delayed neutrons
#this_job.ss = (22.53556, 3.206464e5)
this_job.eFiss = 1.8E2
this_job.potential = 11.2458
this_job.dilutions = ( 1.e10, 10000.0, 3549.18335, 1259.67004, 447.079956, \
  158.676849, 56.3173141, 19.9880447, 7.09412289, 2.51783395 )
njoy_jobs.append(this_job)

this_job = copy.deepcopy(job_ref_fiss)
this_job.hmat = "Pu237"
this_job.mat = 9431
this_job.evaluationFile = this_job.evaluationDir + "n-094_Pu_237.endf"
this_job.fission = 1 # fission without delayed neutrons
#this_job.ss = (22.53556, 3.206464e5)
this_job.potential = 10.5209
this_job.dilutions = ( 1.e10, 10000.0, 3549.18335, 1259.67004, 447.079956, \
  158.676849, 56.3173141, 19.9880447, 7.09412289, 2.51783395 )
njoy_jobs.append(this_job)

this_job = copy.deepcopy(job_ref_fiss)
this_job.hmat = "Pu238"
this_job.mat = 9434
this_job.evaluationFile = this_job.evaluationDir + "n-094_Pu_238.endf"
this_job.fission = 1 # fission without delayed neutrons
#this_job.ss = (22.53556, 3.206464e5)
this_job.potential = 10.8897
this_job.dilutions = ( 1.e10, 10000.0, 5957.50244, 3549.18335, 2114.42676, \
  1259.67004, 750.448669, 447.079956, 266.347961, 158.676849, 94.5317612, \
  56.3173141, 33.5510521, 19.9880447, 11.9078817, 7.09412289, 4.22632504, \
  2.51783395, 1.5 )
njoy_jobs.append(this_job)

this_job = copy.deepcopy(job_ref_fiss)
this_job.hmat = "Pu239"
this_job.mat = 9437
this_job.evaluationFile = this_job.evaluationDir + "n-094_Pu_239.endf"
this_job.fission = 2 # fission with delayed neutrons
#this_job.ss = (22.53556, 3.206464e5)
this_job.potential = 10.8897
this_job.dilutions = ( 1.e10, 10000.0, 6311.33494, 3983.29436, 2513.99016, \
  1586.66319, 1001.39615, 632.014573, 398.885514, 251.749976, 158.887822, \
  100.279413, 63.2896882, 39.9442369, 25.2101426, 15.9109633, 10.0419406, \
  6.33780423, 4.0 )
njoy_jobs.append(this_job)

this_job = copy.deepcopy(job_ref_fiss)
this_job.hmat = "Pu240"
this_job.mat = 9440
this_job.evaluationFile = this_job.evaluationDir + "n-094_Pu_240.endf"
this_job.fission = 2 # fission with delayed neutrons
#this_job.ss = (22.53556, 3.206464e5)
this_job.potential = 9.9091
this_job.dilutions = ( 1.e10, 10000.0, 5957.50244, 3549.18335, 2114.42676, \
  1259.67004, 750.448669, 447.079956, 266.347961, 158.676849, 94.5317612, \
  56.3173141, 33.5510521, 19.9880447, 11.9078817, 7.09412289, 4.22632504, \
  2.51783395, 1.5 )
njoy_jobs.append(this_job)

this_job = copy.deepcopy(job_ref_fiss)
this_job.hmat = "Pu241"
this_job.mat = 9443
this_job.evaluationFile = this_job.evaluationDir + "n-094_Pu_241.endf"
this_job.fission = 2 # fission with delayed neutrons
#this_job.ss = (22.53556, 3.206464e5)
this_job.potential = 11.2156
this_job.dilutions = ( 1.e10, 10000.0, 5957.50244, 3549.18335, 2114.42676, \
  1259.67004, 750.448669, 447.079956, 266.347961, 158.676849, 94.5317612, \
  56.3173141, 33.5510521, 19.9880447, 11.9078817, 7.09412289, 4.22632504, \
  2.51783395, 1.5 )
njoy_jobs.append(this_job)

this_job = copy.deepcopy(job_ref_fiss)
this_job.hmat = "Pu242"
this_job.mat = 9446
this_job.evaluationFile = this_job.evaluationDir + "n-094_Pu_242.endf"
this_job.fission = 1 # fission without delayed neutrons
#this_job.ss = (22.53556, 3.206464e5)
this_job.potential = 10.6961
this_job.dilutions = ( 1.e10, 1.e5, 55118.5161, 30380.5178, 16745.2959, \
  9229.76155, 5087.30922, 2804.05024, 1545.55137, 851.885253,  469.546659, \
  258.807233, 142.650752, 78.6270025, 43.3380508, 23.8872981, 13.1663284, \
  7.25708715, 4.0 )
njoy_jobs.append(this_job)

this_job = copy.deepcopy(job_ref_fiss)
this_job.hmat = "Pu243"
this_job.mat = 9449
this_job.evaluationFile = this_job.evaluationDir + "n-094_Pu_243.endf"
this_job.fission = 1 # fission without delayed neutrons
#this_job.ss = (22.53556, 3.206464e5)
this_job.potential = 10.2000
this_job.eFiss = 1.9E2
this_job.dilutions = ( 1.e10, 10000.0, 3549.18335, 1259.67004, 447.079956, \
  158.676849, 56.3173141, 19.9880447, 7.09412289, 2.51783395 )
njoy_jobs.append(this_job)

this_job = copy.deepcopy(job_ref_fiss)
this_job.hmat = "Pu244"
this_job.mat = 9452
this_job.evaluationFile = this_job.evaluationDir + "n-094_Pu_244.endf"
this_job.fission = 1 # fission without delayed neutrons
#this_job.ss = (22.53556, 3.206464e5)
this_job.potential = 10.1000
this_job.dilutions = ( 1.e10, 10000.0, 3549.18335, 1259.67004, 447.079956, \
  158.676849, 56.3173141, 19.9880447, 7.09412289, 2.51783395 )
njoy_jobs.append(this_job)

this_job = copy.deepcopy(job_ref_fiss)
this_job.hmat = "Am241"
this_job.mat = 9543
this_job.evaluationFile = this_job.evaluationDir + "n-095_Am_241.endf"
this_job.fission = 1 # fission without delayed neutrons
#this_job.ss = (22.53556, 3.206464e5)
this_job.potential = 11.0329
this_job.branchingNG = 0.115
this_job.dilutions = ( 1.e10, 10000.0, 5957.50244, 3549.18335, 2114.42676, \
  1259.67004, 750.448669, 447.079956, 266.347961, 158.676849, 94.5317612, \
  56.3173141, 33.5510521, 19.9880447, 11.9078817, 7.09412289, 4.22632504, \
  2.51783395, 1.5 )
njoy_jobs.append(this_job)

this_job = copy.deepcopy(job_ref_fiss)
this_job.hmat = "Am242"
this_job.mat = 9546
this_job.evaluationFile = this_job.evaluationDir + "n-095_Am_242.endf"
this_job.fission = 0 # no fission matrix!!!
#this_job.ss = (22.53556, 3.206464e5)
this_job.potential = 10.2000
this_job.eFiss = 1.9E2
this_job.dilutions = ( 1.e10, 10000.0, 3549.18335, 1259.67004, 447.079956, \
  158.676849, 56.3173141, 19.9880447, 7.09412289, 2.51783395 )
njoy_jobs.append(this_job)

this_job = copy.deepcopy(job_ref_fiss)
this_job.hmat = "Am242m"
this_job.mat = 9547
this_job.evaluationFile = this_job.evaluationDir + "n-095_Am_242m1.endf"
this_job.fission = 1 # fission without delayed neutrons
#this_job.ss = (22.53556, 3.206464e5)
this_job.potential = 10.2000
this_job.eFiss = 1.9E2
this_job.dilutions = ( 1.e10, 10000.0, 3549.18335, 1259.67004, 447.079956, \
  158.676849, 56.3173141 )
njoy_jobs.append(this_job)

this_job = copy.deepcopy(job_ref_fiss)
this_job.hmat = "Am243"
this_job.mat = 9549
this_job.evaluationFile = this_job.evaluationDir + "n-095_Am_243.endf"
this_job.fission = 1 # fission without delayed neutrons
#this_job.ss = (22.53556, 3.206464e5)
this_job.potential = 11.8237
this_job.dilutions = ( 1.e10, 10000.0, 3549.18335, 1259.67004, 447.079956, \
  158.676849, 56.3173141, 19.9880447, 7.09412289, 2.51783395 )
njoy_jobs.append(this_job)

this_job = copy.deepcopy(job_ref_fiss)
this_job.hmat = "Cm241"
this_job.mat = 9628
this_job.evaluationFile = this_job.evaluationDir + "n-096_Cm_241.endf"
this_job.fission = 1 # fission without delayed neutrons
#this_job.ss = (22.53556, 3.206464e5)
this_job.potential = 10.1788
this_job.eFiss = 1.9245E+02
this_job.dilutions = ( 1.e10, 10000.0, 3549.18335, 1259.67004, 447.079956, \
  158.676849, 56.3173141 )
njoy_jobs.append(this_job)

this_job = copy.deepcopy(job_ref_fiss)
this_job.hmat = "Cm242"
this_job.mat = 9631
this_job.evaluationFile = this_job.evaluationDir + "n-096_Cm_242.endf"
this_job.fission = 1 # fission without delayed neutrons
#this_job.ss = (22.53556, 3.206464e5)
this_job.potential = 10.2000
this_job.eFiss = 1.9142E+02
this_job.dilutions = ( 1.e10, 10000.0, 3549.18335, 1259.67004, 447.079956, \
  158.676849, 56.3173141 )
njoy_jobs.append(this_job)

this_job = copy.deepcopy(job_ref_fiss)
this_job.hmat = "Cm243"
this_job.mat = 9634
this_job.evaluationFile = this_job.evaluationDir + "n-096_Cm_243.endf"
this_job.fission = 1 # fission without delayed neutrons
#this_job.ss = (22.53556, 3.206464e5)
this_job.potential = 11.2832
this_job.eFiss = 1.9E2
this_job.dilutions = ( 1.e10, 10000.0, 3549.18335, 1259.67004, 447.079956, \
  158.676849, 56.3173141 )
njoy_jobs.append(this_job)

this_job = copy.deepcopy(job_ref_fiss)
this_job.hmat = "Cm244"
this_job.mat = 9637
this_job.evaluationFile = this_job.evaluationDir + "n-096_Cm_244.endf"
this_job.fission = 1 # fission without delayed neutrons
#this_job.ss = (22.53556, 3.206464e5)
this_job.potential = 10.3200
this_job.eFiss = 1.9049E+02
this_job.dilutions = ( 1.e10, 10000.0, 3549.18335, 1259.67004, 447.079956, \
  158.676849, 56.3173141 )
njoy_jobs.append(this_job)

this_job = copy.deepcopy(job_ref_fiss)
this_job.hmat = "Cm245"
this_job.mat = 9640
this_job.evaluationFile = this_job.evaluationDir + "n-096_Cm_245.endf"
this_job.fission = 1 # fission without delayed neutrons
#this_job.ss = (22.53556, 3.206464e5)
this_job.potential = 11.3900
this_job.eFiss = 1.9E2
this_job.dilutions = ( 1.e10, 10000.0, 3549.18335, 1259.67004, 447.079956, \
  158.676849, 56.3173141 )
njoy_jobs.append(this_job)

this_job = copy.deepcopy(job_ref_fiss)
this_job.hmat = "Cm246"
this_job.mat = 9643
this_job.evaluationFile = this_job.evaluationDir + "n-096_Cm_246.endf"
this_job.fission = 1 # fission without delayed neutrons
#this_job.ss = (22.53556, 3.206464e5)
this_job.potential = 10.2758
this_job.eFiss = 1.9E2
this_job.dilutions = ( 1.e10, 10000.0, 3549.18335, 1259.67004, 447.079956, \
  158.676849, 56.3173141 )
njoy_jobs.append(this_job)

this_job = copy.deepcopy(job_ref_fiss)
this_job.hmat = "Cm247"
this_job.mat = 9646
this_job.evaluationFile = this_job.evaluationDir + "n-096_Cm_247.endf"
this_job.fission = 1 # fission without delayed neutrons
#this_job.ss = (22.53556, 3.206464e5)
this_job.potential = 10.0000
this_job.eFiss = 1.9E2
this_job.dilutions = ( 1.e10, 10000.0, 3549.18335, 1259.67004, 447.079956, \
  158.676849, 56.3173141 )
njoy_jobs.append(this_job)

this_job = copy.deepcopy(job_ref_fiss)
this_job.hmat = "Cm248"
this_job.mat = 9649
this_job.evaluationFile = this_job.evaluationDir + "n-096_Cm_248.endf"
this_job.fission = 1 # fission without delayed neutrons
#this_job.ss = (22.53556, 3.206464e5)
this_job.potential = 10.3971
this_job.eFiss = 1.8885E+02
this_job.dilutions = ( 1.e10, 10000.0, 3549.18335, 1259.67004, 447.079956, \
  158.676849, 56.3173141 )
njoy_jobs.append(this_job)

this_job = copy.deepcopy(job_ref_fiss)
this_job.hmat = "Bk249"
this_job.mat = 9752
this_job.evaluationFile = this_job.evaluationDir + "n-097_Bk_249.endf"
this_job.fission = 1 # fission without delayed neutrons
#this_job.ss = (22.53556, 3.206464e5)
this_job.potential = 11.0983
this_job.eFiss = 1.9E2
this_job.dilutions = ( 1.e10, 10000.0, 3549.18335, 1259.67004, 447.079956, \
  158.676849, 56.3173141 )
njoy_jobs.append(this_job)

this_job = copy.deepcopy(job_ref_fiss)
this_job.hmat = "Cf249"
this_job.mat = 9852
this_job.evaluationFile = this_job.evaluationDir + "n-098_Cf_249.endf"
this_job.fission = 1 # fission without delayed neutrons
#this_job.ss = (22.53556, 3.206464e5)
this_job.potential = 11.1510
this_job.eFiss = 1.9E2
this_job.dilutions = ( 1.e10, 10000.0, 3549.18335, 1259.67004, 447.079956, \
  158.676849, 56.3173141 )
njoy_jobs.append(this_job)

this_job = copy.deepcopy(job_ref_fiss)
this_job.hmat = "Cf250"
this_job.mat = 9855
this_job.evaluationFile = this_job.evaluationDir + "n-098_Cf_250.endf"
this_job.fission = 1 # fission without delayed neutrons
#this_job.ss = (22.53556, 3.206464e5)
this_job.potential = 9.8800
this_job.eFiss = 1.9E2
this_job.dilutions = ( 1.e10, 10000.0, 3549.18335, 1259.67004, 447.079956, \
  158.676849, 56.3173141 )
njoy_jobs.append(this_job)

this_job = copy.deepcopy(job_ref_fiss)
this_job.hmat = "Cf251"
this_job.mat = 9858
this_job.evaluationFile = this_job.evaluationDir + "n-098_Cf_251.endf"
this_job.fission = 1 # fission without delayed neutrons
#this_job.ss = (22.53556, 3.206464e5)
this_job.potential = 9.8800
this_job.eFiss = 1.9E2
this_job.dilutions = ( 1.e10, 10000.0, 3549.18335, 1259.67004, 447.079956, \
  158.676849, 56.3173141 )
njoy_jobs.append(this_job)

this_job = copy.deepcopy(job_ref_fiss)
this_job.hmat = "Cf252"
this_job.mat = 9861
this_job.evaluationFile = this_job.evaluationDir + "n-098_Cf_252.endf"
this_job.fission = 1 # fission without delayed neutrons
#this_job.ss = (22.53556, 3.206464e5)
this_job.potential = 9.8000
this_job.eFiss = 1.9E2
this_job.dilutions = ( 1.e10, 10000.0, 3549.18335, 1259.67004, 447.079956, \
  158.676849, 56.3173141 )
njoy_jobs.append(this_job)

this_job = copy.deepcopy(job_ref_fiss)
this_job.hmat = "Cf253"
this_job.mat = 9864
this_job.evaluationFile = this_job.evaluationDir + "n-098_Cf_253.endf"
this_job.fission = 1 # fission without delayed neutrons
#this_job.ss = (22.53556, 3.206464e5)
this_job.potential = 9.7600
this_job.eFiss = 1.9E2
this_job.dilutions = ( 1.e10, 10000.0, 3549.18335, 1259.67004, 447.079956, \
  158.676849, 56.3173141 )
njoy_jobs.append(this_job)

print('Number of jobs from fissionable isotopes: '+ str(len(njoy_jobs) - c1))

#############################################################################
#  fission products
#############################################################################
c1 = len(njoy_jobs)
job_ref_fp = copy.deepcopy(job_ref)
# General options
job_ref_fp.legendre = 0
# Specifics for output library format
job_ref_fp.fp = 1


iso_dict = OrderedDict()
iso_dict["Ge72"] = (3231, "n-032_Ge_072.endf")
iso_dict["Ge73"] = (3234, "n-032_Ge_073.endf")
iso_dict["Ge74"] = (3237, "n-032_Ge_074.endf")
iso_dict["Ge76"] = (3243, "n-032_Ge_076.endf")
iso_dict["As75"] = (3325, "n-033_As_075.endf")
iso_dict["Se76"] = (3431, "n-034_Se_076.endf")
iso_dict["Se77"] = (3434, "n-034_Se_077.endf")
iso_dict["Se78"] = (3437, "n-034_Se_078.endf")
iso_dict["Se79"] = (3440, "n-034_Se_079.endf")
iso_dict["Se80"] = (3443, "n-034_Se_080.endf")
iso_dict["Se82"] = (3449, "n-034_Se_082.endf")
iso_dict["Br79"] = (3525, "n-035_Br_079.endf")
iso_dict["Br81"] = (3531, "n-035_Br_081.endf")
iso_dict["Kr80"] = (3631, "n-036_Kr_080.endf")
iso_dict["Kr82"] = (3637, "n-036_Kr_082.endf")
iso_dict["Kr83"] = (3640, "n-036_Kr_083.endf")
iso_dict["Kr84"] = (3643, "n-036_Kr_084.endf")
iso_dict["Kr85"] = (3646, "n-036_Kr_085.endf")
iso_dict["Kr86"] = (3649, "n-036_Kr_086.endf")
iso_dict["Rb85"] = (3725, "n-037_Rb_085.endf")
iso_dict["Rb87"] = (3731, "n-037_Rb_087.endf")
iso_dict["Sr86"] = (3831, "n-038_Sr_086.endf")
iso_dict["Sr87"] = (3834, "n-038_Sr_087.endf")
iso_dict["Sr88"] = (3837, "n-038_Sr_088.endf")
iso_dict["Sr89"] = (3840, "n-038_Sr_089.endf")
iso_dict["Sr90"] = (3843, "n-038_Sr_090.endf")
iso_dict["Y89"] = (3925, "n-039_Y_089.endf")
iso_dict["Y90"] = (3928, "n-039_Y_090.endf")
iso_dict["Y91"] = (3931, "n-039_Y_091.endf")
iso_dict["Nb93"] = (4125, "n-041_Nb_093.endf")
iso_dict["Nb94"] = (4128, "n-041_Nb_094.endf")
iso_dict["Nb95"] = (4131, "n-041_Nb_095.endf")
iso_dict["Mo92"] = (4225, "n-042_Mo_092.endf")
iso_dict["Mo94"] = (4231, "n-042_Mo_094.endf")
iso_dict["Mo95"] = (4234, "n-042_Mo_095.endf")
iso_dict["Mo96"] = (4237, "n-042_Mo_096.endf")
iso_dict["Mo97"] = (4240, "n-042_Mo_097.endf")
iso_dict["Mo98"] = (4243, "n-042_Mo_098.endf")
iso_dict["Mo99"] = (4246, "n-042_Mo_099.endf")
iso_dict["Mo100"] = (4249, "n-042_Mo_100.endf")
iso_dict["Ru99"] = (4434, "n-044_Ru_099.endf")
iso_dict["Ru100"] = (4437, "n-044_Ru_100.endf")
iso_dict["Ru101"] = (4440, "n-044_Ru_101.endf")
iso_dict["Ru102"] = (4443, "n-044_Ru_102.endf")
iso_dict["Ru103"] = (4446, "n-044_Ru_103.endf")
iso_dict["Ru104"] = (4449, "n-044_Ru_104.endf")
iso_dict["Ru105"] = (4452, "n-044_Ru_105.endf")
iso_dict["Ru106"] = (4455, "n-044_Ru_106.endf")
iso_dict["Rh103"] = (4525, "n-045_Rh_103.endf")
iso_dict["Rh105"] = (4531, "n-045_Rh_105.endf")
iso_dict["Pd104"] = (4631, "n-046_Pd_104.endf")
iso_dict["Pd105"] = (4634, "n-046_Pd_105.endf")
iso_dict["Pd106"] = (4637, "n-046_Pd_106.endf")
iso_dict["Pd107"] = (4640, "n-046_Pd_107.endf")
iso_dict["Pd108"] = (4643, "n-046_Pd_108.endf")
iso_dict["Pd110"] = (4649, "n-046_Pd_110.endf")
iso_dict["Ag111"] = (4737, "n-047_Ag_111.endf")
iso_dict["Cd106"] = (4825, "n-048_Cd_106.endf")
iso_dict["Cd108"] = (4831, "n-048_Cd_108.endf")
iso_dict["Cd111"] = (4840, "n-048_Cd_111.endf")
iso_dict["Cd112"] = (4843, "n-048_Cd_112.endf")
iso_dict["Cd113"] = (4846, "n-048_Cd_113.endf")
# iso_dict["Cd114"] = (4849, "n-048_Cd_114.endf") branchingNG = 0.079383
iso_dict["Cd115m"] = (4853, "n-048_Cd_115m1.endf")
iso_dict["Cd116"] = (4855, "n-048_Cd_116.endf")
iso_dict["In113"] = (4925, "n-049_In_113.endf")
iso_dict["Sn112"] = (5025, "n-050_Sn_112.endf")
iso_dict["Sn114"] = (5031, "n-050_Sn_114.endf")
iso_dict["Sn115"] = (5034, "n-050_Sn_115.endf")
iso_dict["Sn116"] = (5037, "n-050_Sn_116.endf")
iso_dict["Sn117"] = (5040, "n-050_Sn_117.endf")
iso_dict["Sn118"] = (5043, "n-050_Sn_118.endf")
iso_dict["Sn119"] = (5046, "n-050_Sn_119.endf")
iso_dict["Sn120"] = (5049, "n-050_Sn_120.endf")
iso_dict["Sn122"] = (5055, "n-050_Sn_122.endf")
iso_dict["Sn123"] = (5058, "n-050_Sn_123.endf")
iso_dict["Sn124"] = (5061, "n-050_Sn_124.endf")
iso_dict["Sn125"] = (5064, "n-050_Sn_125.endf")
iso_dict["Sn126"] = (5067, "n-050_Sn_126.endf")
iso_dict["Sb121"] = (5125, "n-051_Sb_121.endf")
iso_dict["Sb123"] = (5131, "n-051_Sb_123.endf")
iso_dict["Sb124"] = (5134, "n-051_Sb_124.endf")
iso_dict["Sb125"] = (5137, "n-051_Sb_125.endf")
iso_dict["Sb126"] = (5140, "n-051_Sb_126.endf")
iso_dict["Te122"] = (5231, "n-052_Te_122.endf")
iso_dict["Te123"] = (5234, "n-052_Te_123.endf")
iso_dict["Te124"] = (5237, "n-052_Te_124.endf")
iso_dict["Te125"] = (5240, "n-052_Te_125.endf")
# iso_dict["Te126"] = (5243, "n-052_Te_126.endf") branchingNG = 0.091528
iso_dict["Te127m"] = (5247, "n-052_Te_127m1.endf")
# iso_dict["Te128"] = (5249, "n-052_Te_128.endf") branchingNG = 0.031894
iso_dict["Te129m"] = (5253, "n-052_Te_129m1.endf")
iso_dict["Te130"] = (5255, "n-052_Te_130.endf")
iso_dict["Te132"] = (5261, "n-052_Te_132.endf")
iso_dict["I130"] = (5334, "n-053_I_130.endf")
iso_dict["I131"] = (5337, "n-053_I_131.endf")
iso_dict["I135"] = (5349, "n-053_I_135.endf")
iso_dict["Xe128"] = (5437, "n-054_Xe_128.endf")
iso_dict["Xe129"] = (5440, "n-054_Xe_129.endf")
iso_dict["Xe130"] = (5443, "n-054_Xe_130.endf")
iso_dict["Xe131"] = (5446, "n-054_Xe_131.endf")
iso_dict["Xe132"] = (5449, "n-054_Xe_132.endf")
iso_dict["Xe133"] = (5452, "n-054_Xe_133.endf")
iso_dict["Xe134"] = (5455, "n-054_Xe_134.endf")
iso_dict["Xe135"] = (5458, "n-054_Xe_135.endf")
iso_dict["Xe136"] = (5461, "n-054_Xe_136.endf")
iso_dict["Cs133"] = (5525, "n-055_Cs_133.endf")
iso_dict["Cs134"] = (5528, "n-055_Cs_134.endf")
iso_dict["Cs135"] = (5531, "n-055_Cs_135.endf")
iso_dict["Cs136"] = (5534, "n-055_Cs_136.endf")
iso_dict["Cs137"] = (5537, "n-055_Cs_137.endf")
iso_dict["Ba134"] = (5637, "n-056_Ba_134.endf")
iso_dict["Ba135"] = (5640, "n-056_Ba_135.endf")
iso_dict["Ba136"] = (5643, "n-056_Ba_136.endf")
iso_dict["Ba137"] = (5646, "n-056_Ba_137.endf")
iso_dict["Ba138"] = (5649, "n-056_Ba_138.endf")
iso_dict["Ba140"] = (5655, "n-056_Ba_140.endf")
iso_dict["La138"] = (5725, "n-057_La_138.endf")
iso_dict["La139"] = (5728, "n-057_La_139.endf")
iso_dict["La140"] = (5731, "n-057_La_140.endf")
iso_dict["Ce140"] = (5837, "n-058_Ce_140.endf")
iso_dict["Ce141"] = (5840, "n-058_Ce_141.endf")
iso_dict["Ce142"] = (5843, "n-058_Ce_142.endf")
iso_dict["Ce143"] = (5846, "n-058_Ce_143.endf")
iso_dict["Ce144"] = (5849, "n-058_Ce_144.endf")
iso_dict["Pr141"] = (5925, "n-059_Pr_141.endf")
iso_dict["Pr142"] = (5928, "n-059_Pr_142.endf")
iso_dict["Pr143"] = (5931, "n-059_Pr_143.endf")
iso_dict["Nd142"] = (6025, "n-060_Nd_142.endf")
iso_dict["Nd143"] = (6028, "n-060_Nd_143.endf")
iso_dict["Nd144"] = (6031, "n-060_Nd_144.endf")
iso_dict["Nd145"] = (6034, "n-060_Nd_145.endf")
iso_dict["Nd146"] = (6037, "n-060_Nd_146.endf")
iso_dict["Nd147"] = (6040, "n-060_Nd_147.endf")
iso_dict["Nd148"] = (6043, "n-060_Nd_148.endf")
iso_dict["Nd150"] = (6049, "n-060_Nd_150.endf")
# iso_dict["Pm147"] = (6149, "n-061_Pm_147.endf") branchingNG = 0.470
iso_dict["Pm148"] = (6152, "n-061_Pm_148.endf")
iso_dict["Pm148m"] = (6153, "n-061_Pm_148m1.endf")
iso_dict["Pm149"] = (6155, "n-061_Pm_149.endf")
iso_dict["Pm151"] = (6161, "n-061_Pm_151.endf")
iso_dict["Sm147"] = (6234, "n-062_Sm_147.endf")
iso_dict["Sm148"] = (6237, "n-062_Sm_148.endf")
iso_dict["Sm149"] = (6240, "n-062_Sm_149.endf")
iso_dict["Sm150"] = (6243, "n-062_Sm_150.endf")
iso_dict["Sm151"] = (6246, "n-062_Sm_151.endf")
iso_dict["Sm152"] = (6249, "n-062_Sm_152.endf")
iso_dict["Sm153"] = (6252, "n-062_Sm_153.endf")
iso_dict["Sm154"] = (6255, "n-062_Sm_154.endf")
iso_dict["Eu151"] = (6325, "n-063_Eu_151.endf")
iso_dict["Eu152"] = (6328, "n-063_Eu_152.endf")
iso_dict["Eu153"] = (6331, "n-063_Eu_153.endf")
iso_dict["Eu154"] = (6334, "n-063_Eu_154.endf")
iso_dict["Eu155"] = (6337, "n-063_Eu_155.endf")
iso_dict["Eu156"] = (6340, "n-063_Eu_156.endf")
iso_dict["Eu157"] = (6343, "n-063_Eu_157.endf")
iso_dict["Tb159"] = (6525, "n-065_Tb_159.endf")
iso_dict["Tb160"] = (6528, "n-065_Tb_160.endf")
iso_dict["Ho165"] = (6725, "n-067_Ho_165.endf")
iso_dict["Er166"] = (6837, "n-068_Er_166.endf")
iso_dict["Er167"] = (6840, "n-068_Er_167.endf")
iso_dict["Zr93"] = (4034, "n-040_Zr_093.endf")
iso_dict["Zr95"] = (4040, "n-040_Zr_095.endf")

for iso_name, tup in iso_dict.items():
  this_job = copy.deepcopy(job_ref_fp)
  this_job.hmat = iso_name
  this_job.mat = tup[0]
  this_job.evaluationFile = this_job.evaluationDir + tup[1]
#  print (this_job.hmat + str(this_job.fp) + str(this_job.dilutions) + str(this_job.scatteringLaw))
  njoy_jobs.append(this_job)

# fission product without dilution but additional options

this_job = copy.deepcopy(job_ref_fp)
this_job.hmat = "Cd114"
this_job.mat = 4849
this_job.evaluationFile = this_job.evaluationDir + "n-048_Cd_114.endf"
this_job.branchingNG = 0.079383
njoy_jobs.append(this_job)

this_job = copy.deepcopy(job_ref_fp)
this_job.hmat = "Te126"
this_job.mat = 5243
this_job.evaluationFile = this_job.evaluationDir + "n-052_Te_126.endf"
this_job.branchingNG = 0.091528
njoy_jobs.append(this_job)

this_job = copy.deepcopy(job_ref_fp)
this_job.hmat = "Te128"
this_job.mat = 5249
this_job.evaluationFile = this_job.evaluationDir + "n-052_Te_128.endf"
this_job.branchingNG = 0.031894
njoy_jobs.append(this_job)

this_job = copy.deepcopy(job_ref_fp)
this_job.hmat = "Pm147"
this_job.mat = 6149
this_job.evaluationFile = this_job.evaluationDir + "n-061_Pm_147.endf"
this_job.branchingNG = 0.470
njoy_jobs.append(this_job)

# fp with dilution
job_ref_fp.ss = (22.53556, 1.858471e4)

this_job = copy.deepcopy(job_ref_fp)
this_job.hmat = "Zr90"
this_job.mat = 4025
this_job.evaluationFile = this_job.evaluationDir + "n-040_Zr_090.endf"
#this_job.fission = None
#this_job.ss = (22.53556, 1.858471e4)
this_job.potential = 6.8813
this_job.dilutions = ( 1.e10, 10000.0,  3866.97, 1495.35, 578.2475, 223.6068, 86.4682, 33.4370, 12.9300, 5.0 )
this_job.autolib = (4.632489, 3.481068e3, 0.0005)
njoy_jobs.append(this_job)

this_job = copy.deepcopy(job_ref_fp)
this_job.hmat = "Zr91"
this_job.mat = 4028
this_job.evaluationFile = this_job.evaluationDir + "n-040_Zr_091.endf"
#this_job.fission = None
#this_job.ss = (22.53556, 1.858471e4)
this_job.potential = 6.8813
this_job.dilutions = ( 1.e10, 10000.0, 3549.18335, 1259.67004, 447.079956, \
  158.676849, 56.3173141, 19.9880447, 7.09412289, 2.51783395 )
njoy_jobs.append(this_job)

this_job = copy.deepcopy(job_ref_fp)
this_job.hmat = "Zr92"
this_job.mat = 4031
this_job.evaluationFile = this_job.evaluationDir + "n-040_Zr_092.endf"
#this_job.fission = None
#this_job.ss = (22.53556, 1.858471e4)
this_job.potential = 6.8813
this_job.dilutions = ( 1.e10, 10000.0, 3549.18335, 1259.67004, 447.079956, \
  158.676849, 56.3173141, 19.9880447, 7.09412289, 2.51783395 )
njoy_jobs.append(this_job)

this_job = copy.deepcopy(job_ref_fp)
this_job.hmat = "Zr94"
this_job.mat = 4037
this_job.evaluationFile = this_job.evaluationDir + "n-040_Zr_094.endf"
#this_job.fission = None
#this_job.ss = (22.53556, 1.858471e4)
this_job.potential = 6.8813
this_job.dilutions = ( 1.e10, 10000.0, 3549.18335, 1259.67004, 447.079956, \
  158.676849, 56.3173141, 19.9880447, 7.09412289, 2.51783395 )
njoy_jobs.append(this_job)


this_job = copy.deepcopy(job_ref_fp)
this_job.hmat = "Zr96"
this_job.mat = 4043
this_job.evaluationFile = this_job.evaluationDir + "n-040_Zr_096.endf"
#this_job.fission = None
#this_job.ss = (22.53556, 1.858471e4)
this_job.potential = 6.8813
this_job.dilutions = ( 1.e10, 10000.0, 3549.18335, 1259.67004, 447.079956, \
  158.676849, 56.3173141, 19.9880447, 7.09412289, 2.51783395 )
njoy_jobs.append(this_job)

this_job = copy.deepcopy(job_ref_fp)
this_job.hmat = "Tc99"
this_job.mat = 4325
this_job.evaluationFile = this_job.evaluationDir + "n-043_Tc_099.endf"
#this_job.ss = (22.53556, 1.858471e4)
this_job.potential = 6.4675
this_job.dilutions = ( 1.e10, 10000.0, 4216.96552, 1778.27959, 749.894278, \
  316.227791, 133.352152,  56.2341357, 23.7137381, 10.0 )
njoy_jobs.append(this_job)

this_job = copy.deepcopy(job_ref_fp)
this_job.hmat = "Ag107"
this_job.mat = 4725
this_job.evaluationFile = this_job.evaluationDir + "n-047_Ag_107.endf"
#this_job.ss = (22.53556, 1.858471e4)
this_job.potential = 5.4739
this_job.dilutions = ( 1.e10, 10000.0, 3549.18335, 1259.67004, 447.079956, \
  158.676849, 56.3173141, 19.9880447, 7.09412289, 2.51783395 )
njoy_jobs.append(this_job)

this_job = copy.deepcopy(job_ref_fp)
this_job.hmat = "Ag109"
this_job.mat = 4731
this_job.evaluationFile = this_job.evaluationDir + "n-047_Ag_109.endf"
#this_job.ss = (22.53556, 1.858471e4)
this_job.potential = 5.3316
this_job.dilutions = ( 1.e10, 10000.0, 3549.18335, 1259.67004, 447.079956, \
  158.676849, 56.3173141, 19.9880447, 7.09412289, 2.51783395 )
njoy_jobs.append(this_job)

this_job = copy.deepcopy(job_ref_fp)
this_job.hmat = "Cd110"
this_job.mat = 4837
this_job.evaluationFile = this_job.evaluationDir + "n-048_Cd_110.endf"
#this_job.ss = (22.53556, 1.858471e4)
this_job.potential = 5.1762
this_job.dilutions = ( 1.e10, 10000.0, 3549.18335, 1259.67004, 447.079956, \
  158.676849, 56.3173141, 19.9880447, 7.09412289, 2.51783395 )
njoy_jobs.append(this_job)

this_job = copy.deepcopy(job_ref_fp)
this_job.hmat = "In115"
this_job.mat = 4931
this_job.evaluationFile = this_job.evaluationDir + "n-049_In_115.endf"
#this_job.ss = (22.53556, 1.858471e4)
this_job.potential = 5.0439
this_job.dilutions = ( 1.e10, 10000.0, 3549.18335, 1259.67004, 447.079956, \
  158.676849, 56.3173141, 19.9880447, 7.09412289, 2.51783395 )
njoy_jobs.append(this_job)

this_job = copy.deepcopy(job_ref_fp)
this_job.hmat = "I127"
this_job.mat = 5325
this_job.evaluationFile = this_job.evaluationDir + "n-053_I_127.endf"
#this_job.ss = (22.53556, 1.858471e4)
this_job.potential = 4.5239
this_job.dilutions = ( 1.e10, 10000.0, 4216.96552, 1778.27959, 749.894278, \
  316.227791, 133.352152,  56.2341357, 23.7137381, 10.0 )
njoy_jobs.append(this_job)

this_job = copy.deepcopy(job_ref_fp)
this_job.hmat = "I129"
this_job.mat = 5331
this_job.evaluationFile = this_job.evaluationDir + "n-053_I_129.endf"
#this_job.ss = (22.53556, 1.858471e4)
this_job.potential = 5.8221
this_job.dilutions = ( 1.e10, 10000.0, 4216.96552, 1778.27959, 749.894278, \
  316.227791, 133.352152,  56.2341357, 23.7137381, 10.0 )
njoy_jobs.append(this_job)

this_job = copy.deepcopy(job_ref_fp)
this_job.hmat = "Gd152"
this_job.mat = 6425
this_job.evaluationFile = this_job.evaluationDir + "n-064_Gd_152.endf"
#this_job.ss = (22.53556, 1.858471e4)
this_job.potential = 8.0425
this_job.dilutions = ( 1.e10, 10000.0, 4216.96552, 1778.27959, 749.894278, \
  316.227791, 133.352152,  56.2341357, 23.7137381, 10.0 )
njoy_jobs.append(this_job)

this_job = copy.deepcopy(job_ref_fp)
this_job.hmat = "Gd154"
this_job.mat = 6431
this_job.evaluationFile = this_job.evaluationDir + "n-064_Gd_154.endf"
#this_job.ss = (22.53556, 1.858471e4)
this_job.potential = 6.6723
this_job.dilutions = ( 1.e10, 10000.0, 4216.96552, 1778.27959, 749.894278, \
  316.227791, 133.352152,  56.2341357, 23.7137381, 10.0 )
njoy_jobs.append(this_job)

this_job = copy.deepcopy(job_ref_fp)
this_job.hmat = "Gd155"
this_job.mat = 6434
this_job.evaluationFile = this_job.evaluationDir + "n-064_Gd_155.endf"
#this_job.ss = (22.53556, 1.858471e4)
this_job.potential = 6.3376
this_job.dilutions = ( 1.e10, 10000.0, 4216.96552, 1778.27959, 749.894278, \
  316.227791, 133.352152,  56.2341357, 23.7137381, 10.0 )
njoy_jobs.append(this_job)

this_job = copy.deepcopy(job_ref_fp)
this_job.hmat = "Gd156"
this_job.mat = 6437
this_job.evaluationFile = this_job.evaluationDir + "n-064_Gd_156.endf"
#this_job.ss = (22.53556, 1.858471e4)
this_job.potential = 7.3792
this_job.dilutions = ( 1.e10, 10000.0, 4216.96552, 1778.27959, 749.894278, \
  316.227791, 133.352152,  56.2341357, 23.7137381, 10.0 )
njoy_jobs.append(this_job)

this_job = copy.deepcopy(job_ref_fp)
this_job.hmat = "Gd157"
this_job.mat = 6440
this_job.evaluationFile = this_job.evaluationDir + "n-064_Gd_157.endf"
#this_job.ss = (22.53556, 1.858471e4)
this_job.potential = 6.6063
this_job.dilutions = ( 1.e10, 10000.0, 4216.96552, 1778.27959, 749.894278, \
  316.227791, 133.352152,  56.2341357, 23.7137381, 10.0 )
njoy_jobs.append(this_job)

this_job = copy.deepcopy(job_ref_fp)
this_job.hmat = "Gd158"
this_job.mat = 6443
this_job.evaluationFile = this_job.evaluationDir + "n-064_Gd_158.endf"
#this_job.ss = (22.53556, 1.858471e4)
this_job.potential = 7.6454
this_job.dilutions = ( 1.e10, 10000.0, 4216.96552, 1778.27959, 749.894278, \
  316.227791, 133.352152,  56.2341357, 23.7137381, 10.0 )
njoy_jobs.append(this_job)

this_job = copy.deepcopy(job_ref_fp)
this_job.hmat = "Gd160"
this_job.mat = 6449
this_job.evaluationFile = this_job.evaluationDir + "n-064_Gd_160.endf"
#this_job.ss = (22.53556, 1.858471e4)
this_job.potential = 7.0241
this_job.dilutions = ( 1.e10, 10000.0, 4216.96552, 1778.27959, 749.894278, \
  316.227791, 133.352152,  56.2341357, 23.7137381, 10.0 )
njoy_jobs.append(this_job)

this_job = copy.deepcopy(job_ref_fp)
this_job.hmat = "Dy160"
this_job.mat = 6637
this_job.evaluationFile = this_job.evaluationDir + "n-066_Dy_160.endf"
#this_job.ss = (22.53556, 1.858471e4)
this_job.potential = 6.9861
this_job.dilutions = ( 1.e10, 10000.0, 4216.96552, 1778.27959, 749.894278, \
  316.227791, 133.352152,  56.2341357, 23.7137381, 10.0 )
njoy_jobs.append(this_job)

this_job = copy.deepcopy(job_ref_fp)
this_job.hmat = "Dy161"
this_job.mat = 6640
this_job.evaluationFile = this_job.evaluationDir + "n-066_Dy_161.endf"
#this_job.ss = (22.53556, 1.858471e4)
this_job.potential = 7.0121
this_job.dilutions = ( 1.e10, 10000.0, 4216.96552, 1778.27959, 749.894278, \
  316.227791, 133.352152,  56.2341357, 23.7137381, 10.0 )
njoy_jobs.append(this_job)

this_job = copy.deepcopy(job_ref_fp)
this_job.hmat = "Dy162"
this_job.mat = 6643
this_job.evaluationFile = this_job.evaluationDir + "n-066_Dy_162.endf"
#this_job.ss = (22.53556, 1.858471e4)
this_job.potential = 4.5681
this_job.dilutions = ( 1.e10, 10000.0, 4216.96552, 1778.27959, 749.894278, \
  316.227791, 133.352152,  56.2341357, 23.7137381, 10.0 )
njoy_jobs.append(this_job)

this_job = copy.deepcopy(job_ref_fp)
this_job.hmat = "Dy163"
this_job.mat = 6646
this_job.evaluationFile = this_job.evaluationDir + "n-066_Dy_163.endf"
#this_job.ss = (22.53556, 1.858471e4)
this_job.potential = 7.0639
this_job.dilutions = ( 1.e10, 10000.0, 4216.96552, 1778.27959, 749.894278, \
  316.227791, 133.352152,  56.2341357, 23.7137381, 10.0 )
njoy_jobs.append(this_job)

this_job = copy.deepcopy(job_ref_fp)
this_job.hmat = "Dy164"
this_job.mat = 6649
this_job.evaluationFile = this_job.evaluationDir + "n-066_Dy_164.endf"
#this_job.ss = (22.53556, 1.858471e4)
this_job.potential = 7.0897
this_job.dilutions = ( 1.e10, 10000.0, 4216.96552, 1778.27959, 749.894278, \
  316.227791, 133.352152,  56.2341357, 23.7137381, 10.0 )
njoy_jobs.append(this_job)

this_job = copy.deepcopy(job_ref_fp)
this_job.hmat = "Hf174"
this_job.mat = 7225
this_job.evaluationFile = this_job.evaluationDir + "n-072_Hf_174.endf"
#this_job.ss = (22.53556, 1.858471e4)
this_job.potential = 7.1385
this_job.dilutions = ( 1.e10, 10000.0, 4216.96552, 1778.27959, 749.894278, \
  316.227791, 133.352152,  56.2341357, 23.7137381, 10.0 )
njoy_jobs.append(this_job)

this_job = copy.deepcopy(job_ref_fp)
this_job.hmat = "Hf176"
this_job.mat = 7231
this_job.evaluationFile = this_job.evaluationDir + "n-072_Hf_176.endf"
#this_job.ss = (22.53556, 1.858471e4)
this_job.potential = 7.1935
this_job.dilutions = ( 1.e10, 10000.0, 4216.96552, 1778.27959, 749.894278, \
  316.227791, 133.352152,  56.2341357, 23.7137381, 10.0 )
njoy_jobs.append(this_job)

this_job = copy.deepcopy(job_ref_fp)
this_job.hmat = "Hf177"
this_job.mat = 7234
this_job.evaluationFile = this_job.evaluationDir + "n-072_Hf_177.endf"
#this_job.ss = (22.53556, 1.858471e4)
this_job.potential = 7.2202
this_job.dilutions = ( 1.e10, 10000.0, 4216.96552, 1778.27959, 749.894278, \
  316.227791, 133.352152,  56.2341357, 23.7137381, 10.0 )
njoy_jobs.append(this_job)

this_job = copy.deepcopy(job_ref_fp)
this_job.hmat = "Hf178"
this_job.mat = 7237
this_job.evaluationFile = this_job.evaluationDir + "n-072_Hf_178.endf"
#this_job.ss = (22.53556, 1.858471e4)
this_job.potential = 7.2469
this_job.dilutions = ( 1.e10, 10000.0, 4216.96552, 1778.27959, 749.894278, \
  316.227791, 133.352152,  56.2341357, 23.7137381, 10.0 )
njoy_jobs.append(this_job)

this_job = copy.deepcopy(job_ref_fp)
this_job.hmat = "Hf179"
this_job.mat = 7240
this_job.evaluationFile = this_job.evaluationDir + "n-072_Hf_179.endf"
#this_job.ss = (22.53556, 1.858471e4)
this_job.potential = 7.2736
this_job.dilutions = ( 1.e10, 10000.0, 4216.96552, 1778.27959, 749.894278, \
  316.227791, 133.352152,  56.2341357, 23.7137381, 10.0 )
njoy_jobs.append(this_job)

this_job = copy.deepcopy(job_ref_fp)
this_job.hmat = "Hf180"
this_job.mat = 7243
this_job.evaluationFile = this_job.evaluationDir + "n-072_Hf_180.endf"
#this_job.ss = (22.53556, 1.858471e4)
this_job.potential = 7.3004
this_job.dilutions = ( 1.e10, 10000.0, 4216.96552, 1778.27959, 749.894278, \
  316.227791, 133.352152,  56.2341357, 23.7137381, 10.0 )
njoy_jobs.append(this_job)

print('Number of jobs from fission product isotopes: '+ str(len(njoy_jobs) - c1))

tim1 = time.time()
print('___TIMER___: All jobs definition done =' + str(tim1 - tim) + ' s')
tim = tim1
#############################################################################
#  check file locations
#############################################################################
for this_job in njoy_jobs:
  if not os.path.isfile(os.path.expandvars(this_job.evaluationFile)):
    raise PyNjoyError("evaluation file " + this_job.evaluationFile + " not found")
  if this_job.scatteringLaw != None:
    if not os.path.isfile(os.path.expandvars(this_job.scatteringLaw)):
      raise PyNjoyError("scatteringLaw file " + this_job.scatteringLaw + " not found")

njoy_jobs.pendf()
njoy_jobs.gendf()
njoy_jobs.dendf()
njoy_jobs.dconcat()

this_job = copy.deepcopy(job_ref)
this_job.fissionFile = "$HOME/evaluations/ENDFB7r1/nfy/"
this_job.decayFile = "$HOME/evaluations/ENDFB7r1/decay/"
this_job.burnup()
tim1 =time.time()
print('___TIMER___: Depletion computed =' + str(tim1 - tim) + ' s')
tim = tim1
#
tim1=(tim1 - tim0)/3600
print('___TIMER___: Complete draglib computed =' + str(tim1) + ' h')
