#!/usr/bin/env python
from PyNjoy_mp import *
from os import uname
import os, sys, time
import copy
import argparse
from collections import OrderedDict
# parallel distribution of the library generation
# Author: Richard Chambon - Ecole Polytechnique
#   based on a modified version by Javier Ortensi - Idaho National laboratory
#   of the workflow endfb7r1_shem361.py developed by EPM

def main():
  """
  Parse arguments, gather input evaluation folder and output folder
  """
  parser = argparse.ArgumentParser(description="This python script reads ENDF libraries and calls NJOY to generate multigroup libraries.")

  parser.add_argument('-i', '--input', metavar='str', action='store', type=str, default='../ENDF-B-VIII.0',
                      help='The path to the nuclear data evaluattion (Default: ../ENDF-B-VIII.0)')
  parser.add_argument('--njoy-dir', dest="njoy_dir", metavar='str', action='store', type=str, default='../NJOY2016',
                      help='The path to NJOY (Default: ../NJOY2016)')
  parser.add_argument('-o', '--output', metavar='str', action='store', type=str, default='../data',
                      help='The folder where computations are performed and the result files are stored (Default: ../data)')
  args = parser.parse_args()

  tim0=time.time()
  print('___TIMER___: BEGIN @' + str(tim0))
  print('___TIMER___: BEGIN = 0      s')
  #############################################################################
  #  file locations & options
  #############################################################################
  evalName   = args.output
  if not os.path.isdir(evalName): os.mkdir(evalName)
  execDir    = args.njoy_dir + "/build/"
  evalDir    = os.path.abspath(args.input) + "/neutrons/"
  scatLawDir = os.path.abspath(args.input) + "/thermal_scatt/"

  # delete old temp and tape files
  print('Cleanning old files')
  for roots,dirs,files in os.walk(evalName):
    for file in files:
      if "temp" in file or "tape" in file:
        print('delete', os.path.join(roots,file))
        os.system("rm " + os.path.join(roots,file))

  # select number of cores for distributed jobs
  ncpu = mp.cpu_count()

  job_ref = lib_base(evalName, execDir, evalDir, scatLawDir)
  # General options
  job_ref.nstr = 35 # Griffin-400 group structure
  job_ref.eaf = 0
  job_ref.zaid = "0000000"
  job_ref.temperatures = ( 293., 550., 900., 1200., 2000. )
  job_ref.fission = None
  job_ref.dilutions = (1.e10, 1.e5, 1.e4, 1.e3, 100., 10., 1., 0.1, 0.01)
  # Specifics for output library format
  job_ref.Espectra = None
  job_ref.autolib = (22.53556, 1.11377e4, 0.0005)
  job_ref.fp = 0
  job_ref.concat = 1
  job_ref.thermal_cutoff = 10.0
  # Default options (reminder of the PyNjoy __init__)
  #    self.iwt = 4
  #    self.legendre = 1
  #    self.legendregg = 6
  #    self.scatteringLaw = None
  #    self.eFiss = None
  #    self.branchingNG = None
  #    self.branchingN2N = None
  #    self.gstr = 0
  #    self.oldlib = None
  #    self.purr = None
  #    self.sgref = 1.0E10
  #    self.yields = None
  #    self.iburn = -1
  #    self.ip1opt = 0
  #    self.ifprod = 0
  #    self.jp1 = 0
  #    self.iverw = 4
  #    self.concat = 0
  #    # concat : flag for parallel computing: 0 = sequential / 1 = multi-thread
  #    self.unform = 0
  #    # unform : flag for library format: 0 = formatted / 1 = unformatted

  njoy_jobs = VectPyNjoy()
  njoy_jobs.setncpu()

  tim = time.time()
  print('___TIMER___: General options done =' + str(tim - tim0) + ' s')
  #############################################################################
  #  Thermal scattering
  #############################################################################
  job_ref_tsl = copy.deepcopy(job_ref)
  # General options
  # Specifics for output library format

  this_job = copy.deepcopy(job_ref_tsl)
  this_job.hmat = "H1inH2O"
  this_job.mat = 125
  this_job.zaid = "0000013"
  this_job.evaluationFile = this_job.evaluationDir + "n-001_H_001.endf"
  this_job.scatteringLaw = this_job.ScatteringLawDir + "tsl-HinH2O.endf"
  this_job.scatteringMat = 1
  this_job.temperatures = ( 293.6, 350.0, 400.0, 450.0, 500.0, 600.0 )
  njoy_jobs.append(this_job)

  this_job = copy.deepcopy(job_ref_tsl)
  this_job.hmat = "H2inD2O"
  this_job.mat = 128
  this_job.zaid = "0000021"
  this_job.evaluationFile = this_job.evaluationDir + "n-001_H_002.endf"
  this_job.scatteringLaw = this_job.ScatteringLawDir + "tsl-DinD2O.endf"
  this_job.scatteringMat = 11
  this_job.temperatures = ( 293.6, 350.0, 400.0, 450.0, 500.0, 600.0 )
  njoy_jobs.append(this_job)

  this_job = copy.deepcopy(job_ref_tsl)
  this_job.hmat = "H1inPolyethylene"
  this_job.mat = 125
  this_job.zaid = "0000016"
  this_job.evaluationFile = this_job.evaluationDir + "n-001_H_001.endf"
  this_job.scatteringLaw = this_job.ScatteringLawDir + "tsl-HinCH2.endf"
  this_job.scatteringMat = 37
  this_job.temperatures = ( 293.6, 300, 303, 313, 323, 333, 343, 350)
  njoy_jobs.append(this_job)

  this_job = copy.deepcopy(job_ref_tsl)
  this_job.hmat = "H1inZrH"
  this_job.mat = 125
  this_job.zaid = "0000015"
  this_job.temperatures = ( 296., 400., 500., 600., 700., 800., 1000., 1200.)
  this_job.evaluationFile = this_job.evaluationDir + "n-001_H_001.endf"
  this_job.scatteringLaw = this_job.ScatteringLawDir + "tsl-HinZrH.endf"
  this_job.scatteringMat = 7
  njoy_jobs.append(this_job)

  this_job = copy.deepcopy(job_ref_tsl)
  this_job.hmat = "YinYH2"
  this_job.mat = 3925
  this_job.zaid = "0000390"
  this_job.temperatures = (293.6, 400, 500, 600, 700, 800, 1000, 1200, 1400, 1600)
  this_job.evaluationFile = this_job.evaluationDir + "n-001_H_001.endf"
  this_job.scatteringLaw = this_job.ScatteringLawDir +  "tsl-HinYH2.endf"
  this_job.scatteringMat = 5
  njoy_jobs.append(this_job)

  this_job = copy.deepcopy(job_ref_tsl)
  this_job.hmat = "ZrinZrH"
  this_job.mat =  4025
  this_job.zaid = "0000400"
  this_job.temperatures = ( 296., 400., 500., 600., 700., 800., 1000., 1200.)
  this_job.evaluationFile = this_job.evaluationDir + "n-040_Zr_090.endf"
  this_job.scatteringLaw = this_job.ScatteringLawDir +  "tsl-ZrinZrH.endf"
  this_job.scatteringMat = 58
  njoy_jobs.append(this_job)

  this_job = copy.deepcopy(job_ref_tsl)
  this_job.hmat = "Graphite10Porosity"
  this_job.mat = 600
  this_job.zaid = "0000061"
  this_job.temperatures = ( 296., 400., 500., 600., 700., 800., 1000., 1200., 1600., 2000.)
  this_job.evaluationFile = this_job.evaluationDir + "n-006_C_012.endf"
  this_job.scatteringLaw = this_job.ScatteringLawDir + "tsl-reactor-graphite-10P.endf"
  this_job.scatteringMat = 31
  njoy_jobs.append(this_job)

  # this_job = copy.deepcopy(job_ref_tsl)
  # this_job.hmat = "Graphite20Porosity"
  # this_job.mat = 600
  # this_job.temperatures = ( 296., 400., 500., 600., 700., 800., 1000., 1200., 1600., 2000.)
  # this_job.evaluationFile = this_job.evaluationDir + "n-006_C_012.endf"
  # this_job.scatteringLaw = this_job.ScatteringLawDir + "tsl-reactor-graphite-20P.endf"
  # this_job.scatteringMat = 31
  # njoy_jobs.append(this_job)

  this_job = copy.deepcopy(job_ref_tsl)
  this_job.hmat = "Graphite30Porosity"
  this_job.mat = 600
  this_job.zaid = "0000063"
  this_job.temperatures = ( 296., 400., 500., 600., 700., 800., 1000., 1200., 1600., 2000.)
  this_job.evaluationFile = this_job.evaluationDir + "n-006_C_012.endf"
  this_job.scatteringLaw = this_job.ScatteringLawDir + "tsl-reactor-graphite-30P.endf"
  this_job.scatteringMat = 32
  njoy_jobs.append(this_job)

  this_job = copy.deepcopy(job_ref_tsl)
  this_job.hmat = "CinSiC"
  this_job.mat = 600
  this_job.zaid = "0000064"
  this_job.temperatures = (300, 400, 500, 600, 700, 800, 1000, 1200)
  this_job.evaluationFile = this_job.evaluationDir + "n-006_C_012.endf"
  this_job.scatteringLaw = this_job.ScatteringLawDir +  "tsl-CinSiC.endf"
  this_job.scatteringMat = 44
  njoy_jobs.append(this_job)

  this_job = copy.deepcopy(job_ref_tsl)
  this_job.hmat = "BeMetal"
  this_job.mat = 425
  this_job.zaid = "0000040"
  this_job.temperatures = ( 296., 400., 500., 600., 700., 800., 1000., 1200.)
  this_job.evaluationFile = this_job.evaluationDir + "n-004_Be_009.endf"
  this_job.scatteringLaw = this_job.ScatteringLawDir +  "tsl-Be-metal.endf"
  this_job.scatteringMat = 26
  njoy_jobs.append(this_job)

  this_job = copy.deepcopy(job_ref_tsl)
  this_job.hmat = "BeinBeO"
  this_job.mat = 425
  this_job.zaid = "0000041"
  this_job.temperatures = ( 293.6, 400., 500., 600., 700., 800., 1000., 1200.)
  this_job.evaluationFile = this_job.evaluationDir + "n-004_Be_009.endf"
  this_job.scatteringLaw = this_job.ScatteringLawDir +  "tsl-BeinBeO.endf"
  this_job.scatteringMat = 27
  njoy_jobs.append(this_job)

  this_job = copy.deepcopy(job_ref_tsl)
  this_job.hmat = "NinUN"
  this_job.mat = 725
  this_job.zaid = "0000070"
  this_job.temperatures = ( 296, 400., 500., 600., 700., 800., 1000., 1200.)
  this_job.evaluationFile = this_job.evaluationDir + "n-007_N_014.endf"
  this_job.scatteringLaw = this_job.ScatteringLawDir +  "tsl-NinUN.endf"
  this_job.scatteringMat = 71
  njoy_jobs.append(this_job)

  this_job = copy.deepcopy(job_ref_tsl)
  this_job.hmat = "AlMetal"
  this_job.mat = 1325
  this_job.zaid = "0000130"
  this_job.temperatures = ( 20, 80, 293.6, 400, 600, 800)
  this_job.evaluationFile = this_job.evaluationDir + "n-013_Al_027.endf"
  this_job.scatteringLaw = this_job.ScatteringLawDir +  "tsl-013_Al_027.endf"
  this_job.scatteringMat = 53 #45
  njoy_jobs.append(this_job)

  this_job = copy.deepcopy(job_ref_tsl)
  this_job.hmat = "FeMetal"
  this_job.mat = 2631
  this_job.zaid = "0000260"
  this_job.temperatures = ( 20, 80, 293.6, 400, 600, 800)
  this_job.evaluationFile = this_job.evaluationDir + "n-026_Fe_056.endf"
  this_job.scatteringLaw = this_job.ScatteringLawDir +  "tsl-026_Fe_056.endf"
  this_job.scatteringMat = 56
  njoy_jobs.append(this_job)

  this_job = copy.deepcopy(job_ref_tsl)
  this_job.hmat = "OinBeO"
  this_job.mat = 825
  this_job.zaid = "0000081"
  this_job.temperatures = (293.6, 400, 500, 600, 700, 800, 1000, 1200)
  this_job.evaluationFile = this_job.evaluationDir + "n-008_O_016.endf"
  this_job.scatteringLaw = this_job.ScatteringLawDir +  "tsl-OinBeO.endf"
  this_job.scatteringMat = 46 #28
  njoy_jobs.append(this_job)

  this_job = copy.deepcopy(job_ref_tsl)
  this_job.hmat = "OinUO2"
  this_job.mat = 825
  this_job.zaid = "0000080"
  this_job.temperatures = (296, 400, 500, 600, 700, 800, 1000, 1200)
  this_job.evaluationFile = this_job.evaluationDir + "n-008_O_016.endf"
  this_job.scatteringLaw = this_job.ScatteringLawDir +  "tsl-OinUO2.endf"
  this_job.scatteringMat = 75
  njoy_jobs.append(this_job)

  this_job = copy.deepcopy(job_ref_tsl)
  this_job.hmat = "SiinC"
  this_job.mat = 1425
  this_job.zaid = "0000140"
  this_job.temperatures = (300, 400, 500, 600, 700, 800, 1000, 1200)
  this_job.evaluationFile = this_job.evaluationDir + "n-014_Si_028.endf"
  this_job.scatteringLaw = this_job.ScatteringLawDir +  "tsl-SiinSiC.endf"
  this_job.scatteringMat = 43
  njoy_jobs.append(this_job)

  this_job = copy.deepcopy(job_ref_tsl)
  this_job.hmat = "SiO2Alpha"
  this_job.mat = 1425
  this_job.zaid = "0000141"
  this_job.temperatures = (293.6, 350, 400, 500, 800)
  this_job.evaluationFile = this_job.evaluationDir + "n-014_Si_028.endf"
  this_job.scatteringLaw = this_job.ScatteringLawDir +  "tsl-SiO2-alpha.endf"
  this_job.scatteringMat = 47
  njoy_jobs.append(this_job)

  this_job = copy.deepcopy(job_ref_tsl)
  this_job.hmat = "SiO2Beta"
  this_job.mat = 1425
  this_job.zaid = "0000142"
  this_job.temperatures = (1000, 1100)
  this_job.evaluationFile = this_job.evaluationDir + "n-014_Si_028.endf"
  this_job.scatteringLaw = this_job.ScatteringLawDir +  "tsl-SiO2-beta.endf"
  this_job.scatteringMat = 49
  njoy_jobs.append(this_job)

  this_job = copy.deepcopy(job_ref_tsl)
  this_job.hmat = "YinYH2"
  this_job.mat = 3925
  this_job.zaid = "0000390"
  this_job.temperatures = (293.6, 400, 500, 600, 700, 800, 1000, 1200, 1400, 1600)
  this_job.evaluationFile = this_job.evaluationDir + "n-039_Y_089.endf"
  this_job.scatteringLaw = this_job.ScatteringLawDir +  "tsl-YinYH2.endf"
  this_job.scatteringMat = 55
  njoy_jobs.append(this_job)

  #
  # need to address error in thermr
  # ***error in findf*** mat  75 mf 7 mt  0 not on tape  28
  # this_job = copy.deepcopy(job_ref_tsl)
  # this_job.hmat = "UinUO2"
  # this_job.mat = 9237
  # this_job.temperatures = (296, 400, 500, 600, 700, 800, 1000, 1200)
  # this_job.evaluationFile = this_job.evaluationDir + "n-092_U_238.endf"
  # this_job.scatteringLaw = this_job.ScatteringLawDir +  "tsl-UinUO2.endf"
  # this_job.scatteringMat = 75 
  # njoy_jobs.append(this_job)


  this_job = copy.deepcopy(job_ref_tsl)
  this_job.hmat = "UinUN"
  this_job.mat = 9237
  this_job.zaid = "0000920"
  this_job.temperatures = ( 296, 400., 500., 600., 700., 800., 1000., 1200.)
  this_job.evaluationFile = this_job.evaluationDir + "n-092_U_238.endf"
  this_job.scatteringLaw = this_job.ScatteringLawDir +  "tsl-UinUN.endf"
  this_job.scatteringMat = 72
  njoy_jobs.append(this_job)

  print('Number of jobs from isotopes with thermal scattering: '+ str(len(njoy_jobs)))

  #############################################################################
  #  nominal isotopes
  #############################################################################
  c1 = len(njoy_jobs)
  job_ref_nom = copy.deepcopy(job_ref)
  # General options
  # Specifics for output library format

  iso_dict = OrderedDict()
  iso_dict["H1"] = (125, "0010010", "n-001_H_001.endf")
  iso_dict["H2"] = (128, "0010020", "n-001_H_002.endf")
  iso_dict["H3"] = (131, "0010030", "n-001_H_003.endf")
  iso_dict["He3"] = (225, "0020030", "n-002_He_003.endf")
  iso_dict["He4"] = (228, "0020040", "n-002_He_004.endf")
  iso_dict["Li6"] = (325, "0030060", "n-003_Li_006.endf")
  iso_dict["Li7"] = (328, "0030070", "n-003_Li_007.endf")
  iso_dict["Be7"] = (419, "0040070", "n-004_Be_007.endf")
  iso_dict["B10"] = (525, "0050100", "n-005_B_010.endf")
  iso_dict["B11"] = (528, "0050110", "n-005_B_011.endf")
  iso_dict["C12"] = (625, "0060120", "n-006_C_012.endf")
  iso_dict["C13"] = (628, "0060130", "n-006_C_013.endf")
  iso_dict["N14"] = (725, "0070140", "n-007_N_014.endf")
  iso_dict["N15"] = (728, "0070150", "n-007_N_015.endf")
  iso_dict["O16"] = (825, "0080160", "n-008_O_016.endf")
  iso_dict["O17"] = (828, "0080170", "n-008_O_017.endf")
  iso_dict["O18"] = (831, "0080180", "n-008_O_018.endf")
  iso_dict["F19"] = (925, "0090190", "n-009_F_019.endf")
  iso_dict["Ne20"] = (1025, "0100200", "n-010_Ne_020.endf")
  iso_dict["Ne21"] = (1028, "0100210", "n-010_Ne_021.endf")
  iso_dict["Ne22"] = (1031, "0100220", "n-010_Ne_022.endf")
  iso_dict["Na22"] = (1122, "0110220", "n-011_Na_022.endf")
  iso_dict["Na23"] = (1125, "0110230", "n-011_Na_023.endf")
  iso_dict["Mg24"] = (1225, "0120240", "n-012_Mg_024.endf")
  iso_dict["Mg25"] = (1228, "0120250", "n-012_Mg_025.endf")
  iso_dict["Mg26"] = (1231, "0120260", "n-012_Mg_026.endf")
  iso_dict["Al26M"] = (1323, "0130261", "n-013_Al_026m1.endf")
  iso_dict["Al27"] = (1325, "0130270", "n-013_Al_027.endf")
  iso_dict["Si28"] = (1425, "0140280", "n-014_Si_028.endf")
  iso_dict["Si29"] = (1428, "0140290", "n-014_Si_029.endf")
  iso_dict["Si30"] = (1431, "0140300", "n-014_Si_030.endf")
  iso_dict["Si31"] = (1434, "0140310", "n-014_Si_031.endf")
  iso_dict["Si32"] = (1437, "0140320", "n-014_Si_032.endf")
  iso_dict["P31"] = (1525, "0150310", "n-015_P_031.endf")
  iso_dict["S32"] = (1625, "0160320", "n-016_S_032.endf")
  iso_dict["S33"] = (1628, "0160330", "n-016_S_033.endf")
  iso_dict["S34"] = (1631, "0160340", "n-016_S_034.endf")
  iso_dict["S35"] = (1634, "0160350", "n-016_S_035.endf")
  iso_dict["S36"] = (1637, "0160360", "n-016_S_036.endf")
  iso_dict["Cl35"] = (1725, "0170350", "n-017_Cl_035.endf")
  iso_dict["Cl36"] = (1728, "0170360", "n-017_Cl_036.endf")
  iso_dict["Cl37"] = (1731, "0170370", "n-017_Cl_037.endf")
  iso_dict["Ar36"] = (1825, "0180360", "n-018_Ar_036.endf")
  iso_dict["Ar37"] = (1828, "0180370", "n-018_Ar_037.endf")
  iso_dict["Ar38"] = (1831, "0180380", "n-018_Ar_038.endf")
  iso_dict["Ar39"] = (1834, "0180390", "n-018_Ar_039.endf")
  iso_dict["Ar40"] = (1837, "0180400", "n-018_Ar_040.endf")
  iso_dict["Ar41"] = (1840, "0180410", "n-018_Ar_041.endf")
  iso_dict["K39"] = (1925, "0190390", "n-019_K_039.endf")
  iso_dict["K40"] = (1928, "0190400", "n-019_K_040.endf")
  iso_dict["K41"] = (1931, "0190410", "n-019_K_041.endf")
  iso_dict["Ca40"] = (2025, "0200400", "n-020_Ca_040.endf")
  iso_dict["Ca41"] = (2028, "0200410", "n-020_Ca_041.endf")
  iso_dict["Ca42"] = (2031, "0200420", "n-020_Ca_042.endf")
  iso_dict["Ca43"] = (2034, "0200430", "n-020_Ca_043.endf")
  iso_dict["Ca44"] = (2037, "0200440", "n-020_Ca_044.endf")
  iso_dict["Ca45"] = (2040, "0200450", "n-020_Ca_045.endf")
  iso_dict["Ca46"] = (2043, "0200460", "n-020_Ca_046.endf")
  iso_dict["Ca47"] = (2046, "0200470", "n-020_Ca_047.endf")
  iso_dict["Ca48"] = (2049, "0200480", "n-020_Ca_048.endf")
  iso_dict["Ti46"] = (2225, "0220460", "n-022_Ti_046.endf")
  iso_dict["Ti47"] = (2228, "0220470", "n-022_Ti_047.endf")
  iso_dict["Ti48"] = (2231, "0220480", "n-022_Ti_048.endf")
  iso_dict["Ti49"] = (2234, "0220490", "n-022_Ti_049.endf")
  iso_dict["Ti50"] = (2237, "0220500", "n-022_Ti_050.endf")
  iso_dict["V50"] = (2325, "0230500", "n-023_V_050.endf")
  iso_dict["V51"] = (2328, "0230510", "n-023_V_051.endf")
  iso_dict["V49"] = (2322, "0230490", "n-023_V_049.endf")
  iso_dict["Cr50"] = (2425, "0240500", "n-024_Cr_050.endf")
  iso_dict["Cr51"] = (2428, "0240510", "n-024_Cr_051.endf")
  iso_dict["Cr52"] = (2431, "0240520", "n-024_Cr_052.endf")
  iso_dict["Cr53"] = (2434, "0240530", "n-024_Cr_053.endf")
  iso_dict["Cr54"] = (2437, "0240540", "n-024_Cr_054.endf")
  iso_dict["Mn54"] = (2522, "0250540", "n-025_Mn_054.endf")
  iso_dict["Mn55"] = (2525, "0250550", "n-025_Mn_055.endf")
  iso_dict["Fe54"] = (2625, "0260540", "n-026_Fe_054.endf")
  iso_dict["Fe55"] = (2628, "0260550", "n-026_Fe_055.endf")
  iso_dict["Fe56"] = (2631, "0260560", "n-026_Fe_056.endf")
  iso_dict["Fe57"] = (2634, "0260570", "n-026_Fe_057.endf")
  iso_dict["Fe58"] = (2637, "0260580", "n-026_Fe_058.endf")
  iso_dict["Co59"] = (2725, "0270590", "n-027_Co_059.endf")
  iso_dict["Ni58"] = (2825, "0280580", "n-028_Ni_058.endf")
  iso_dict["Ni60"] = (2831, "0280600", "n-028_Ni_060.endf")
  iso_dict["Ni61"] = (2834, "0280610", "n-028_Ni_061.endf")
  iso_dict["Ni62"] = (2837, "0280620", "n-028_Ni_062.endf")
  iso_dict["Ni63"] = (2840, "0280630", "n-028_Ni_063.endf")
  iso_dict["Ni64"] = (2843, "0280640", "n-028_Ni_064.endf")
  iso_dict["Cu63"] = (2925, "0290630", "n-029_Cu_063.endf")
  iso_dict["Cu64"] = (2928, "0290640", "n-029_Cu_064.endf")
  iso_dict["Cu65"] = (2931, "0290650", "n-029_Cu_065.endf")
  iso_dict["Zn66"] = (3031, "0300660", "n-030_Zn_066.endf")
  iso_dict["Zn67"] = (3034, "0300670", "n-030_Zn_067.endf")
  iso_dict["Zn68"] = (3037, "0300680", "n-030_Zn_068.endf")
  iso_dict["Zn69"] = (3040, "0300690", "n-030_Zn_069.endf")
  iso_dict["Zn70"] = (3043, "0300700", "n-030_Zn_070.endf")
  iso_dict["Ga69"] = (3125, "0310690", "n-031_Ga_069.endf")
  iso_dict["Ga70"] = (3128, "0310700", "n-031_Ga_070.endf")
  iso_dict["Ga71"] = (3131, "0310710", "n-031_Ga_071.endf")
  iso_dict["W182"] = (7431, "0741820", "n-074_W_182.endf")
  iso_dict["W183"] = (7434, "0741830", "n-074_W_183.endf")
  iso_dict["W184"] = (7437, "0741840", "n-074_W_184.endf")
  iso_dict["W186"] = (7443, "0741860", "n-074_W_186.endf")
  iso_dict["Pb204"] = (8225, "0822040", "n-082_Pb_204.endf")
  iso_dict["Pb206"] = (8231, "0822060", "n-082_Pb_206.endf")
  iso_dict["Pb207"] = (8234, "0822070", "n-082_Pb_207.endf")
  iso_dict["Pb208"] = (8237, "0822080", "n-082_Pb_208.endf")
  iso_dict["Bi209"] = (8325, "0832090", "n-083_Bi_209.endf")

  for iso_name, tup in iso_dict.items():
    this_job = copy.deepcopy(job_ref_nom)
    this_job.hmat = iso_name
    this_job.mat = tup[0]
    this_job.zaid = tup[1]
    this_job.evaluationFile = this_job.evaluationDir + tup[2]
    if iso_name == "Na22":
      this_job.dilutions = None
    njoy_jobs.append(this_job)

  print('Number of jobs from nominal isotopes: '+ str(len(njoy_jobs) - c1))

  #############################################################################
  #  fissionable isotopes
  #############################################################################
  c1 = len(njoy_jobs)
  job_ref_fiss = copy.deepcopy(job_ref)
  # General options
  # Specifics for output library format

  this_job = copy.deepcopy(job_ref_fiss)
  this_job.hmat = "Th230"
  this_job.mat = 9034
  this_job.zaid = "0902300"
  this_job.evaluationFile = this_job.evaluationDir + "n-090_Th_230.endf"
  this_job.fission = 1 # fission without delayed neutrons
  #this_job.ss = (22.53556, 3.206464e5)
  this_job.dilutions = ( 1.e10, 10000.0, 3549.18335, 1259.67004, 447.079956, \
    158.676849, 56.3173141, 19.9880447, 7.09412289, 2.51783395 )
  njoy_jobs.append(this_job)

  this_job = copy.deepcopy(job_ref_fiss)
  this_job.hmat = "Th232"
  this_job.mat = 9040
  this_job.zaid = "0902320"
  this_job.evaluationFile = this_job.evaluationDir + "n-090_Th_232.endf"
  this_job.fission = 2 # fission with delayed neutrons
  this_job.dilutions = ( 1.e10, 10000.0, 5957.50244, 3549.18335, 2114.42676, \
    1259.67004, 750.448669, 447.079956, 266.347961, 158.676849, 94.5317612, \
    56.3173141, 33.5510521, 19.9880447, 11.9078817, 7.09412289, 4.22632504, \
    2.51783395, 1.5 )
  njoy_jobs.append(this_job)

  this_job = copy.deepcopy(job_ref_fiss)
  this_job.hmat = "Pa231"
  this_job.mat = 9131
  this_job.zaid = "0912310"
  this_job.evaluationFile = this_job.evaluationDir + "n-091_Pa_231.endf"
  this_job.fission = 1 # fission without delayed neutrons
  this_job.dilutions = ( 1.e10, 10000.0, 3549.18335, 1259.67004, 447.079956, \
    158.676849, 56.3173141, 19.9880447, 7.09412289, 2.51783395 )
  njoy_jobs.append(this_job)

  this_job = copy.deepcopy(job_ref_fiss)
  this_job.hmat = "Pa233"
  this_job.mat = 9137
  this_job.zaid = "0912330"
  this_job.evaluationFile = this_job.evaluationDir + "n-091_Pa_233.endf"
  this_job.fission = 1 # fission without delayed neutrons
  #this_job.ss = (22.53556, 3.206464e5)
  this_job.dilutions = ( 1.e10, 10000.0, 3549.18335, 1259.67004, 447.079956, \
    158.676849, 56.3173141, 19.9880447, 7.09412289, 2.51783395 )
  njoy_jobs.append(this_job)

  this_job = copy.deepcopy(job_ref_fiss)
  this_job.hmat = "U232"
  this_job.mat = 9219
  this_job.zaid = "0922320"
  this_job.evaluationFile = this_job.evaluationDir + "n-092_U_232.endf"
  this_job.fission = 1 # fission without delayed neutrons
  this_job.dilutions = ( 1.e10, 10000.0, 3549.18335, 1259.67004, 447.079956, \
    158.676849, 56.3173141, 19.9880447, 7.09412289, 2.51783395 )
  njoy_jobs.append(this_job)

  this_job = copy.deepcopy(job_ref_fiss)
  this_job.hmat = "U233"
  this_job.mat = 9222
  this_job.zaid = "0922330"
  this_job.evaluationFile = this_job.evaluationDir + "n-092_U_233.endf"
  this_job.fission = 2 # fission with delayed neutrons
  this_job.dilutions = ( 1.e10, 10000.0, 3549.18335, 1259.67004, 447.079956, \
    158.676849, 56.3173141, 19.9880447, 7.09412289, 2.51783395 )
  njoy_jobs.append(this_job)

  this_job = copy.deepcopy(job_ref_fiss)
  this_job.hmat = "U234"
  this_job.mat = 9225
  this_job.zaid = "0922340"
  this_job.evaluationFile = this_job.evaluationDir + "n-092_U_234.endf"
  this_job.fission = 1 # fission without delayed neutrons
  this_job.dilutions = ( 1.e10, 10000.0, 3549.18335, 1259.67004, 447.079956, \
    158.676849, 56.3173141, 19.9880447, 7.09412289, 2.51783395 )
  njoy_jobs.append(this_job)

  this_job = copy.deepcopy(job_ref_fiss)
  this_job.hmat = "U235"
  this_job.mat = 9228
  this_job.zaid = "0922350"
  this_job.evaluationFile = this_job.evaluationDir + "n-092_U_235.endf"
  this_job.fission = 2 # fission with delayed neutrons
  this_job.dilutions = ( 1.e10, 10000.0, 5957.50244, 3549.18335, 2114.42676, \
    1259.67004, 750.448669, 447.079956, 266.347961, 158.676849, 94.5317612, \
    56.3173141, 33.5510521, 19.9880447, 11.9078817, 7.09412289, 4.22632504, \
    2.51783395, 1.5 )
  njoy_jobs.append(this_job)

  this_job = copy.deepcopy(job_ref_fiss)
  this_job.hmat = "U236"
  this_job.mat = 9231
  this_job.zaid = "0922360"
  this_job.evaluationFile = this_job.evaluationDir + "n-092_U_236.endf"
  this_job.fission = 1 # fission without delayed neutrons
  this_job.dilutions = ( 1.e10, 10000.0, 3549.18335, 1259.67004, 447.079956, \
    158.676849, 56.3173141, 19.9880447, 7.09412289, 2.51783395 )
  njoy_jobs.append(this_job)

  this_job = copy.deepcopy(job_ref_fiss)
  this_job.hmat = "U237"
  this_job.mat = 9234
  this_job.zaid = "0922370"
  this_job.evaluationFile = this_job.evaluationDir + "n-092_U_237.endf"
  this_job.fission = 1 # fission without delayed neutrons
  this_job.dilutions = ( 1.e10, 10000.0, 3549.18335, 1259.67004, 447.079956, \
    158.676849, 56.3173141, 19.9880447, 7.09412289, 2.51783395 )
  njoy_jobs.append(this_job)

  this_job = copy.deepcopy(job_ref_fiss)
  this_job.hmat = "U238"
  this_job.mat = 9237
  this_job.zaid = "0922380"
  this_job.evaluationFile = this_job.evaluationDir + "n-092_U_238.endf"
  this_job.fission = 2 # fission with delayed neutrons
  this_job.dilutions = ( 1.e10, 10000.0, 5957.50244, 3549.18335, 2114.42676, \
    1259.67004, 750.448669, 447.079956, 266.347961, 158.676849, 94.5317612, \
    56.3173141, 33.5510521, 19.9880447, 11.9078817, 7.09412289, 4.22632504, \
    2.51783395, 1.5 )
  njoy_jobs.append(this_job)

  this_job = copy.deepcopy(job_ref_fiss)
  this_job.hmat = "Np236"
  this_job.mat = 9343
  this_job.zaid = "0932360"
  this_job.evaluationFile = this_job.evaluationDir + "n-093_Np_236.endf"
  this_job.fission = 1 # fission without delayed neutrons
  this_job.dilutions = ( 1.e10, 10000.0, 3549.18335, 1259.67004, 447.079956, \
    158.676849, 56.3173141, 19.9880447, 7.09412289, 2.51783395 )
  njoy_jobs.append(this_job)

  this_job = copy.deepcopy(job_ref_fiss)
  this_job.hmat = "Np237"
  this_job.mat = 9346
  this_job.zaid = "0932370"
  this_job.evaluationFile = this_job.evaluationDir + "n-093_Np_237.endf"
  this_job.fission = 1 # fission without delayed neutrons
  this_job.dilutions = ( 1.e10, 10000.0, 3549.18335, 1259.67004, 447.079956, \
    158.676849, 56.3173141, 19.9880447, 7.09412289, 2.51783395 )
  njoy_jobs.append(this_job)

  this_job = copy.deepcopy(job_ref_fiss)
  this_job.hmat = "Np238"
  this_job.mat = 9349
  this_job.zaid = "0932380"
  this_job.evaluationFile = this_job.evaluationDir + "n-093_Np_238.endf"
  this_job.fission = 1 # fission without delayed neutrons
  this_job.dilutions = ( 1.e10, 10000.0, 3549.18335, 1259.67004, 447.079956, \
    158.676849, 56.3173141 )
  njoy_jobs.append(this_job)

  this_job = copy.deepcopy(job_ref_fiss)
  this_job.hmat = "Np239"
  this_job.mat = 9352
  this_job.zaid = "0932390"
  this_job.evaluationFile = this_job.evaluationDir + "n-093_Np_239.endf"
  this_job.fission = 1 # fission without delayed neutrons
  this_job.dilutions = ( 1.e10, 10000.0, 3549.18335, 1259.67004, 447.079956, \
    158.676849, 56.3173141, 19.9880447, 7.09412289, 2.51783395 )
  njoy_jobs.append(this_job)

  this_job = copy.deepcopy(job_ref_fiss)
  this_job.hmat = "Pu236"
  this_job.mat = 9428
  this_job.zaid = "0942360"
  this_job.evaluationFile = this_job.evaluationDir + "n-094_Pu_236.endf"
  this_job.fission = 1 # fission without delayed neutrons
  #this_job.ss = (22.53556, 3.206464e5)
  this_job.dilutions = ( 1.e10, 10000.0, 3549.18335, 1259.67004, 447.079956, \
    158.676849, 56.3173141, 19.9880447, 7.09412289, 2.51783395 )
  njoy_jobs.append(this_job)

  this_job = copy.deepcopy(job_ref_fiss)
  this_job.hmat = "Pu237"
  this_job.mat = 9431
  this_job.zaid = "0942370"
  this_job.evaluationFile = this_job.evaluationDir + "n-094_Pu_237.endf"
  this_job.fission = 1 # fission without delayed neutrons
  this_job.dilutions = ( 1.e10, 10000.0, 3549.18335, 1259.67004, 447.079956, \
    158.676849, 56.3173141, 19.9880447, 7.09412289, 2.51783395 )
  njoy_jobs.append(this_job)

  this_job = copy.deepcopy(job_ref_fiss)
  this_job.hmat = "Pu238"
  this_job.mat = 9434
  this_job.zaid = "0942380"
  this_job.evaluationFile = this_job.evaluationDir + "n-094_Pu_238.endf"
  this_job.fission = 1 # fission without delayed neutrons
  this_job.dilutions = ( 1.e10, 10000.0, 5957.50244, 3549.18335, 2114.42676, \
    1259.67004, 750.448669, 447.079956, 266.347961, 158.676849, 94.5317612, \
    56.3173141, 33.5510521, 19.9880447, 11.9078817, 7.09412289, 4.22632504, \
    2.51783395, 1.5 )
  njoy_jobs.append(this_job)

  this_job = copy.deepcopy(job_ref_fiss)
  this_job.hmat = "Pu239"
  this_job.mat = 9437
  this_job.zaid = "0942390"
  this_job.evaluationFile = this_job.evaluationDir + "n-094_Pu_239.endf"
  this_job.fission = 2 # fission with delayed neutrons
  this_job.dilutions = ( 1.e10, 10000.0, 6311.33494, 3983.29436, 2513.99016, \
    1586.66319, 1001.39615, 632.014573, 398.885514, 251.749976, 158.887822, \
    100.279413, 63.2896882, 39.9442369, 25.2101426, 15.9109633, 10.0419406, \
    6.33780423, 4.0 )
  njoy_jobs.append(this_job)

  this_job = copy.deepcopy(job_ref_fiss)
  this_job.hmat = "Pu240"
  this_job.mat = 9440
  this_job.zaid = "0942400"
  this_job.evaluationFile = this_job.evaluationDir + "n-094_Pu_240.endf"
  this_job.fission = 2 # fission with delayed neutrons
  this_job.dilutions = ( 1.e10, 10000.0, 5957.50244, 3549.18335, 2114.42676, \
    1259.67004, 750.448669, 447.079956, 266.347961, 158.676849, 94.5317612, \
    56.3173141, 33.5510521, 19.9880447, 11.9078817, 7.09412289, 4.22632504, \
    2.51783395, 1.5 )
  njoy_jobs.append(this_job)

  this_job = copy.deepcopy(job_ref_fiss)
  this_job.hmat = "Pu241"
  this_job.mat = 9443
  this_job.zaid = "0942410"
  this_job.evaluationFile = this_job.evaluationDir + "n-094_Pu_241.endf"
  this_job.fission = 2 # fission with delayed neutrons
  this_job.dilutions = ( 1.e10, 10000.0, 5957.50244, 3549.18335, 2114.42676, \
    1259.67004, 750.448669, 447.079956, 266.347961, 158.676849, 94.5317612, \
    56.3173141, 33.5510521, 19.9880447, 11.9078817, 7.09412289, 4.22632504, \
    2.51783395, 1.5 )
  njoy_jobs.append(this_job)

  this_job = copy.deepcopy(job_ref_fiss)
  this_job.hmat = "Pu242"
  this_job.mat = 9446
  this_job.zaid = "0942420"
  this_job.evaluationFile = this_job.evaluationDir + "n-094_Pu_242.endf"
  this_job.fission = 1 # fission without delayed neutrons
  this_job.dilutions = ( 1.e10, 1.e5, 55118.5161, 30380.5178, 16745.2959, \
    9229.76155, 5087.30922, 2804.05024, 1545.55137, 851.885253,  469.546659, \
    258.807233, 142.650752, 78.6270025, 43.3380508, 23.8872981, 13.1663284, \
    7.25708715, 4.0 )
  njoy_jobs.append(this_job)

  this_job = copy.deepcopy(job_ref_fiss)
  this_job.hmat = "Pu243"
  this_job.mat = 9449
  this_job.zaid = "0942430"
  this_job.evaluationFile = this_job.evaluationDir + "n-094_Pu_243.endf"
  this_job.fission = 1 # fission without delayed neutrons
  this_job.dilutions = ( 1.e10, 10000.0, 3549.18335, 1259.67004, 447.079956, \
    158.676849, 56.3173141, 19.9880447, 7.09412289, 2.51783395 )
  njoy_jobs.append(this_job)

  this_job = copy.deepcopy(job_ref_fiss)
  this_job.hmat = "Pu244"
  this_job.mat = 9452
  this_job.zaid = "0942440"
  this_job.evaluationFile = this_job.evaluationDir + "n-094_Pu_244.endf"
  this_job.fission = 1 # fission without delayed neutrons
  this_job.dilutions = ( 1.e10, 10000.0, 3549.18335, 1259.67004, 447.079956, \
    158.676849, 56.3173141, 19.9880447, 7.09412289, 2.51783395 )
  njoy_jobs.append(this_job)

  this_job = copy.deepcopy(job_ref_fiss)
  this_job.hmat = "Am241"
  this_job.mat = 9543
  this_job.zaid = "0952410"
  this_job.evaluationFile = this_job.evaluationDir + "n-095_Am_241.endf"
  this_job.fission = 1 # fission without delayed neutrons
  this_job.dilutions = ( 1.e10, 10000.0, 5957.50244, 3549.18335, 2114.42676, \
    1259.67004, 750.448669, 447.079956, 266.347961, 158.676849, 94.5317612, \
    56.3173141, 33.5510521, 19.9880447, 11.9078817, 7.09412289, 4.22632504, \
    2.51783395, 1.5 )
  njoy_jobs.append(this_job)

  this_job = copy.deepcopy(job_ref_fiss)
  this_job.hmat = "Am242"
  this_job.mat = 9546
  this_job.zaid = "0952420"
  this_job.evaluationFile = this_job.evaluationDir + "n-095_Am_242.endf"
  this_job.fission = 0 # no fission matrix!!!
  this_job.dilutions = ( 1.e10, 10000.0, 3549.18335, 1259.67004, 447.079956, \
    158.676849, 56.3173141, 19.9880447, 7.09412289, 2.51783395 )
  njoy_jobs.append(this_job)

  this_job = copy.deepcopy(job_ref_fiss)
  this_job.hmat = "Am242M"
  this_job.mat = 9547
  this_job.zaid = "0952421"
  this_job.evaluationFile = this_job.evaluationDir + "n-095_Am_242m1.endf"
  this_job.fission = 1 # fission without delayed neutrons
  this_job.dilutions = ( 1.e10, 10000.0, 3549.18335, 1259.67004, 447.079956, \
    158.676849, 56.3173141 )
  njoy_jobs.append(this_job)

  this_job = copy.deepcopy(job_ref_fiss)
  this_job.hmat = "Am243"
  this_job.mat = 9549
  this_job.zaid = "0952430"
  this_job.evaluationFile = this_job.evaluationDir + "n-095_Am_243.endf"
  this_job.fission = 1 # fission without delayed neutrons
  this_job.dilutions = ( 1.e10, 10000.0, 3549.18335, 1259.67004, 447.079956, \
    158.676849, 56.3173141, 19.9880447, 7.09412289, 2.51783395 )
  njoy_jobs.append(this_job)

  this_job = copy.deepcopy(job_ref_fiss)
  this_job.hmat = "Cm241"
  this_job.mat = 9628
  this_job.zaid = "0962410"
  this_job.evaluationFile = this_job.evaluationDir + "n-096_Cm_241.endf"
  this_job.fission = 1 # fission without delayed neutrons
  this_job.dilutions = ( 1.e10, 10000.0, 3549.18335, 1259.67004, 447.079956, \
    158.676849, 56.3173141 )
  njoy_jobs.append(this_job)

  this_job = copy.deepcopy(job_ref_fiss)
  this_job.hmat = "Cm242"
  this_job.mat = 9631
  this_job.zaid = "0962420"
  this_job.evaluationFile = this_job.evaluationDir + "n-096_Cm_242.endf"
  this_job.fission = 1 # fission without delayed neutrons
  this_job.dilutions = ( 1.e10, 10000.0, 3549.18335, 1259.67004, 447.079956, \
    158.676849, 56.3173141 )
  njoy_jobs.append(this_job)

  this_job = copy.deepcopy(job_ref_fiss)
  this_job.hmat = "Cm243"
  this_job.mat = 9634
  this_job.zaid = "0962430"
  this_job.evaluationFile = this_job.evaluationDir + "n-096_Cm_243.endf"
  this_job.fission = 1 # fission without delayed neutrons
  this_job.dilutions = ( 1.e10, 10000.0, 3549.18335, 1259.67004, 447.079956, \
    158.676849, 56.3173141 )
  njoy_jobs.append(this_job)

  this_job = copy.deepcopy(job_ref_fiss)
  this_job.hmat = "Cm244"
  this_job.mat = 9637
  this_job.zaid = "0962440"
  this_job.evaluationFile = this_job.evaluationDir + "n-096_Cm_244.endf"
  this_job.fission = 1 # fission without delayed neutrons
  this_job.dilutions = ( 1.e10, 10000.0, 3549.18335, 1259.67004, 447.079956, \
    158.676849, 56.3173141 )
  njoy_jobs.append(this_job)

  this_job = copy.deepcopy(job_ref_fiss)
  this_job.hmat = "Cm245"
  this_job.mat = 9640
  this_job.zaid = "0962450"
  this_job.evaluationFile = this_job.evaluationDir + "n-096_Cm_245.endf"
  this_job.fission = 1 # fission without delayed neutrons
  this_job.dilutions = ( 1.e10, 10000.0, 3549.18335, 1259.67004, 447.079956, \
    158.676849, 56.3173141 )
  njoy_jobs.append(this_job)

  this_job = copy.deepcopy(job_ref_fiss)
  this_job.hmat = "Cm246"
  this_job.mat = 9643
  this_job.zaid = "0962460"
  this_job.evaluationFile = this_job.evaluationDir + "n-096_Cm_246.endf"
  this_job.fission = 1 # fission without delayed neutrons
  this_job.dilutions = ( 1.e10, 10000.0, 3549.18335, 1259.67004, 447.079956, \
    158.676849, 56.3173141 )
  njoy_jobs.append(this_job)

  this_job = copy.deepcopy(job_ref_fiss)
  this_job.hmat = "Cm247"
  this_job.mat = 9646
  this_job.zaid = "0962470"
  this_job.evaluationFile = this_job.evaluationDir + "n-096_Cm_247.endf"
  this_job.fission = 1 # fission without delayed neutrons
  this_job.dilutions = ( 1.e10, 10000.0, 3549.18335, 1259.67004, 447.079956, \
    158.676849, 56.3173141 )
  njoy_jobs.append(this_job)

  this_job = copy.deepcopy(job_ref_fiss)
  this_job.hmat = "Cm248"
  this_job.mat = 9649
  this_job.zaid = "0962480"
  this_job.evaluationFile = this_job.evaluationDir + "n-096_Cm_248.endf"
  this_job.fission = 1 # fission without delayed neutrons
  this_job.dilutions = ( 1.e10, 10000.0, 3549.18335, 1259.67004, 447.079956, \
    158.676849, 56.3173141 )
  njoy_jobs.append(this_job)

  this_job = copy.deepcopy(job_ref_fiss)
  this_job.hmat = "Bk249"
  this_job.mat = 9752
  this_job.zaid = "0972490"
  this_job.evaluationFile = this_job.evaluationDir + "n-097_Bk_249.endf"
  this_job.fission = 1 # fission without delayed neutrons
  this_job.dilutions = ( 1.e10, 10000.0, 3549.18335, 1259.67004, 447.079956, \
    158.676849, 56.3173141 )
  njoy_jobs.append(this_job)

  this_job = copy.deepcopy(job_ref_fiss)
  this_job.hmat = "Cf249"
  this_job.mat = 9852
  this_job.zaid = "0982490"
  this_job.evaluationFile = this_job.evaluationDir + "n-098_Cf_249.endf"
  this_job.fission = 1 # fission without delayed neutrons
  this_job.dilutions = ( 1.e10, 10000.0, 3549.18335, 1259.67004, 447.079956, \
    158.676849, 56.3173141 )
  njoy_jobs.append(this_job)

  this_job = copy.deepcopy(job_ref_fiss)
  this_job.hmat = "Cf250"
  this_job.mat = 9855
  this_job.zaid = "0982500"
  this_job.evaluationFile = this_job.evaluationDir + "n-098_Cf_250.endf"
  this_job.fission = 1 # fission without delayed neutrons
  this_job.dilutions = ( 1.e10, 10000.0, 3549.18335, 1259.67004, 447.079956, \
    158.676849, 56.3173141 )
  njoy_jobs.append(this_job)

  this_job = copy.deepcopy(job_ref_fiss)
  this_job.hmat = "Cf251"
  this_job.mat = 9858
  this_job.zaid = "0982510"
  this_job.evaluationFile = this_job.evaluationDir + "n-098_Cf_251.endf"
  this_job.fission = 1 # fission without delayed neutrons
  this_job.dilutions = ( 1.e10, 10000.0, 3549.18335, 1259.67004, 447.079956, \
    158.676849, 56.3173141 )
  njoy_jobs.append(this_job)

  this_job = copy.deepcopy(job_ref_fiss)
  this_job.hmat = "Cf252"
  this_job.mat = 9861
  this_job.zaid = "0982520"
  this_job.evaluationFile = this_job.evaluationDir + "n-098_Cf_252.endf"
  this_job.fission = 1 # fission without delayed neutrons
  this_job.dilutions = ( 1.e10, 10000.0, 3549.18335, 1259.67004, 447.079956, \
    158.676849, 56.3173141 )
  njoy_jobs.append(this_job)

  this_job = copy.deepcopy(job_ref_fiss)
  this_job.hmat = "Cf253"
  this_job.mat = 9864
  this_job.zaid = "0982530"
  this_job.evaluationFile = this_job.evaluationDir + "n-098_Cf_253.endf"
  this_job.fission = 1 # fission without delayed neutrons
  this_job.dilutions = ( 1.e10, 10000.0, 3549.18335, 1259.67004, 447.079956, \
    158.676849, 56.3173141 )
  njoy_jobs.append(this_job)

  # we will add the following fissionable isotopes with the standard dilution
  iso_dict.clear()
  iso_dict["Ac225"] = (8925, "0892250", "n-089_Ac_225.endf", 1)
  iso_dict["Ac226"] = (8928, "0892260", "n-089_Ac_226.endf", 1)
  iso_dict["Ac227"] = (8931, "0892270", "n-089_Ac_227.endf", 1)
  iso_dict["Th227"] = (9025, "0902270", "n-090_Th_227.endf", 2)
  iso_dict["Th228"] = (9028, "0902280", "n-090_Th_228.endf", 1)
  iso_dict["Th229"] = (9031, "0902290", "n-090_Th_229.endf", 2)
  iso_dict["Th231"] = (9037, "0902310", "n-090_Th_231.endf", 1)
  iso_dict["Th233"] = (9043, "0902330", "n-090_Th_233.endf", 1)
  iso_dict["Th234"] = (9046, "0902340", "n-090_Th_234.endf", 1)
  iso_dict["Pa229"] = (9125, "0912290", "n-091_Pa_229.endf", 1)
  iso_dict["Pa230"] = (9128, "0912300", "n-091_Pa_230.endf", 1)
  iso_dict["Pa232"] = (9134, "0912320", "n-091_Pa_232.endf", 1)
  iso_dict["U230"] = (9213, "0922300", "n-092_U_230.endf", 1)
  iso_dict["U231"] = (9216, "0922310", "n-092_U_231.endf", 1)
  iso_dict["U239"] = (9240, "0922390", "n-092_U_239.endf", 2)
  iso_dict["U240"] = (9243, "0922400", "n-092_U_240.endf", 2)
  iso_dict["U241"] = (9246, "0922410", "n-092_U_241.endf", 2)
  iso_dict["Np234"] = (9337, "0932340", "n-093_Np_234.endf", 1)
  iso_dict["Np235"] = (9340, "0932350", "n-093_Np_235.endf", 1)
  iso_dict["Np236M"] = (9344, "0932361", "n-093_Np_236m1.endf", 1)
  iso_dict["Pu245"] = (9455, "0942450", "n-094_Pu_245.endf", 1)
  iso_dict["Pu246"] = (9458, "0942460", "n-094_Pu_246.endf", 1)
  iso_dict["Am240"] = (9540, "0952400", "n-095_Am_240.endf", 1)
  iso_dict["Am244"] = (9552, "0952440", "n-095_Am_244.endf", 1)
  iso_dict["Am244M"] = (9553, "0952441", "n-095_Am_244m1.endf", 1)
  iso_dict["Cm240"] = (9625, "0962400", "n-096_Cm_240.endf", 1)
  iso_dict["Cm249"] = (9652, "0962490", "n-096_Cm_249.endf", 1)
  iso_dict["Cm250"] = (9655, "0962500", "n-096_Cm_250.endf", 1)
  iso_dict["Bk245"] = (9740, "0972450", "n-097_Bk_245.endf", 1)
  iso_dict["Bk246"] = (9743, "0972460", "n-097_Bk_246.endf", 1)
  iso_dict["Bk247"] = (9746, "0972470", "n-097_Bk_247.endf", 1)
  iso_dict["Bk248"] = (9749, "0972480", "n-097_Bk_248.endf", 1)
  iso_dict["Bk250"] = (9755, "0972500", "n-097_Bk_250.endf", 1)
  iso_dict["Cf254"] = (9867, "0982540", "n-098_Cf_254.endf", 1)
  iso_dict["Cf246"] = (9843, "0982460", "n-098_Cf_246.endf", 1)
  iso_dict["Cf247"] = (9846, "0982470", "n-098_Cf_247.endf", 1)
  iso_dict["Cf248"] = (9849, "0982480", "n-098_Cf_248.endf", 1)
  iso_dict["Es251"] = (9911, "0992510", "n-099_Es_251.endf", 1)
  iso_dict["Es252"] = (9912, "0992520", "n-099_Es_252.endf", 1)
  iso_dict["Es253"] = (9913, "0992530", "n-099_Es_253.endf", 1)
  iso_dict["Es254"] = (9914, "0992540", "n-099_Es_254.endf", 2)
  iso_dict["Es254M"] = (9915, "0992541", "n-099_Es_254m1.endf", 2)
  iso_dict["Es255"] = (9916, "0992550", "n-099_Es_255.endf", 1)
  iso_dict["Fm255"] = (9936, "1002550", "n-100_Fm_255.endf", 2)

  for iso_name, tup in iso_dict.items():
    this_job = copy.deepcopy(job_ref_fiss)
    this_job.hmat = iso_name
    this_job.mat = tup[0]
    this_job.zaid = tup[1]
    this_job.evaluationFile = this_job.evaluationDir + tup[2]
    this_job.fission = tup[2] # 1 fission 2 fission with delayed neutrons
    njoy_jobs.append(this_job)

  print('Number of jobs from fissionable isotopes: '+ str(len(njoy_jobs) - c1))

  #############################################################################
  #  fission products
  #############################################################################
  c1 = len(njoy_jobs)
  job_ref_fp = copy.deepcopy(job_ref)
  # General options
  job_ref_fp.legendre = 0
  # Specifics for output library format
  job_ref_fp.fp = 1

  iso_dict.clear()
  iso_dict["Sc45"] = (2125, "0210450", "n-021_Sc_045.endf")
  iso_dict["Co58M"] = (2723, "0270581", "n-027_Co_058m1.endf")
  iso_dict["Co58"] = (2722, "0270580", "n-027_Co_058.endf")
  iso_dict["Ni59"] = (2828, "0280590", "n-028_Ni_059.endf")
  iso_dict["Zn64"] = (3025, "0300640", "n-030_Zn_064.endf")
  iso_dict["Zn65"] = (3028, "0300650", "n-030_Zn_065.endf")
  iso_dict["Ge70"] = (3225, "0320700", "n-032_Ge_070.endf")
  iso_dict["Ge71"] = (3228, "0320710", "n-032_Ge_071.endf")
  iso_dict["Ge72"] = (3231, "0320720", "n-032_Ge_072.endf")
  iso_dict["Ge73"] = (3234, "0320730", "n-032_Ge_073.endf")
  iso_dict["Ge74"] = (3237, "0320740", "n-032_Ge_074.endf")
  iso_dict["Ge75"] = (3240, "0320750", "n-032_Ge_075.endf")
  iso_dict["Ge76"] = (3243, "0320760", "n-032_Ge_076.endf")
  iso_dict["As73"] = (3319, "0330730", "n-033_As_073.endf")
  iso_dict["As74"] = (3322, "0330740", "n-033_As_074.endf")
  iso_dict["As75"] = (3325, "0330750", "n-033_As_075.endf")
  iso_dict["Se74"] = (3425, "0340740", "n-034_Se_074.endf")
  iso_dict["Se75"] = (3428, "0340750", "n-034_Se_075.endf")
  iso_dict["Se76"] = (3431, "0340760", "n-034_Se_076.endf")
  iso_dict["Se77"] = (3434, "0340770", "n-034_Se_077.endf")
  iso_dict["Se78"] = (3437, "0340780", "n-034_Se_078.endf")
  iso_dict["Se79"] = (3440, "0340790", "n-034_Se_079.endf")
  iso_dict["Se80"] = (3443, "0340800", "n-034_Se_080.endf")
  iso_dict["Se81"] = (3446, "0340810", "n-034_Se_081.endf")
  iso_dict["Se82"] = (3449, "0340820", "n-034_Se_082.endf")
  iso_dict["Br79"] = (3525, "0350790", "n-035_Br_079.endf")
  iso_dict["Br80"] = (3528, "0350800", "n-035_Br_080.endf")
  iso_dict["Br81"] = (3531, "0350810", "n-035_Br_081.endf")
  iso_dict["Kr78"] = (3625, "0360780", "n-036_Kr_078.endf")
  iso_dict["Kr79"] = (3628, "0360790", "n-036_Kr_079.endf")
  iso_dict["Kr80"] = (3631, "0360800", "n-036_Kr_080.endf")
  iso_dict["Kr81"] = (3634, "0360810", "n-036_Kr_081.endf")
  iso_dict["Kr82"] = (3637, "0360820", "n-036_Kr_082.endf")
  iso_dict["Kr83"] = (3640, "0360830", "n-036_Kr_083.endf")
  iso_dict["Kr84"] = (3643, "0360840", "n-036_Kr_084.endf")
  iso_dict["Kr85"] = (3646, "0360850", "n-036_Kr_085.endf")
  iso_dict["Kr86"] = (3649, "0360860", "n-036_Kr_086.endf")
  iso_dict["Rb85"] = (3725, "0370850", "n-037_Rb_085.endf")
  iso_dict["Rb86"] = (3728, "0370860", "n-037_Rb_086.endf")
  iso_dict["Rb87"] = (3731, "0370870", "n-037_Rb_087.endf")
  iso_dict["Sr84"] = (3825, "0380840", "n-038_Sr_084.endf")
  iso_dict["Sr85"] = (3828, "0380850", "n-038_Sr_085.endf")
  iso_dict["Sr86"] = (3831, "0380860", "n-038_Sr_086.endf")
  iso_dict["Sr87"] = (3834, "0380870", "n-038_Sr_087.endf")
  iso_dict["Sr88"] = (3837, "0380880", "n-038_Sr_088.endf")
  iso_dict["Sr89"] = (3840, "0380890", "n-038_Sr_089.endf")
  iso_dict["Sr90"] = (3843, "0380900", "n-038_Sr_090.endf")
  iso_dict["Y89"] = (3925, "0390890", "n-039_Y_089.endf")
  iso_dict["Y90"] = (3928, "0390900", "n-039_Y_090.endf")
  iso_dict["Y91"] = (3931, "0390910", "n-039_Y_091.endf")
  iso_dict["Zr93"] = (4034, "0400930", "n-040_Zr_093.endf")
  iso_dict["Zr95"] = (4040, "0400950", "n-040_Zr_095.endf")
  iso_dict["Nb93"] = (4125, "0410930", "n-041_Nb_093.endf")
  iso_dict["Nb94"] = (4128, "0410940", "n-041_Nb_094.endf")
  iso_dict["Nb95"] = (4131, "0410950", "n-041_Nb_095.endf")
  iso_dict["Mo92"] = (4225, "0420920", "n-042_Mo_092.endf")
  iso_dict["Mo93"] = (4228, "0420930", "n-042_Mo_093.endf")
  iso_dict["Mo94"] = (4231, "0420940", "n-042_Mo_094.endf")
  iso_dict["Mo95"] = (4234, "0420950", "n-042_Mo_095.endf")
  iso_dict["Mo96"] = (4237, "0420960", "n-042_Mo_096.endf")
  iso_dict["Mo97"] = (4240, "0420970", "n-042_Mo_097.endf")
  iso_dict["Mo98"] = (4243, "0420980", "n-042_Mo_098.endf")
  iso_dict["Mo99"] = (4246, "0420990", "n-042_Mo_099.endf")
  iso_dict["Mo100"] = (4249, "0421000", "n-042_Mo_100.endf")
  iso_dict["Tc98"] = (4322, "0430980", "n-043_Tc_098.endf")
  iso_dict["Ru96"] = (4425, "0440960", "n-044_Ru_096.endf")
  iso_dict["Ru97"] = (4428, "0440970", "n-044_Ru_097.endf")
  iso_dict["Ru98"] = (4431, "0440980", "n-044_Ru_098.endf")
  iso_dict["Ru99"] = (4434, "0440990", "n-044_Ru_099.endf")
  iso_dict["Ru100"] = (4437, "0441000", "n-044_Ru_100.endf")
  iso_dict["Ru101"] = (4440, "0441010", "n-044_Ru_101.endf")
  iso_dict["Ru102"] = (4443, "0441020", "n-044_Ru_102.endf")
  iso_dict["Ru103"] = (4446, "0441030", "n-044_Ru_103.endf")
  iso_dict["Ru104"] = (4449, "0441040", "n-044_Ru_104.endf")
  iso_dict["Ru105"] = (4452, "0441050", "n-044_Ru_105.endf")
  iso_dict["Ru106"] = (4455, "0441060", "n-044_Ru_106.endf")
  iso_dict["Rh103"] = (4525, "0451030", "n-045_Rh_103.endf")
  iso_dict["Rh104"] = (4528, "0451040", "n-045_Rh_104.endf")
  iso_dict["Rh105"] = (4531, "0451050", "n-045_Rh_105.endf")
  iso_dict["Pd102"] = (4625, "0461020", "n-046_Pd_102.endf")
  iso_dict["Pd103"] = (4628, "0461030", "n-046_Pd_103.endf")
  iso_dict["Pd104"] = (4631, "0461040", "n-046_Pd_104.endf")
  iso_dict["Pd105"] = (4634, "0461050", "n-046_Pd_105.endf")
  iso_dict["Pd106"] = (4637, "0461060", "n-046_Pd_106.endf")
  iso_dict["Pd107"] = (4640, "0461070", "n-046_Pd_107.endf")
  iso_dict["Pd108"] = (4643, "0461080", "n-046_Pd_108.endf")
  iso_dict["Pd109"] = (4646, "0461090", "n-046_Pd_109.endf")
  iso_dict["Pd110"] = (4649, "0461100", "n-046_Pd_110.endf")
  iso_dict["Ag108"] = (4728, "0471080", "n-047_Ag_108.endf")
  iso_dict["Ag110M"] = (4735, "0471101", "n-047_Ag_110m1.endf")
  iso_dict["Ag111"] = (4737, "0471110", "n-047_Ag_111.endf")
  iso_dict["Ag112"] = (4740, "0471120", "n-047_Ag_112.endf")
  iso_dict["Ag113"] = (4743, "0471130", "n-047_Ag_113.endf")
  iso_dict["Ag114"] = (4746, "0471140", "n-047_Ag_114.endf")
  iso_dict["Ag115"] = (4749, "0471150", "n-047_Ag_115.endf")
  iso_dict["Ag116"] = (4752, "0471160", "n-047_Ag_116.endf")
  iso_dict["Ag117"] = (4755, "0471170", "n-047_Ag_117.endf")
  iso_dict["Ag118M"] = (4759, "0471181", "n-047_Ag_118m1.endf")
  iso_dict["Cd106"] = (4825, "0481060", "n-048_Cd_106.endf")
  iso_dict["Cd107"] = (4828, "0481070", "n-048_Cd_107.endf")
  iso_dict["Cd108"] = (4831, "0481080", "n-048_Cd_108.endf")
  iso_dict["Cd109"] = (4834, "0481090", "n-048_Cd_109.endf")
  iso_dict["Cd111"] = (4840, "0481110", "n-048_Cd_111.endf")
  iso_dict["Cd112"] = (4843, "0481120", "n-048_Cd_112.endf")
  iso_dict["Cd113"] = (4846, "0481130", "n-048_Cd_113.endf")
  iso_dict["Cd114"] = (4849, "0481140", "n-048_Cd_114.endf")
  iso_dict["Cd115M"] = (4853, "0481151", "n-048_Cd_115m1.endf")
  iso_dict["Cd116"] = (4855, "0481160", "n-048_Cd_116.endf")
  iso_dict["In113"] = (4925, "0491130", "n-049_In_113.endf")
  iso_dict["In114"] = (4928, "0491140", "n-049_In_114.endf")
  iso_dict["Sn112"] = (5025, "0501120", "n-050_Sn_112.endf")
  iso_dict["Sn113"] = (5028, "0501130", "n-050_Sn_113.endf")
  iso_dict["Sn114"] = (5031, "0501140", "n-050_Sn_114.endf")
  iso_dict["Sn115"] = (5034, "0501150", "n-050_Sn_115.endf")
  iso_dict["Sn116"] = (5037, "0501160", "n-050_Sn_116.endf")
  iso_dict["Sn117"] = (5040, "0501170", "n-050_Sn_117.endf")
  iso_dict["Sn118"] = (5043, "0501180", "n-050_Sn_118.endf")
  iso_dict["Sn119"] = (5046, "0501190", "n-050_Sn_119.endf")
  iso_dict["Sn120"] = (5049, "0501200", "n-050_Sn_120.endf")
  iso_dict["Sn121M"] = (5053, "0501211", "n-050_Sn_121m1.endf")
  iso_dict["Sn122"] = (5055, "0501220", "n-050_Sn_122.endf")
  iso_dict["Sn123"] = (5058, "0501230", "n-050_Sn_123.endf")
  iso_dict["Sn124"] = (5061, "0501240", "n-050_Sn_124.endf")
  iso_dict["Sn125"] = (5064, "0501250", "n-050_Sn_125.endf")
  iso_dict["Sn126"] = (5067, "0501260", "n-050_Sn_126.endf")
  iso_dict["Sb121"] = (5125, "0511210", "n-051_Sb_121.endf")
  iso_dict["Sb122"] = (5128, "0511220", "n-051_Sb_122.endf")
  iso_dict["Sb123"] = (5131, "0511230", "n-051_Sb_123.endf")
  iso_dict["Sb124"] = (5134, "0511240", "n-051_Sb_124.endf")
  iso_dict["Sb125"] = (5137, "0511250", "n-051_Sb_125.endf")
  iso_dict["Sb126"] = (5140, "0511260", "n-051_Sb_126.endf")
  iso_dict["Te120"] = (5225, "0521200", "n-052_Te_120.endf")
  iso_dict["Te121"] = (5228, "0521210", "n-052_Te_121.endf")
  iso_dict["Te121M"] = (5229, "0521211", "n-052_Te_121m1.endf")
  iso_dict["Te122"] = (5231, "0521220", "n-052_Te_122.endf")
  iso_dict["Te123"] = (5234, "0521230", "n-052_Te_123.endf")
  iso_dict["Te124"] = (5237, "0521240", "n-052_Te_124.endf")
  iso_dict["Te125"] = (5240, "0521250", "n-052_Te_125.endf")
  iso_dict["Te126"] = (5243, "0521260", "n-052_Te_126.endf")
  iso_dict["Te127M"] = (5247, "0521271", "n-052_Te_127m1.endf")
  iso_dict["Te128"] = (5249, "0521280", "n-052_Te_128.endf")
  iso_dict["Te129M"] = (5253, "0521291", "n-052_Te_129m1.endf")
  iso_dict["Te130"] = (5255, "0521300", "n-052_Te_130.endf")
  iso_dict["Te131"] = (5258, "0521310", "n-052_Te_131.endf")
  iso_dict["Te131M"] = (5259, "0521311", "n-052_Te_131m1.endf")
  iso_dict["Te132"] = (5261, "0521320", "n-052_Te_132.endf")
  iso_dict["I128"] = (5328, "0531280", "n-053_I_128.endf")
  iso_dict["I130"] = (5334, "0531300", "n-053_I_130.endf")
  iso_dict["I131"] = (5337, "0531310", "n-053_I_131.endf")
  iso_dict["I132"] = (5340, "0531320", "n-053_I_132.endf")
  iso_dict["I132M"] = (5341, "0531321", "n-053_I_132m1.endf")
  iso_dict["I133"] = (5343, "0531330", "n-053_I_133.endf")
  iso_dict["I134"] = (5346, "0531340", "n-053_I_134.endf")
  iso_dict["I135"] = (5349, "0531350", "n-053_I_135.endf")
  iso_dict["Xe123"] = (5422, "0541230", "n-054_Xe_123.endf")
  iso_dict["Xe124"] = (5425, "0541240", "n-054_Xe_124.endf")
  iso_dict["Xe125"] = (5428, "0541250", "n-054_Xe_125.endf")
  iso_dict["Xe126"] = (5431, "0541260", "n-054_Xe_126.endf")
  iso_dict["Xe127"] = (5434, "0541270", "n-054_Xe_127.endf")
  iso_dict["Xe128"] = (5437, "0541280", "n-054_Xe_128.endf")
  iso_dict["Xe129"] = (5440, "0541290", "n-054_Xe_129.endf")
  iso_dict["Xe130"] = (5443, "0541300", "n-054_Xe_130.endf")
  iso_dict["Xe131"] = (5446, "0541310", "n-054_Xe_131.endf")
  iso_dict["Xe132"] = (5449, "0541320", "n-054_Xe_132.endf")
  iso_dict["Xe133"] = (5452, "0541330", "n-054_Xe_133.endf")
  iso_dict["Xe134"] = (5455, "0541340", "n-054_Xe_134.endf")
  iso_dict["Xe135"] = (5458, "0541350", "n-054_Xe_135.endf")
  iso_dict["Xe136"] = (5461, "0541360", "n-054_Xe_136.endf")
  iso_dict["Cs133"] = (5525, "0551330", "n-055_Cs_133.endf")
  iso_dict["Cs134"] = (5528, "0551340", "n-055_Cs_134.endf")
  iso_dict["Cs135"] = (5531, "0551350", "n-055_Cs_135.endf")
  iso_dict["Cs136"] = (5534, "0551360", "n-055_Cs_136.endf")
  iso_dict["Cs137"] = (5537, "0551370", "n-055_Cs_137.endf")
  iso_dict["Ba130"] = (5625, "0561300", "n-056_Ba_130.endf")
  iso_dict["Ba131"] = (5628, "0561310", "n-056_Ba_131.endf")
  iso_dict["Ba132"] = (5631, "0561320", "n-056_Ba_132.endf")
  iso_dict["Ba133"] = (5634, "0561330", "n-056_Ba_133.endf")
  iso_dict["Ba134"] = (5637, "0561340", "n-056_Ba_134.endf")
  iso_dict["Ba135"] = (5640, "0561350", "n-056_Ba_135.endf")
  iso_dict["Ba136"] = (5643, "0561360", "n-056_Ba_136.endf")
  iso_dict["Ba137"] = (5646, "0561370", "n-056_Ba_137.endf")
  iso_dict["Ba138"] = (5649, "0561380", "n-056_Ba_138.endf")
  iso_dict["Ba139"] = (5652, "0561390", "n-056_Ba_139.endf")
  iso_dict["Ba140"] = (5655, "0561400", "n-056_Ba_140.endf")
  iso_dict["La138"] = (5725, "0571380", "n-057_La_138.endf")
  iso_dict["La139"] = (5728, "0571390", "n-057_La_139.endf")
  iso_dict["La140"] = (5731, "0571400", "n-057_La_140.endf")
  iso_dict["Ce136"] = (5825, "0581360", "n-058_Ce_136.endf")
  iso_dict["Ce137"] = (5828, "0581370", "n-058_Ce_137.endf")
  iso_dict["Ce137M"] = (5829, "0581371", "n-058_Ce_137m1.endf")
  iso_dict["Ce138"] = (5831, "0581380", "n-058_Ce_138.endf")
  iso_dict["Ce139"] = (5834, "0581390", "n-058_Ce_139.endf")
  iso_dict["Ce140"] = (5837, "0581400", "n-058_Ce_140.endf")
  iso_dict["Ce141"] = (5840, "0581410", "n-058_Ce_141.endf")
  iso_dict["Ce142"] = (5843, "0581420", "n-058_Ce_142.endf")
  iso_dict["Ce143"] = (5846, "0581430", "n-058_Ce_143.endf")
  iso_dict["Ce144"] = (5849, "0581440", "n-058_Ce_144.endf")
  iso_dict["Pr141"] = (5925, "0591410", "n-059_Pr_141.endf")
  iso_dict["Pr142"] = (5928, "0591420", "n-059_Pr_142.endf")
  iso_dict["Pr143"] = (5931, "0591430", "n-059_Pr_143.endf")
  iso_dict["Nd142"] = (6025, "0601420", "n-060_Nd_142.endf")
  iso_dict["Nd143"] = (6028, "0601430", "n-060_Nd_143.endf")
  iso_dict["Nd144"] = (6031, "0601440", "n-060_Nd_144.endf")
  iso_dict["Nd145"] = (6034, "0601450", "n-060_Nd_145.endf")
  iso_dict["Nd146"] = (6037, "0601460", "n-060_Nd_146.endf")
  iso_dict["Nd147"] = (6040, "0601470", "n-060_Nd_147.endf")
  iso_dict["Nd148"] = (6043, "0601480", "n-060_Nd_148.endf")
  iso_dict["Nd149"] = (6046, "0601490", "n-060_Nd_149.endf")
  iso_dict["Nd150"] = (6049, "0601500", "n-060_Nd_150.endf")
  iso_dict["Pm143"] = (6137, "0611430", "n-061_Pm_143.endf")
  iso_dict["Pm144"] = (6140, "0611440", "n-061_Pm_144.endf")
  iso_dict["Pm145"] = (6143, "0611450", "n-061_Pm_145.endf")
  iso_dict["Pm146"] = (6146, "0611460", "n-061_Pm_146.endf")
  iso_dict["Pm147"] = (6149, "0611470", "n-061_Pm_147.endf")
  iso_dict["Pm148"] = (6152, "0611480", "n-061_Pm_148.endf")
  iso_dict["Pm148M"] = (6153, "0611481", "n-061_Pm_148m1.endf")
  iso_dict["Pm149"] = (6155, "0611490", "n-061_Pm_149.endf")
  iso_dict["Pm150"] = (6158, "0611500", "n-061_Pm_150.endf")
  iso_dict["Pm151"] = (6161, "0611510", "n-061_Pm_151.endf")
  iso_dict["Sm144"] = (6225, "0621440", "n-062_Sm_144.endf")
  iso_dict["Sm145"] = (6228, "0621450", "n-062_Sm_145.endf")
  iso_dict["Sm146"] = (6231, "0621460", "n-062_Sm_146.endf")
  iso_dict["Sm147"] = (6234, "0621470", "n-062_Sm_147.endf")
  iso_dict["Sm148"] = (6237, "0621480", "n-062_Sm_148.endf")
  iso_dict["Sm149"] = (6240, "0621490", "n-062_Sm_149.endf")
  iso_dict["Sm150"] = (6243, "0621500", "n-062_Sm_150.endf")
  iso_dict["Sm151"] = (6246, "0621510", "n-062_Sm_151.endf")
  iso_dict["Sm152"] = (6249, "0621520", "n-062_Sm_152.endf")
  iso_dict["Sm153"] = (6252, "0621530", "n-062_Sm_153.endf")
  iso_dict["Sm154"] = (6255, "0621540", "n-062_Sm_154.endf")
  iso_dict["Eu151"] = (6325, "0631510", "n-063_Eu_151.endf")
  iso_dict["Eu152"] = (6328, "0631520", "n-063_Eu_152.endf")
  iso_dict["Eu153"] = (6331, "0631530", "n-063_Eu_153.endf")
  iso_dict["Eu154"] = (6334, "0631540", "n-063_Eu_154.endf")
  iso_dict["Eu155"] = (6337, "0631550", "n-063_Eu_155.endf")
  iso_dict["Eu156"] = (6340, "0631560", "n-063_Eu_156.endf")
  iso_dict["Eu157"] = (6343, "0631570", "n-063_Eu_157.endf")
  iso_dict["Gd153"] = (6428, "0641530", "n-064_Gd_153.endf")
  iso_dict["Gd159"] = (6446, "0641590", "n-064_Gd_159.endf")
  iso_dict["Tb158"] = (6522, "0651580", "n-065_Tb_158.endf")
  iso_dict["Tb159"] = (6525, "0651590", "n-065_Tb_159.endf")
  iso_dict["Tb160"] = (6528, "0651600", "n-065_Tb_160.endf")
  iso_dict["Tb161"] = (6531, "0651610", "n-065_Tb_161.endf")
  iso_dict["Dy154"] = (6619, "0661540", "n-066_Dy_154.endf")
  iso_dict["Dy155"] = (6622, "0661550", "n-066_Dy_155.endf")
  iso_dict["Dy156"] = (6625, "0661560", "n-066_Dy_156.endf")
  iso_dict["Dy157"] = (6628, "0661570", "n-066_Dy_157.endf")
  iso_dict["Dy158"] = (6631, "0661580", "n-066_Dy_158.endf")
  iso_dict["Dy159"] = (6634, "0661590", "n-066_Dy_159.endf")
  iso_dict["Ho165"] = (6725, "0671650", "n-067_Ho_165.endf")
  iso_dict["Ho166M"] = (6729, "0671661", "n-067_Ho_166m1.endf")
  iso_dict["Er162"] = (6825, "0681620", "n-068_Er_162.endf")
  iso_dict["Er163"] = (6828, "0681630", "n-068_Er_163.endf")
  iso_dict["Er165"] = (6834, "0681650", "n-068_Er_165.endf")
  iso_dict["Er169"] = (6846, "0681690", "n-068_Er_169.endf")
  iso_dict["Er164"] = (6831, "0681640", "n-068_Er_164.endf")
  iso_dict["Er166"] = (6837, "0681660", "n-068_Er_166.endf")
  iso_dict["Er167"] = (6840, "0681670", "n-068_Er_167.endf")
  iso_dict["Er168"] = (6843, "0681680", "n-068_Er_168.endf")
  iso_dict["Er170"] = (6849, "0681700", "n-068_Er_170.endf")
  iso_dict["Tm169"] = (6925, "0691690", "n-069_Tm_169.endf")
  iso_dict["Tm168"] = (6922, "0691680", "n-069_Tm_168.endf")
  iso_dict["Tm170"] = (6928, "0691700", "n-069_Tm_170.endf")
  iso_dict["Tm171"] = (6931, "0691710", "n-069_Tm_171.endf")
  iso_dict["Yb168"] = (7025, "0701680", "n-070_Yb_168.endf")
  iso_dict["Yb169"] = (7028, "0701690", "n-070_Yb_169.endf")
  iso_dict["Yb170"] = (7031, "0701700", "n-070_Yb_170.endf")
  iso_dict["Yb171"] = (7034, "0701710", "n-070_Yb_171.endf")
  iso_dict["Yb172"] = (7037, "0701720", "n-070_Yb_172.endf")
  iso_dict["Yb173"] = (7040, "0701730", "n-070_Yb_173.endf")
  iso_dict["Yb174"] = (7043, "0701740", "n-070_Yb_174.endf")
  iso_dict["Yb175"] = (7046, "0701750", "n-070_Yb_175.endf")
  iso_dict["Yb176"] = (7049, "0701760", "n-070_Yb_176.endf")
  iso_dict["Hf175"] = (7228, "0721750", "n-072_Hf_175.endf")
  iso_dict["Hf181"] = (7246, "0721810", "n-072_Hf_181.endf")
  iso_dict["Hf182"] = (7249, "0721820", "n-072_Hf_182.endf")
  iso_dict["Ta182"] = (7331, "0731820", "n-073_Ta_182.endf")
  iso_dict["Ta180"] = (7325, "0731800", "n-073_Ta_180.endf")
  iso_dict["W180"] = (7425, "0741800", "n-074_W_180.endf")
  iso_dict["W181"] = (7428, "0741810", "n-074_W_181.endf")
  iso_dict["W185"] = (7440, "0741850", "n-074_W_185.endf")
  iso_dict["Re186M"] = (7529, "0751861", "n-075_Re_186m1.endf")
  iso_dict["Re187"] = (7531, "0751870", "n-075_Re_187.endf")
  iso_dict["Re185"] = (7525, "0751850", "n-075_Re_185.endf")
  iso_dict["Os184"] = (7625, "0761840", "n-076_Os_184.endf")
  iso_dict["Os185"] = (7628, "0761850", "n-076_Os_185.endf")
  iso_dict["Os186"] = (7631, "0761860", "n-076_Os_186.endf")
  iso_dict["Os187"] = (7634, "0761870", "n-076_Os_187.endf")
  iso_dict["Os188"] = (7637, "0761880", "n-076_Os_188.endf")
  iso_dict["Os189"] = (7640, "0761890", "n-076_Os_189.endf")
  iso_dict["Os190"] = (7643, "0761900", "n-076_Os_190.endf")
  iso_dict["Os191"] = (7646, "0761910", "n-076_Os_191.endf")
  iso_dict["Os192"] = (7649, "0761920", "n-076_Os_192.endf")
  iso_dict["Ir193"] = (7731, "0771930", "n-077_Ir_193.endf")
  iso_dict["Ir191"] = (7725, "0771910", "n-077_Ir_191.endf")
  iso_dict["Ir192"] = (7728, "0771920", "n-077_Ir_192.endf")
  iso_dict["Ir194M"] = (7735, "0771941", "n-077_Ir_194m1.endf")
  iso_dict["Pt190"] = (7825, "0781900", "n-078_Pt_190.endf")
  iso_dict["Pt191"] = (7828, "0781910", "n-078_Pt_191.endf")
  iso_dict["Pt192"] = (7831, "0781920", "n-078_Pt_192.endf")
  iso_dict["Pt193"] = (7834, "0781930", "n-078_Pt_193.endf")
  iso_dict["Pt194"] = (7837, "0781940", "n-078_Pt_194.endf")
  iso_dict["Pt195"] = (7840, "0781950", "n-078_Pt_195.endf")
  iso_dict["Pt196"] = (7843, "0781960", "n-078_Pt_196.endf")
  iso_dict["Pt197"] = (7846, "0781970", "n-078_Pt_197.endf")
  iso_dict["Pt198"] = (7849, "0781980", "n-078_Pt_198.endf")
  iso_dict["Au197"] = (7925, "0791970", "n-079_Au_197.endf")
  iso_dict["Hg196"] = (8025, "0801960", "n-080_Hg_196.endf")
  iso_dict["Hg197"] = (8028, "0801970", "n-080_Hg_197.endf")
  iso_dict["Hg197M"] = (8029, "0801971", "n-080_Hg_197m1.endf")
  iso_dict["Hg198"] = (8031, "0801980", "n-080_Hg_198.endf")
  iso_dict["Hg199"] = (8034, "0801990", "n-080_Hg_199.endf")
  iso_dict["Hg200"] = (8037, "0802000", "n-080_Hg_200.endf")
  iso_dict["Hg201"] = (8040, "0802010", "n-080_Hg_201.endf")
  iso_dict["Hg202"] = (8043, "0802020", "n-080_Hg_202.endf")
  iso_dict["Hg203"] = (8046, "0802030", "n-080_Hg_203.endf")
  iso_dict["Hg204"] = (8049, "0802040", "n-080_Hg_204.endf")
  iso_dict["Tl204"] = (8128, "0812040", "n-081_Tl_204.endf")
  iso_dict["Tl205"] = (8131, "0812050", "n-081_Tl_205.endf")
  iso_dict["Tl203"] = (8125, "0812030", "n-081_Tl_203.endf")
  iso_dict["Pb205"] = (8228, "0822050", "n-082_Pb_205.endf")
  iso_dict["Bi210M"] = (8329, "0832101", "n-083_Bi_210m1.endf")
  iso_dict["Po208"] = (8431, "0842080", "n-084_Po_208.endf")
  iso_dict["Po209"] = (8434, "0842090", "n-084_Po_209.endf")
  iso_dict["Po210"] = (8437, "0842100", "n-084_Po_210.endf")
  iso_dict["Ra225"] = (8831, "0882250", "n-088_Ra_225.endf")
  iso_dict["Ra223"] = (8825, "0882230", "n-088_Ra_223.endf")
  iso_dict["Ra226"] = (8834, "0882260", "n-088_Ra_226.endf")
  iso_dict["Ra224"] = (8828, "0882240", "n-088_Ra_224.endf")

  for iso_name, tup in iso_dict.items():
    this_job = copy.deepcopy(job_ref_fp)
    this_job.hmat = iso_name
    this_job.mat = tup[0]
    this_job.zaid = tup[1]
    this_job.evaluationFile = this_job.evaluationDir + tup[2]
    if iso_name == "Pt192":
      this_job.dilutions = None
  #  print (this_job.hmat + str(this_job.fp) + str(this_job.dilutions) + str(this_job.scatteringLaw))
    njoy_jobs.append(this_job)

  # fp with dilution
  job_ref_fp.ss = (22.53556, 1.858471e4)

  this_job = copy.deepcopy(job_ref_fp)
  this_job.hmat = "Zr90"
  this_job.mat = 4025
  this_job.zaid = "0400900"
  this_job.evaluationFile = this_job.evaluationDir + "n-040_Zr_090.endf"
  this_job.dilutions = ( 1.e10, 10000.0,  3866.97, 1495.35, 578.2475, 223.6068, 86.4682, 33.4370, 12.9300, 5.0 )
  this_job.autolib = (4.632489, 3.481068e3, 0.0005)
  njoy_jobs.append(this_job)

  this_job = copy.deepcopy(job_ref_fp)
  this_job.hmat = "Zr91"
  this_job.mat = 4028
  this_job.zaid = "0400910"
  this_job.evaluationFile = this_job.evaluationDir + "n-040_Zr_091.endf"
  this_job.dilutions = ( 1.e10, 10000.0, 3549.18335, 1259.67004, 447.079956, \
    158.676849, 56.3173141, 19.9880447, 7.09412289, 2.51783395 )
  njoy_jobs.append(this_job)

  this_job = copy.deepcopy(job_ref_fp)
  this_job.hmat = "Zr92"
  this_job.mat = 4031
  this_job.zaid = "0400920"
  this_job.evaluationFile = this_job.evaluationDir + "n-040_Zr_092.endf"
  this_job.dilutions = ( 1.e10, 10000.0, 3549.18335, 1259.67004, 447.079956, \
    158.676849, 56.3173141, 19.9880447, 7.09412289, 2.51783395 )
  njoy_jobs.append(this_job)

  this_job = copy.deepcopy(job_ref_fp)
  this_job.hmat = "Zr94"
  this_job.mat = 4037
  this_job.zaid = "0400940"
  this_job.evaluationFile = this_job.evaluationDir + "n-040_Zr_094.endf"
  this_job.dilutions = ( 1.e10, 10000.0, 3549.18335, 1259.67004, 447.079956, \
    158.676849, 56.3173141, 19.9880447, 7.09412289, 2.51783395 )
  njoy_jobs.append(this_job)

  this_job = copy.deepcopy(job_ref_fp)
  this_job.hmat = "Zr96"
  this_job.mat = 4043
  this_job.zaid = "0400960"
  this_job.evaluationFile = this_job.evaluationDir + "n-040_Zr_096.endf"
  this_job.dilutions = ( 1.e10, 10000.0, 3549.18335, 1259.67004, 447.079956, \
    158.676849, 56.3173141, 19.9880447, 7.09412289, 2.51783395 )
  njoy_jobs.append(this_job)

  this_job = copy.deepcopy(job_ref_fp)
  this_job.hmat = "Tc99"
  this_job.mat = 4325
  this_job.zaid = "0430990"
  this_job.evaluationFile = this_job.evaluationDir + "n-043_Tc_099.endf"
  this_job.dilutions = ( 1.e10, 10000.0, 4216.96552, 1778.27959, 749.894278, \
    316.227791, 133.352152,  56.2341357, 23.7137381, 10.0 )
  njoy_jobs.append(this_job)

  this_job = copy.deepcopy(job_ref_fp)
  this_job.hmat = "Ag107"
  this_job.mat = 4725
  this_job.zaid = "0471070"
  this_job.evaluationFile = this_job.evaluationDir + "n-047_Ag_107.endf"
  this_job.dilutions = ( 1.e10, 10000.0, 3549.18335, 1259.67004, 447.079956, \
    158.676849, 56.3173141, 19.9880447, 7.09412289, 2.51783395 )
  njoy_jobs.append(this_job)

  this_job = copy.deepcopy(job_ref_fp)
  this_job.hmat = "Ag109"
  this_job.mat = 4731
  this_job.zaid = "0471090"
  this_job.evaluationFile = this_job.evaluationDir + "n-047_Ag_109.endf"
  this_job.dilutions = ( 1.e10, 10000.0, 3549.18335, 1259.67004, 447.079956, \
    158.676849, 56.3173141, 19.9880447, 7.09412289, 2.51783395 )
  njoy_jobs.append(this_job)

  this_job = copy.deepcopy(job_ref_fp)
  this_job.hmat = "Cd110"
  this_job.mat = 4837
  this_job.zaid = "0481100"
  this_job.evaluationFile = this_job.evaluationDir + "n-048_Cd_110.endf"
  this_job.dilutions = ( 1.e10, 10000.0, 3549.18335, 1259.67004, 447.079956, \
    158.676849, 56.3173141, 19.9880447, 7.09412289, 2.51783395 )
  njoy_jobs.append(this_job)

  this_job = copy.deepcopy(job_ref_fp)
  this_job.hmat = "In115"
  this_job.mat = 4931
  this_job.zaid = "0491150"
  this_job.evaluationFile = this_job.evaluationDir + "n-049_In_115.endf"
  this_job.dilutions = ( 1.e10, 10000.0, 3549.18335, 1259.67004, 447.079956, \
    158.676849, 56.3173141, 19.9880447, 7.09412289, 2.51783395 )
  njoy_jobs.append(this_job)

  this_job = copy.deepcopy(job_ref_fp)
  this_job.hmat = "I127"
  this_job.mat = 5325
  this_job.zaid = "0531270"
  this_job.evaluationFile = this_job.evaluationDir + "n-053_I_127.endf"
  this_job.dilutions = ( 1.e10, 10000.0, 4216.96552, 1778.27959, 749.894278, \
    316.227791, 133.352152,  56.2341357, 23.7137381, 10.0 )
  njoy_jobs.append(this_job)

  this_job = copy.deepcopy(job_ref_fp)
  this_job.hmat = "I129"
  this_job.mat = 5331
  this_job.zaid = "0531290"
  this_job.evaluationFile = this_job.evaluationDir + "n-053_I_129.endf"
  this_job.dilutions = ( 1.e10, 10000.0, 4216.96552, 1778.27959, 749.894278, \
    316.227791, 133.352152,  56.2341357, 23.7137381, 10.0 )
  njoy_jobs.append(this_job)

  this_job = copy.deepcopy(job_ref_fp)
  this_job.hmat = "Gd152"
  this_job.mat = 6425
  this_job.zaid = "0641520"
  this_job.evaluationFile = this_job.evaluationDir + "n-064_Gd_152.endf"
  this_job.dilutions = ( 1.e10, 10000.0, 4216.96552, 1778.27959, 749.894278, \
    316.227791, 133.352152,  56.2341357, 23.7137381, 10.0 )
  njoy_jobs.append(this_job)

  this_job = copy.deepcopy(job_ref_fp)
  this_job.hmat = "Gd154"
  this_job.mat = 6431
  this_job.zaid = "0641540"
  this_job.evaluationFile = this_job.evaluationDir + "n-064_Gd_154.endf"
  this_job.dilutions = ( 1.e10, 10000.0, 4216.96552, 1778.27959, 749.894278, \
    316.227791, 133.352152,  56.2341357, 23.7137381, 10.0 )
  njoy_jobs.append(this_job)

  this_job = copy.deepcopy(job_ref_fp)
  this_job.hmat = "Gd155"
  this_job.mat = 6434
  this_job.zaid = "0641550"
  this_job.evaluationFile = this_job.evaluationDir + "n-064_Gd_155.endf"
  this_job.dilutions = ( 1.e10, 10000.0, 4216.96552, 1778.27959, 749.894278, \
    316.227791, 133.352152,  56.2341357, 23.7137381, 10.0 )
  njoy_jobs.append(this_job)

  this_job = copy.deepcopy(job_ref_fp)
  this_job.hmat = "Gd156"
  this_job.mat = 6437
  this_job.zaid = "0641560"
  this_job.evaluationFile = this_job.evaluationDir + "n-064_Gd_156.endf"
  this_job.dilutions = ( 1.e10, 10000.0, 4216.96552, 1778.27959, 749.894278, \
    316.227791, 133.352152,  56.2341357, 23.7137381, 10.0 )
  njoy_jobs.append(this_job)

  this_job = copy.deepcopy(job_ref_fp)
  this_job.hmat = "Gd157"
  this_job.mat = 6440
  this_job.zaid = "0641570"
  this_job.evaluationFile = this_job.evaluationDir + "n-064_Gd_157.endf"
  this_job.dilutions = ( 1.e10, 10000.0, 4216.96552, 1778.27959, 749.894278, \
    316.227791, 133.352152,  56.2341357, 23.7137381, 10.0 )
  njoy_jobs.append(this_job)

  this_job = copy.deepcopy(job_ref_fp)
  this_job.hmat = "Gd158"
  this_job.mat = 6443
  this_job.zaid = "0641580"
  this_job.evaluationFile = this_job.evaluationDir + "n-064_Gd_158.endf"
  this_job.dilutions = ( 1.e10, 10000.0, 4216.96552, 1778.27959, 749.894278, \
    316.227791, 133.352152,  56.2341357, 23.7137381, 10.0 )
  njoy_jobs.append(this_job)

  this_job = copy.deepcopy(job_ref_fp)
  this_job.hmat = "Gd160"
  this_job.mat = 6449
  this_job.zaid = "0641600"
  this_job.evaluationFile = this_job.evaluationDir + "n-064_Gd_160.endf"
  this_job.dilutions = ( 1.e10, 10000.0, 4216.96552, 1778.27959, 749.894278, \
    316.227791, 133.352152,  56.2341357, 23.7137381, 10.0 )
  njoy_jobs.append(this_job)

  this_job = copy.deepcopy(job_ref_fp)
  this_job.hmat = "Dy160"
  this_job.mat = 6637
  this_job.zaid = "0661600"
  this_job.evaluationFile = this_job.evaluationDir + "n-066_Dy_160.endf"
  this_job.dilutions = ( 1.e10, 10000.0, 4216.96552, 1778.27959, 749.894278, \
    316.227791, 133.352152,  56.2341357, 23.7137381, 10.0 )
  njoy_jobs.append(this_job)

  this_job = copy.deepcopy(job_ref_fp)
  this_job.hmat = "Dy161"
  this_job.mat = 6640
  this_job.zaid = "0661610"
  this_job.evaluationFile = this_job.evaluationDir + "n-066_Dy_161.endf"
  this_job.dilutions = ( 1.e10, 10000.0, 4216.96552, 1778.27959, 749.894278, \
    316.227791, 133.352152,  56.2341357, 23.7137381, 10.0 )
  njoy_jobs.append(this_job)

  this_job = copy.deepcopy(job_ref_fp)
  this_job.hmat = "Dy162"
  this_job.mat = 6643
  this_job.zaid = "0661620"
  this_job.evaluationFile = this_job.evaluationDir + "n-066_Dy_162.endf"
  this_job.dilutions = ( 1.e10, 10000.0, 4216.96552, 1778.27959, 749.894278, \
    316.227791, 133.352152,  56.2341357, 23.7137381, 10.0 )
  njoy_jobs.append(this_job)

  this_job = copy.deepcopy(job_ref_fp)
  this_job.hmat = "Dy163"
  this_job.mat = 6646
  this_job.zaid = "0661630"
  this_job.evaluationFile = this_job.evaluationDir + "n-066_Dy_163.endf"
  this_job.dilutions = ( 1.e10, 10000.0, 4216.96552, 1778.27959, 749.894278, \
    316.227791, 133.352152,  56.2341357, 23.7137381, 10.0 )
  njoy_jobs.append(this_job)

  this_job = copy.deepcopy(job_ref_fp)
  this_job.hmat = "Dy164"
  this_job.mat = 6649
  this_job.zaid = "0661640"
  this_job.evaluationFile = this_job.evaluationDir + "n-066_Dy_164.endf"
  this_job.dilutions = ( 1.e10, 10000.0, 4216.96552, 1778.27959, 749.894278, \
    316.227791, 133.352152,  56.2341357, 23.7137381, 10.0 )
  njoy_jobs.append(this_job)

  this_job = copy.deepcopy(job_ref_fp)
  this_job.hmat = "Lu175"
  this_job.mat = 7125
  this_job.zaid = "0711750"
  this_job.evaluationFile = this_job.evaluationDir + "n-071_Lu_175.endf"
  this_job.dilutions = ( 1.e10, 10000.0, 4216.96552, 1778.27959, 749.894278, \
    316.227791, 133.352152,  56.2341357, 23.7137381, 10.0 )
  njoy_jobs.append(this_job)

  this_job = copy.deepcopy(job_ref_fp)
  this_job.hmat = "Lu176"
  this_job.mat = 7128
  this_job.zaid = "0711760"
  this_job.evaluationFile = this_job.evaluationDir + "n-071_Lu_176.endf"
  this_job.dilutions = ( 1.e10, 10000.0, 4216.96552, 1778.27959, 749.894278, \
    316.227791, 133.352152,  56.2341357, 23.7137381, 10.0 )
  njoy_jobs.append(this_job)

  this_job = copy.deepcopy(job_ref_fp)
  this_job.hmat = "Hf174"
  this_job.mat = 7225
  this_job.zaid = "0721740"
  this_job.evaluationFile = this_job.evaluationDir + "n-072_Hf_174.endf"
  this_job.dilutions = ( 1.e10, 10000.0, 4216.96552, 1778.27959, 749.894278, \
    316.227791, 133.352152,  56.2341357, 23.7137381, 10.0 )
  njoy_jobs.append(this_job)

  this_job = copy.deepcopy(job_ref_fp)
  this_job.hmat = "Hf176"
  this_job.mat = 7231
  this_job.zaid = "0721760"
  this_job.evaluationFile = this_job.evaluationDir + "n-072_Hf_176.endf"
  this_job.dilutions = ( 1.e10, 10000.0, 4216.96552, 1778.27959, 749.894278, \
    316.227791, 133.352152,  56.2341357, 23.7137381, 10.0 )
  njoy_jobs.append(this_job)

  this_job = copy.deepcopy(job_ref_fp)
  this_job.hmat = "Hf177"
  this_job.mat = 7234
  this_job.zaid = "0721770"
  this_job.evaluationFile = this_job.evaluationDir + "n-072_Hf_177.endf"
  this_job.dilutions = ( 1.e10, 10000.0, 4216.96552, 1778.27959, 749.894278, \
    316.227791, 133.352152,  56.2341357, 23.7137381, 10.0 )
  njoy_jobs.append(this_job)

  this_job = copy.deepcopy(job_ref_fp)
  this_job.hmat = "Hf178"
  this_job.mat = 7237
  this_job.zaid = "0721780"
  this_job.evaluationFile = this_job.evaluationDir + "n-072_Hf_178.endf"
  this_job.dilutions = ( 1.e10, 10000.0, 4216.96552, 1778.27959, 749.894278, \
    316.227791, 133.352152,  56.2341357, 23.7137381, 10.0 )
  njoy_jobs.append(this_job)

  this_job = copy.deepcopy(job_ref_fp)
  this_job.hmat = "Hf179"
  this_job.mat = 7240
  this_job.zaid = "0721790"
  this_job.evaluationFile = this_job.evaluationDir + "n-072_Hf_179.endf"
  this_job.dilutions = ( 1.e10, 10000.0, 4216.96552, 1778.27959, 749.894278, \
    316.227791, 133.352152,  56.2341357, 23.7137381, 10.0 )
  njoy_jobs.append(this_job)

  this_job = copy.deepcopy(job_ref_fp)
  this_job.hmat = "Hf180"
  this_job.mat = 7243
  this_job.zaid = "0721800"
  this_job.evaluationFile = this_job.evaluationDir + "n-072_Hf_180.endf"
  this_job.dilutions = ( 1.e10, 10000.0, 4216.96552, 1778.27959, 749.894278, \
    316.227791, 133.352152,  56.2341357, 23.7137381, 10.0 )
  njoy_jobs.append(this_job)

  this_job = copy.deepcopy(job_ref_fp)
  this_job.hmat = "Ta181"
  this_job.mat = 7328
  this_job.zaid = "0731810"
  this_job.evaluationFile = this_job.evaluationDir + "n-073_Ta_181.endf"
  this_job.dilutions = ( 1.e10, 10000.0, 4216.96552, 1778.27959, 749.894278, \
    316.227791, 133.352152,  56.2341357, 23.7137381, 10.0 )
  njoy_jobs.append(this_job)

  print('Number of jobs from fission product isotopes: '+ str(len(njoy_jobs) - c1))

  tim1 = time.time()
  print('___TIMER___: All jobs definition done =' + str(tim1 - tim) + ' s')
  tim = tim1
  #############################################################################
  #  check file locations
  #############################################################################
  my_iso = []
  for this_job in njoy_jobs:
    if this_job.hmat not in my_iso:
      my_iso.append(this_job.hmat)
    else:
          print('Duplicate isotope', this_job.hmat)
    if not os.path.isfile(os.path.expandvars(this_job.evaluationFile)):
      raise PyNjoyError("evaluation file " + this_job.evaluationFile + " not found")
    if this_job.scatteringLaw != None:
      if not os.path.isfile(os.path.expandvars(this_job.scatteringLaw)):
        raise PyNjoyError("scatteringLaw file " + this_job.scatteringLaw + " not found")

  njoy_jobs.pendf()
  njoy_jobs.gendf()
  #
  # clean up
  #
  os.chdir(evalName)
  os.system('find . -name "gendf_neutron*" -exec mv {} . \;')
  os.system('rm -R -- */')

  tim1=(tim1 - tim0)/3600
  print('___TIMER___: Complete GENDF files computed =' + str(tim1) + ' h')

if __name__ == '__main__':
  sys.exit(main())
