   program upd
   !--------------------------------------------------------------------------
   !
   ! Program UPD
   ! A  Simple Update Program
   ! Version: 3.0
   ! Date: 21 Dec 2012
   !
   ! This is a revision-control program originally modeled on the UPDATE
   ! program that ran on CDC and Cray machines.  It is used to make a
   ! record of consecutive changes to a package of text files, such as
   ! Fortran source code or TeX documentation, that is useful for history
   ! and quality-assurance purposes.  The changes are specified with simple
   ! directives that are easy to exchange between various users of the code
   ! or other text being maintained.  The history mechanism provides a
   ! capability to step back to previous versions, and it also provides for
   ! detailed explanatory comments on each revision made.  UPD includes an
   ! option for conditional blocks of text or computer code that can be
   ! activated by switches in the input file; this is useful for handling
   ! computer system dependency issues.  This version differs from the
   ! previous version of UPD in the following ways: it can construct new
   ! updates automatically from the differences between the current edited
   ! files and the files defined by the previous updates, it only touches
   ! files that really change in order to make the best use of code
   ! configuration tools like make, it has changes to help it manage
   ! other kinds of information than Fortran-77 ".f" files, it no longer
   ! labels lines after column 72 in order to handle free-format text
   ! lines (up to 80 columns allowed), conditional blocks are more
   ! restrictive, and some of its operatiaons are now controlled by
   ! command-line options.  The "*b" (insert before) and "*comdeck"
   ! directives from previous versions of UPD are no longer supported.
   ! The "*cpl", "*lst", "*noid", and "*npl" directives are no longer
   ! needed. 
   !
   ! The original text, such as a Fortran source, is stored in the file
   ! "src".  It is divided up into separate parts by "*deck name.suf"
   ! lines, and each deck is designed to generate an active file 
   ! "name.suf" and a corresponding listing file "name.lst".  The
   ! "name" is limited to 6 characters.  The suffix could be "f90" for
   ! Fortran-90 code, "tex" for documentation, "bat" for a DOS batch file,
   ! or almost any other useful string with no more than 3 characters.
   ! Each name must be unique; that is, you cannot have "njoy.f90" and
   ! "njoy.bat" both present in the package.
   !
   ! A key feature of UPDATE-type programs is that each line has a label
   ! that is permanently associated with that line.  In each deck, the
   ! first line after the "*deck" line is labeled "name.2", the next line
   ! is referred to using "name.3", and so on.  The "src" files can also
   ! contain "*if" and "*endif" lines as described below.  These lines
   ! are numbered just like any other lines in the "src" file.
   !
   ! Changes to the managed text are given in an input file called "upn".
   ! This file is divided into separate named parts by lines of the form
   ! "*ident name".  The "name" is a string of up to six characters used
   ! to construct labels for the new lines.  Each ident contains a mixture
   ! of UPD directives and new lines of text (such as Fortran statements).
   ! The directives are as follows:
   !
   !   *i ref
   !       insert the lines between the "*i" directive and the
   !       next UPD directive after the location "ref".
   !
   !   *d ref1,ref2
   !       delete the lines from "ref1" through "ref2, and
   !       insert the lines between the "*d" directive and the
   !       next upd directive (if any).
   !
   !   */ text
   !       comments on the changes being made (the comments
   !       are not inserted into the code)
   !
   ! The line references can have the following forms:
   !
   !    name.5
   !    name.5,7
   !    name1.5,name2.6
   !
   ! Updates can be made on top of previous updates as long as each line
   ! referenced is currently active.  Updates are numbered so that the
   ! first line after the "*ident name" line is labeled "name.2".  A new
   ! "*deck" card with associated text lines can appear in an ident, but
   ! changes to the new deck will have to use the ident name until a new
   ! resequenced version is prepared.
   !
   ! The ident names are arbitrary, but it is useful to establish some
   ! conventions.  For example, an ident called "up11" might advance the
   ! version name of this code to "upd 3.11".  Experimental changes,
   ! site-dependent changes, or machine-dependent changes can be given
   ! other appropriate names.
   !
   ! For quality-assurance reasons, it is important to label source code
   ! and output from codes with current version/date information.  Codes
   ! normally contain version and date information as comments near the
   ! beginning of the source file, and they should also provide version
   ! and date strings for labeling output files.  For flexibility and
   ! simplicity, UPD does not provide a standard mechanism for changing
   ! version and date inside the text being managed.  It is recommended
   ! that this information be included in the ident for each update using
   ! something like the following:
   !
   !    *ident up11
   !    *d up10.3,4
   !       ! Version: 3.11
   !       ! Date: 11 March 2002
   !    *d up10.6,7
   !       character(6)::vers='3.11  '
   !       character(7)::verd='11mar02'
   !    */ upd 3.11 (11 March 2002)
   !    */   This update extends the ....
   ! 
   ! UPD supports a capability for conditional blocks in the package coding
   ! that can be turned on with "*set switch" lines at the beginning of the
   ! upn file.  This capability is useful for handling machine dependencies.
   ! Conditional blocks in the src or upn files have the following very
   ! simple form:
   ! 
   !    *if switch
   !       line1
   !       line2
   !    *endif
   ! 
   ! Nesting of if-endif blocks is not allowed; the effects of nesting or
   ! "else" clauses can be achieved by choosing appropriate switch names.
   !
   ! In order to construct modification directives manually, it is
   ! necessary to know the line labels.  These labels are shown along
   ! the left-hand edge of the listings in the ".lst" files.  These
   ! files provide a handy way to see what changes were made in a region
   ! of coding, and they provide a readable version of the code for a
   ! notebook.  Some ".lst" files give procedure names on the right to
   ! make it easier to scan through the listings by eye.  The ".lst" files
   ! should be printed using a font that allows for 104 columns on the
   ! page (8pt).  Most of the time, it is not necessary to look at the
   ! ".lst" files, because the changes can be contructed automatically
   ! with the UPD "revise" option.
   ! 
   ! UPD provides the following options: 
   ! 
   !    upd history
   ! 
   !       Write the history provided by the "*/ comment" cards to
   !       standard output.  The action string "history" can be 
   !       abbreviated as "h".
   ! 
   !    upd extract
   ! 
   !       Extract all the ".suf" files to the current directory.
   !       Any files that are present and not different will be
   !       left untouched so that a make run will only process the
   !       changed or new files. The action string "extract" can
   !       be abbreviated as "x".
   !
   !    upd list
   !       Extract ".lst" files for all the decks to the current
   !       directory.  The action string "list" can be abbreviated
   !       as "l".
   ! 
   !    upd revise
   ! 
   !       Find all the differences between the edited ".suf" files 
   !       currently in the working directory and the corresponding 
   !       files as defined by the current upn file.  Construct the
   !       UPD directives needed to produce the changes and write
   !       them into the file "rev".  Remind the user to insert rev
   !       into the upn file and to edit the new "*ident" section to
   !       provide an appropriate name, version/date information,
   !       and detailed descriptive comments.  If the new upn implies
   !       futher changes to the ".suf" files, run "upd extract".
   !       If new ".lst" files are needed, run "upd list".  The 
   !       action string "revise" can be abbreviated as "r".
   !
   !    upd new
   !
   !       Make a new src file called "new".  This command is used to
   !       start a new major version of the package.  The action 
   !       string "new" can abbreviated as "n".
   !
   ! To back up to an earlier version of a package, copy your upn
   ! file to a backup file, delete any idents that are not wanted,
   ! and run UPD with the "extract" option.  This will only affect
   ! files that are changed by backing up, so just run make to recompile
   ! the modified files.
   !
   ! Files used:
   !
   !    src        original source file for the package
   !    upn        revision history
   !    rev        revisions generated by "revise" command
   !    new        new src file generated by "new" command
   !    x.suf      managed file for deck x.suf
   !    x.lst      listing file for deck x.suf
   !    tmp        direct-access scratch file with system-dependent name
   !    stdout     standard output
   ! 
   ! Notes:
   ! 
   ! 1. UPD is designed to manage packages of modest size (less than
   !    200K lines) that are controlled by one person.  Therefore, 
   !    the complications of recursive access to subdirectories, 
   !    client/server structure, managing concurrent access, branches,
   !    or merging of changes from different people found in systems 
   !    like CVS have been omitted.  This makes it easier to port the
   !    code to many different computer systems.
   !
   ! 2. We could have had the revise command ask the user for text input for
   !    the descriptive comments about the new revision and automatically
   !    update the upn file, but it seems easier to just open upn in a good
   !    editor and enter the additions and comments that way.  This approach
   !    is the most portable.
   !
   ! History:
   !
   !   3.0    01jan01  Initial version
   !          21dec12  Version for NJOY2012 (identical)
   !
   !                                           Robert MacFarlane
   !                                           T-2 MS B216
   !                                           Los Alamos National Laboratory
   !                                           ryxm@lanl.gov
   ! 
   !--------------------------------------------------------------------------
   implicit none

   ! UPD version and date strings
   character(6)::vers='3.0   '
   character(7)::verd='21dec12'

   ! storage limits
   integer,parameter::llen=80       ! maximum number of characters in a line
   integer,parameter::mline=200000  ! maximum number of lines in a package
   integer,parameter::mdeck=100     ! maximum number of decks in a package
   integer,parameter::mdiff=99999   ! maximum number of lines in a deck
   integer,parameter::ndiff=200000  ! maximum number of lines in a new upn
   integer,parameter::mset=20       ! maximum number of set switches

   ! internal variables
   integer::n,l,i,ideck,nrec,nline,ndeck,nset,iupn,j1,j2,j3,l3,jj
   integer::kline,k,j,idiff,i2,n2,i1,n1,idiff0,k1,k2,m,m1,ii,m2
   integer::irec,iout,nsrc,nupn,nfile,nout,ntmp,iargc,iden,isrc
   logical::ins,new,set,exists,nofile
   character(8)::date
   character(10)::time
   character(5)::zone
   integer,dimension(8)::values
   character(7)::hdate
   character(llen)::iline
   integer::lline(mline)
   character(12)::label(mline)
   character(12)::ref1,ref2
   integer::ldeck(mdeck)
   character(6)::deckn(mdeck)
   character(6)::lab
   character(6)::idnt
   character(3)::dsuff(mdeck)
   character(llen)::diffs(ndiff)
   character(llen)::line1(mdiff),line2(mdiff)
   character(10)::action,temp
   character(15)::fname
   character(8)::sets(mset),switch
   character(3),dimension(12)::month=(/'jan','feb','mar','apr','may',&
     'jun','jul','aug','sep','oct','nov','dec'/)

   !--get arguments
   n=iargc()
   action='none'
   if (n.ge.1) then
      call getarg(1,action)
   endif

   !--check for action abbreviations or errors
   if (action.eq.'x') action='extract'
   if (action.eq.'r') action='revise'
   if (action.eq.'h') action='history'
   if (action.eq.'n') action='new'
   if (action.eq.'l') action='list'
   if (action.ne.'extract'.and.action.ne.'revise'.and.&
     action.ne.'history'.and.action.ne.'new'.and.action.ne.'list')&
      call error('illegal action')

   !--execute the history command
   if (action.eq.'history') then

      !--write a header for the output file
      write(*,'('' UPD History''/'' -----------'')')

      !--read through the upn file
      nupn=2
      open(nupn,file='upn',status='old')
      do 
         read(nupn,'(a)',end=100) iline
         l=len_trim(iline)
         if (iline(1:7).eq.'*ident ') then
            write(*,'(1x)')
            write(*,'(2x,a)') iline(2:l)
         endif
         if (iline(1:3).eq.'*/ ') then
            write(*,'(3x,a)') iline(3:l)
         endif
      enddo
     100 continue
      close(nupn)

   ! execute the extract, revise, list, or new command
   else

      !--write a header for the output
      l=len_trim(vers)
      write(*,'('' upd ----------------------- v'',a)') vers(1:l)
      if (action.eq.'extract') then
         write(*,'('' extract'')')
      else if (action.eq.'list') then
         write(*,'('' list'')')
      else if (action.eq.'new') then
         write(*,'('' new'')')
      else
         write(*,'('' revise'')')
      endif

      !--read src file into a direct access file
      !--initialize the list of line pointers
      nsrc=1
      open(nsrc,file='src',status='old')
      ntmp=11
      open(ntmp,status='scratch',access='direct',recl=llen)
      irec=0
      ideck=0
      isrc=0
      do
         irec=irec+1
         if (irec.gt.mline) call error('too many lines in package')
         read(nsrc,'(a)',end=110) iline
         lline(irec)=irec
         if (iline(1:6).eq.'*deck ') then
            ideck=ideck+1
            if (ideck.gt.mdeck) call error('too many deck names')
            ldeck(ideck)=irec
            l=len_trim(iline)
            j=0
            do i=7,l
               if (iline(i:i).eq.'.') then
                  j=i
                  exit
               endif
            enddo
            if (j.eq.0) then
               write(*,'(''deck='',a)') iline(7:l)
               call error('no suffix for deck name')
            endif
            deckn(ideck)=iline(7:j-1)
            dsuff(ideck)=iline(j+1:l)
            j1=j-1
            isrc=0
            lab='      '
            do i=7,j1
               j=i-j1+6
               lab(j:j)=iline(i:i)
            enddo
         endif
         isrc=isrc+1
         label(irec)='            '
         if (isrc.lt.10) then
            write(label(irec),'(a,''.'',i1)') lab,isrc
         else if (isrc.lt.100) then
            write(label(irec),'(a,''.'',i2)') lab,isrc
         else if (isrc.lt.1000) then
            write(label(irec),'(a,''.'',i3)') lab,isrc
         else if (isrc.lt.10000) then
            write(label(irec),'(a,''.'',i4)') lab,isrc
         else
            write(label(irec),'(a,''.'',i5)') lab,isrc
         endif
         write(ntmp,rec=irec) iline
      enddo
     110 continue
      close(nsrc)
      nsrc=irec-1
      write(*,'('' src:'',i7,'' lines'')') nsrc
      nrec=nsrc
      nline=nsrc
      ndeck=ideck
   
      !--read the upn file through the desired revision
      !--act on the modification directives
      !--store any new lines in the direct access file
      nupn=2
      open(nupn,file='upn',status='old')
      ins=.false.
      nset=0
      iupn=0
      iden=0
      do
         iden=iden+1
         iupn=iupn+1
         read(nupn,'(a)',end=120) iline
         l=len_trim(iline)
    
         !--ignore comment lines
         if (iline(1:3).eq.'*/ ') then
            ins=.false.

         !--store any switches found
         else if (iline(1:5).eq.'*set ') then
            if (nset.ge.mset) call error('too many set switches')
            nset=nset+1
            sets(nset)=iline(6:l)
   
         !--start a new ident
         else if (iline(1:7).eq.'*ident ') then
            j1=0
            do i=8,l
               if (iline(i:i).ne.' '.and.j1.eq.0) j1=i
            enddo
            iden=1
            lab='      '
            do i=j1,l
               j=i-l+6
               lab(j:j)=iline(i:i)
            enddo
   
         !--insert new lines after referenced line
         else if (iline(1:3).eq.'*i ') then
            ins=.false.
            i=0
            do j=1,nline
               if (adjustl(label(j)).eq.adjustl(iline(4:l))) then
                  i=j
                  exit
               endif
            enddo
            if (i.eq.0) then
               write(*,'('' line='',i4)') iupn
               call error(' not active for insert')
            endif
            kline=i
            ins=.true.
   
         !--delete referenced lines
         else if (iline(1:3).eq.'*d ') then
            ins=.false.
            k=0
            do i=1,l
               if (iline(i:i).eq.',') k=i
            enddo
            if (k.eq.0) then
               j1=0
               do j=1,nline
                  if (adjustl(label(j)).eq.adjustl(iline(4:l))) then
                     j1=j
                     exit
                  endif
               enddo
               if (j1.eq.0) then
                  write(*,'('' line='',i4)') iupn
                  call error(' not active for delete')
               endif
               j2=j1
            else
               j=0
               do j=1,l
                  if (iline(j:j).eq.'.') then
                     j3=j
                     exit
                  endif
               enddo
               j1=0
               do j=1,nline
                  if (adjustl(label(j)).eq.adjustl(iline(4:k-1))) then
                     j1=j
                     j3=0
                     do jj=4,k-1
                        if (iline(jj:jj).eq.'.') then
                           j3=jj
                           exit
                        endif
                     enddo
                     idnt=iline(4:j3-1)
                     l3=j3-4
                     exit
                  endif
               enddo
               if (j1.eq.0) then
                  write(*,'('' line='',i4)') iupn
                  call error(' not active for delete')
               endif
               j3=0
               do j=k,l
                  if (iline(j:j).eq.'.') j3=j
               enddo
               if (j3.eq.0) then
                  iline=iline(1:k)//idnt(1:l3)//'.'//iline(k+1:l)   
                  l=l+l3+2
               endif
               j2=0
               do j=1,nline
                  if (adjustl(label(j)).eq.adjustl(iline(k+1:l))) then
                     j2=j
                     exit
                  endif
               enddo
               if (j2.eq.0) then
                  write(*,'('' line='',i4)') iupn
                  call error(' not active for delete')
               endif
            endif
            kline=j1
            nline=nline-(j2-j1+1)
            do k=kline,nline
               lline(k)=lline(k+(j2-j1+1))
               label(k)=label(k+(j2-j1+1))
            enddo
            do k=1,ndeck
               if (ldeck(k).gt.kline) ldeck(k)=ldeck(k)-(j2-j1+1)
            enddo
            kline=kline-1
            ins=.true.
   
         !--update line pointers for this insertion
         !--store inserted line in direct access file
         else if (ins) then
            if (nline.ge.mline) call error('too many lines in package')
            kline=kline+1
            do k=kline,nline
               lline(nline-k+kline+1)=lline(nline-k+kline)
               label(nline-k+kline+1)=label(nline-k+kline)
            enddo
            do k=1,ndeck
               if (ldeck(k).gt.kline) ldeck(k)=ldeck(k)+1
            enddo
            nline=nline+1
            nrec=nrec+1
            lline(kline)=nrec
            if (iden.lt.10) then
               write(label(kline),'(a,''.'',i1)') lab,iden
            else if (iden.lt.100) then
               write(label(kline),'(a,''.'',i2)') lab,iden
            else if (iden.lt.1000) then
               write(label(kline),'(a,''.'',i3)') lab,iden
            else if (iden.lt.10000) then
               write(label(kline),'(a,''.'',i4)') lab,iden
            else
               write(label(kline),'(a,''.'',i5)') lab,iden
            endif
            write(ntmp,rec=nrec) iline
   
         endif
      enddo
     120 continue 
      close(nupn)
      write(*,'('' upn:'',i7,'' lines'')') iupn

      ! execute the new command
      if (action.eq.'new') then
         nout=3
         open(nout,file='new',status='unknown')
         do i=1,nline
            j=lline(i)
            read(ntmp,rec=j) iline
            l=len_trim(iline)
            write(nout,'(a)') iline(1:l)
         enddo
         write(*,'('' new:'',i7,'' lines'')') nline
         close(nout)

      ! execute the list command
      else if (action.eq.'list') then

         ! loop over the decks
         do i=1,ndeck
   
            !--open the listing file
            l=len_trim(deckn(i))
            fname=deckn(i)(1:l)//'.lst'
            nout=3
            open(nout,file=fname,status='unknown')
            j1=ldeck(i)+1
            j2=nline
            if (i.lt.ndeck) j2=ldeck(i+1)-1
            temp='      '
            do j=j1,j2
               k=lline(j)
               read(ntmp,rec=k) iline
               l=len_trim(iline)

               ! check for procedure names for lst files
               m1=0
               m2=0
               do m=1,l
                  if (m1.eq.0.and.iline(m:m).ne.' ') m1=m
                  if (m2.eq.0.and.iline(m:m).eq.'(') m2=m
               enddo 
               if (m2.eq.0) then
                  m2=l
               else
                  m2=m2-1
               endif
               if (dsuff(i).eq.'f90') then
                  if (iline(m1:m1+6).eq.'module ')&
                    temp=iline(m1+7:m2)
                  if (iline(m1:m1+7).eq.'program ')&
                    temp=iline(m1+8:m2)
                  if (iline(m1:m1+10).eq.'subroutine ')&
                    temp=iline(m1+11:m2)
                  if (iline(m1:m1+8).eq.'function ')&
                    temp=iline(m1+9:m2)
               endif

               ! write the text line
               write(nout,'(4x,a,'': '',a,1x,a)')&
                 label(j),iline,temp(1:6)
            enddo
            close(nout)
         enddo

      !--execute the extract or revise commands
      else

         !--loop over all the decks
         idiff=0
         if (action.eq.'extract')&
           write(*,'('' files changed (compile them):'')')
         do i=1,ndeck
   
            !--check whether this file is missing
            l=len_trim(deckn(i))
            fname=deckn(i)(1:l)//'.'//dsuff(i)
            inquire(file=fname,exist=exists)
   
            !--file exists
            if (exists) then
               nofile=.false.
   
               !--read the file into line2 and
               !--store the current lines into line1
               nfile=3
               open(nfile,file=fname,status='old')
               i2=0
               do
                  if (i2.ge.mdiff) call error('too many lines in deck')
                  i2=i2+1
                  read(nfile,'(a)',end=140) line2(i2)
               enddo
              140 continue
               close(nfile)
               n2=i2-1
               i1=0
               j1=ldeck(i)+1
               j2=nline
               if (i.lt.ndeck) j2=ldeck(i+1)-1
               set=.true.
               do j=j1,j2
                  k=lline(j)
                  read(ntmp,rec=k) iline
                  if (iline(1:6).eq.'*endif') then
                     set=.true.
                  else if (iline(1:4).eq.'*if ') then
                     l=len_trim(iline)
                     switch=iline(5:l)
                     set=.false.
                     do m=1,nset
                        if (switch.eq.sets(m)) set=.true.
                     enddo
                  else
                     if (set) then
                        if (i1.ge.mdiff) call error('too many lines in deck')
                        i1=i1+1
                        line1(i1)=iline
                     endif
                  endif
               enddo
               n1=i1
      
               !--find the differences from line1 to line2
               idiff0=idiff
               i1=0
               i2=0
               k1=0
               k2=0
               do while (i1.le.n1.and.i2.le.n2)
                  j2=n2+1
            
                  !--find closest pair of identical lines
                  do
                     i1=i1+1
                     if (i1.gt.n1) exit
                     i2=k2
                     do
                        i2=i2+1
                        if (i2.gt.n2) exit
                        if (line1(i1).eq.line2(i2)) exit
                     enddo
                     if (i2.le.n2.and.i2.lt.j2) then
                        j1=i1
                        j2=i2
                        exit
                     endif
                  enddo
                  if (j2.le.n2) then
      
                     !--check for modification
                     if (j1.eq.k1+1) then
                        if (j2.gt.k2+1) then
                           !--this is an insert
                           if (idiff.ge.ndiff)&
                             call error('too many diffs for upn')
                           idiff=idiff+1
                           ref1=adjustl(label(ldeck(i)+k1))
                           write(diffs(idiff),'(''*i '',a)') ref1
                           do ii=k2+1,j2-1
                              if (idiff.ge.ndiff)&
                                call error('too many diffs for upn')
                              idiff=idiff+1
                              write(diffs(idiff),'(a)') line2(ii)
                           enddo
                        endif
                     !--this is a delete
                     else
                        if (idiff.ge.ndiff)&
                          call error('too many diffs for upn')
                        if (k1+1.eq.j1-1) then
                           idiff=idiff+1
                           ref1=adjustl(label(ldeck(i)+k1+1))
                           write(diffs(idiff),'(''*d '',a)') ref1
                        else
                           idiff=idiff+1
                           ref1=adjustl(label(ldeck(i)+k1+1))
                           l=len_trim(ref1)
                           ref2=adjustl(label(ldeck(i)+j1-1))
                           write(diffs(idiff),'(''*d '',a,'','',a)')&
                             ref1(1:l),ref2
                        endif
                        !--the delete has replacement text
                        if (j2.gt.k2+1) then
                           do ii=k2+1,j2-1
                              if (idiff.ge.ndiff)&
                                call error('too many diffs for upn')
                              idiff=idiff+1
                              write(diffs(idiff),'(a)') line2(ii)
                           enddo
                        endif
                     endif
                     i1=j1
                     i2=j2
                     k1=j1
                     k2=j2
                  else
                     j1=j1+1
                     i1=j1
                     i2=k2
                  endif
               enddo
         
            !--file does not exist..
            else
               nofile=.true.
            endif
   
            !--for the extract command,
            !--only update the new or changed files
            if (action.eq.'extract'.and.&
              (nofile.or.idiff.gt.idiff0)) then
   
               !--write out the modified file for each deck
               nout=3
               l=len_trim(deckn(i))
               fname=deckn(i)(1:l)//'.'//dsuff(i)
               open(nout,file=fname,status='unknown')
               write(*,'(5x,a)') fname
               j1=ldeck(i)+1
               j2=nline
               if (i.lt.ndeck) j2=ldeck(i+1)-1
               set=.true.
               do j=j1,j2
                  k=lline(j)
                  read(ntmp,rec=k) iline
                  l=len_trim(iline)
                  if (iline(1:6).eq.'*endif') then
                        set=.true.
                  else if (iline(1:4).eq.'*if ') then
                     switch=iline(5:l)
                     set=.false.
                     if (nset.gt.0) then
                        do k=1,nset
                           if (switch.eq.sets(k)) set=.true.
                        enddo
                     endif
                  else
                     if (set) write(nout,'(a)') iline(1:l)
                  endif
               enddo
               close(nout)
            endif
   
         !--close the loop over decks
         enddo
   
         !--write out the diffs for upn
         if (action(1:6).eq.'revise') then
            nout=3
            open(nout,file='rev',status='unknown')
            call date_and_time(date,time,zone,values)
            write(hdate,'(i2,a,i2)') &
               values(3),month(values(2)),mod(values(1),100)
            do i=1,7
               if (hdate(i:i).eq.' ') hdate(i:i)='0'
            end do
            iout=0
            if (idiff.gt.0) then
               write(nout,'(''*ident rev'')')
               iout=iout+1
               write(nout,'(''*/ '',a)') hdate
               iout=iout+1
               write(nout,'(''*/ comments on this revision'')')
               iout=iout+1
               do j=1,idiff
                  l=len_trim(diffs(j))
                  write(nout,'(a)') diffs(j)(1:l)
                  iout=iout+1
               enddo
               close(nout)
               write(*,'('' rev:'',i7,'' lines'')') iout
               write(*,'('' add rev to upn and edit comments'')')
               write(*,'(''   run a new extract if'')')
               write(*,'(''   edits will change things!'')')
            else
               write(*,'('' no differences found'')')
            endif
         endif
      endif
      write(*,'('' --------------------------------'')')

   endif
   end program upd

   subroutine error(text)
   ! fatal error routine
   character(*)::text
   write(*,'('' error: '',a)') text
   stop 77
   end subroutine error
